Class: Aws::CloudWatchLogs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudWatchLogs::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudwatchlogs/client.rb
Overview
An API client for CloudWatchLogs. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CloudWatchLogs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_kms_key(params = {}) ⇒ Struct
Associates the specified KMS key with the specified log group.
-
#cancel_export_task(params = {}) ⇒ Struct
Cancels the specified export task.
-
#create_export_task(params = {}) ⇒ Types::CreateExportTaskResponse
Creates an export task so that you can efficiently export data from a log group to an Amazon S3 bucket.
-
#create_log_group(params = {}) ⇒ Struct
Creates a log group with the specified name.
-
#create_log_stream(params = {}) ⇒ Struct
Creates a log stream for the specified log group.
-
#delete_account_policy(params = {}) ⇒ Struct
Deletes a CloudWatch Logs account policy.
-
#delete_data_protection_policy(params = {}) ⇒ Struct
Deletes the data protection policy from the specified log group.
-
#delete_destination(params = {}) ⇒ Struct
Deletes the specified destination, and eventually disables all the subscription filters that publish to it.
-
#delete_log_group(params = {}) ⇒ Struct
Deletes the specified log group and permanently deletes all the archived log events associated with the log group.
-
#delete_log_stream(params = {}) ⇒ Struct
Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream.
-
#delete_metric_filter(params = {}) ⇒ Struct
Deletes the specified metric filter.
-
#delete_query_definition(params = {}) ⇒ Types::DeleteQueryDefinitionResponse
Deletes a saved CloudWatch Logs Insights query definition.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy from this account.
-
#delete_retention_policy(params = {}) ⇒ Struct
Deletes the specified retention policy.
-
#delete_subscription_filter(params = {}) ⇒ Struct
Deletes the specified subscription filter.
-
#describe_account_policies(params = {}) ⇒ Types::DescribeAccountPoliciesResponse
Returns a list of all CloudWatch Logs account policies in the account.
-
#describe_destinations(params = {}) ⇒ Types::DescribeDestinationsResponse
Lists all your destinations.
-
#describe_export_tasks(params = {}) ⇒ Types::DescribeExportTasksResponse
Lists the specified export tasks.
-
#describe_log_groups(params = {}) ⇒ Types::DescribeLogGroupsResponse
Lists the specified log groups.
-
#describe_log_streams(params = {}) ⇒ Types::DescribeLogStreamsResponse
Lists the log streams for the specified log group.
-
#describe_metric_filters(params = {}) ⇒ Types::DescribeMetricFiltersResponse
Lists the specified metric filters.
-
#describe_queries(params = {}) ⇒ Types::DescribeQueriesResponse
Returns a list of CloudWatch Logs Insights queries that are scheduled, running, or have been run recently in this account.
-
#describe_query_definitions(params = {}) ⇒ Types::DescribeQueryDefinitionsResponse
This operation returns a paginated list of your saved CloudWatch Logs Insights query definitions.
-
#describe_resource_policies(params = {}) ⇒ Types::DescribeResourcePoliciesResponse
Lists the resource policies in this account.
-
#describe_subscription_filters(params = {}) ⇒ Types::DescribeSubscriptionFiltersResponse
Lists the subscription filters for the specified log group.
-
#disassociate_kms_key(params = {}) ⇒ Struct
Disassociates the associated KMS key from the specified log group.
-
#filter_log_events(params = {}) ⇒ Types::FilterLogEventsResponse
Lists log events from the specified log group.
-
#get_data_protection_policy(params = {}) ⇒ Types::GetDataProtectionPolicyResponse
Returns information about a log group data protection policy.
-
#get_log_events(params = {}) ⇒ Types::GetLogEventsResponse
Lists log events from the specified log stream.
-
#get_log_group_fields(params = {}) ⇒ Types::GetLogGroupFieldsResponse
Returns a list of the fields that are included in log events in the specified log group.
-
#get_log_record(params = {}) ⇒ Types::GetLogRecordResponse
Retrieves all of the fields and values of a single log event.
-
#get_query_results(params = {}) ⇒ Types::GetQueryResultsResponse
Returns the results from the specified query.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with a CloudWatch Logs resource.
-
#list_tags_log_group(params = {}) ⇒ Types::ListTagsLogGroupResponse
The ListTagsLogGroup operation is on the path to deprecation.
-
#put_account_policy(params = {}) ⇒ Types::PutAccountPolicyResponse
Creates an account-level data protection policy that applies to all log groups in the account.
-
#put_data_protection_policy(params = {}) ⇒ Types::PutDataProtectionPolicyResponse
Creates a data protection policy for the specified log group.
-
#put_destination(params = {}) ⇒ Types::PutDestinationResponse
Creates or updates a destination.
-
#put_destination_policy(params = {}) ⇒ Struct
Creates or updates an access policy associated with an existing destination.
-
#put_log_events(params = {}) ⇒ Types::PutLogEventsResponse
Uploads a batch of log events to the specified log stream.
-
#put_metric_filter(params = {}) ⇒ Struct
Creates or updates a metric filter and associates it with the specified log group.
-
#put_query_definition(params = {}) ⇒ Types::PutQueryDefinitionResponse
Creates or updates a query definition for CloudWatch Logs Insights.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53.
-
#put_retention_policy(params = {}) ⇒ Struct
Sets the retention of the specified log group.
-
#put_subscription_filter(params = {}) ⇒ Struct
Creates or updates a subscription filter and associates it with the specified log group.
-
#start_query(params = {}) ⇒ Types::StartQueryResponse
Schedules a query of a log group using CloudWatch Logs Insights.
-
#stop_query(params = {}) ⇒ Types::StopQueryResponse
Stops a CloudWatch Logs Insights query that is in progress.
-
#tag_log_group(params = {}) ⇒ Struct
The TagLogGroup operation is on the path to deprecation.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch Logs resource.
-
#test_metric_filter(params = {}) ⇒ Types::TestMetricFilterResponse
Tests the filter pattern of a metric filter against a sample of log event messages.
-
#untag_log_group(params = {}) ⇒ Struct
The UntagLogGroup operation is on the path to deprecation.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
380 381 382 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 380 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3477 3478 3479 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3477 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3480 3481 3482 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3480 def errors_module Errors end |
Instance Method Details
#associate_kms_key(params = {}) ⇒ Struct
Associates the specified KMS key with the specified log group.
Associating a KMS key with a log group overrides any existing associations between the log group and a KMS key. After a KMS key is associated with a log group, all newly ingested data for the log group is encrypted using the KMS key. This association is stored as long as the data encrypted with the KMS keyis still within CloudWatch Logs. This enables CloudWatch Logs to decrypt this data whenever it is requested.
CloudWatch Logs supports only symmetric KMS keys. Do not use an associate an asymmetric KMS key with your log group. For more information, see [Using Symmetric and Asymmetric Keys].
It can take up to 5 minutes for this operation to take effect.
If you attempt to associate a KMS key with a log group but the KMS key does not exist or the KMS key is disabled, you receive an ‘InvalidParameterException` error.
[1]: docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html
437 438 439 440 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 437 def associate_kms_key(params = {}, = {}) req = build_request(:associate_kms_key, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3455 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-cloudwatchlogs' context[:gem_version] = '1.64.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_export_task(params = {}) ⇒ Struct
Cancels the specified export task.
The task must be in the ‘PENDING` or `RUNNING` state.
461 462 463 464 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 461 def cancel_export_task(params = {}, = {}) req = build_request(:cancel_export_task, params) req.send_request() end |
#create_export_task(params = {}) ⇒ Types::CreateExportTaskResponse
Creates an export task so that you can efficiently export data from a log group to an Amazon S3 bucket. When you perform a ‘CreateExportTask` operation, you must use credentials that have permission to write to the S3 bucket that you specify as the destination.
Exporting log data to S3 buckets that are encrypted by KMS is supported. Exporting log data to Amazon S3 buckets that have S3 Object Lock enabled with a retention period is also supported.
Exporting to S3 buckets that are encrypted with AES-256 is supported.
This is an asynchronous call. If all the required information is provided, this operation initiates an export task and responds with the ID of the task. After the task has started, you can use
- DescribeExportTasks][1
-
to get the status of the export task. Each
account can only have one active (‘RUNNING` or `PENDING`) export task at a time. To cancel an export task, use [CancelExportTask].
You can export logs from multiple log groups or multiple time ranges to the same S3 bucket. To separate log data for each export task, specify a prefix to be used as the Amazon S3 key prefix for all exported objects.
<note markdown=“1”> Time-based sorting on chunks of log data inside an exported file is not guaranteed. You can sort the exported log field data by using Linux utilities.
</note>
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeExportTasks.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CancelExportTask.html
556 557 558 559 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 556 def create_export_task(params = {}, = {}) req = build_request(:create_export_task, params) req.send_request() end |
#create_log_group(params = {}) ⇒ Struct
Creates a log group with the specified name. You can create up to 20,000 log groups per account.
You must use the following guidelines when naming a log group:
-
Log group names must be unique within a Region for an Amazon Web Services account.
-
Log group names can be between 1 and 512 characters long.
-
Log group names consist of the following characters: a-z, A-Z, 0-9, ‘_’ (underscore), ‘-’ (hyphen), ‘/’ (forward slash), ‘.’ (period), and ‘#’ (number sign)
When you create a log group, by default the log events in the log group do not expire. To set a retention policy so that events expire and are deleted after a specified time, use [PutRetentionPolicy].
If you associate an KMS key with the log group, ingested data is encrypted using the KMS key. This association is stored as long as the data encrypted with the KMS key is still within CloudWatch Logs. This enables CloudWatch Logs to decrypt this data whenever it is requested.
If you attempt to associate a KMS key with the log group but the KMS key does not exist or the KMS key is disabled, you receive an ‘InvalidParameterException` error.
CloudWatch Logs supports only symmetric KMS keys. Do not associate an asymmetric KMS key with your log group. For more information, see [Using Symmetric and Asymmetric Keys].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutRetentionPolicy.html [2]: docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html
641 642 643 644 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 641 def create_log_group(params = {}, = {}) req = build_request(:create_log_group, params) req.send_request() end |
#create_log_stream(params = {}) ⇒ Struct
Creates a log stream for the specified log group. A log stream is a sequence of log events that originate from a single source, such as an application instance or a resource that is being monitored.
There is no limit on the number of log streams that you can create for a log group. There is a limit of 50 TPS on ‘CreateLogStream` operations, after which transactions are throttled.
You must use the following guidelines when naming a log stream:
-
Log stream names must be unique within the log group.
-
Log stream names can be between 1 and 512 characters long.
-
Don’t use ‘:’ (colon) or ‘*’ (asterisk) characters.
681 682 683 684 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 681 def create_log_stream(params = {}, = {}) req = build_request(:create_log_stream, params) req.send_request() end |
#delete_account_policy(params = {}) ⇒ Struct
Deletes a CloudWatch Logs account policy.
To use this operation, you must be signed on with the ‘logs:DeleteDataProtectionPolicy` and `logs:DeleteAccountPolicy` permissions.
712 713 714 715 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 712 def delete_account_policy(params = {}, = {}) req = build_request(:delete_account_policy, params) req.send_request() end |
#delete_data_protection_policy(params = {}) ⇒ Struct
Deletes the data protection policy from the specified log group.
For more information about data protection policies, see [PutDataProtectionPolicy].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html
742 743 744 745 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 742 def delete_data_protection_policy(params = {}, = {}) req = build_request(:delete_data_protection_policy, params) req.send_request() end |
#delete_destination(params = {}) ⇒ Struct
Deletes the specified destination, and eventually disables all the subscription filters that publish to it. This operation does not delete the physical resource encapsulated by the destination.
766 767 768 769 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 766 def delete_destination(params = {}, = {}) req = build_request(:delete_destination, params) req.send_request() end |
#delete_log_group(params = {}) ⇒ Struct
Deletes the specified log group and permanently deletes all the archived log events associated with the log group.
789 790 791 792 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 789 def delete_log_group(params = {}, = {}) req = build_request(:delete_log_group, params) req.send_request() end |
#delete_log_stream(params = {}) ⇒ Struct
Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream.
816 817 818 819 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 816 def delete_log_stream(params = {}, = {}) req = build_request(:delete_log_stream, params) req.send_request() end |
#delete_metric_filter(params = {}) ⇒ Struct
Deletes the specified metric filter.
842 843 844 845 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 842 def delete_metric_filter(params = {}, = {}) req = build_request(:delete_metric_filter, params) req.send_request() end |
#delete_query_definition(params = {}) ⇒ Types::DeleteQueryDefinitionResponse
Deletes a saved CloudWatch Logs Insights query definition. A query definition contains details about a saved CloudWatch Logs Insights query.
Each ‘DeleteQueryDefinition` operation can delete one query definition.
You must have the ‘logs:DeleteQueryDefinition` permission to be able to perform this operation.
884 885 886 887 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 884 def delete_query_definition(params = {}, = {}) req = build_request(:delete_query_definition, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy from this account. This revokes the access of the identities in that policy to put log events to this account.
907 908 909 910 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 907 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_retention_policy(params = {}) ⇒ Struct
Deletes the specified retention policy.
Log events do not expire if they belong to log groups without a retention policy.
932 933 934 935 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 932 def delete_retention_policy(params = {}, = {}) req = build_request(:delete_retention_policy, params) req.send_request() end |
#delete_subscription_filter(params = {}) ⇒ Struct
Deletes the specified subscription filter.
958 959 960 961 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 958 def delete_subscription_filter(params = {}, = {}) req = build_request(:delete_subscription_filter, params) req.send_request() end |
#describe_account_policies(params = {}) ⇒ Types::DescribeAccountPoliciesResponse
Returns a list of all CloudWatch Logs account policies in the account.
1010 1011 1012 1013 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1010 def describe_account_policies(params = {}, = {}) req = build_request(:describe_account_policies, params) req.send_request() end |
#describe_destinations(params = {}) ⇒ Types::DescribeDestinationsResponse
Lists all your destinations. The results are ASCII-sorted by destination name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1060 1061 1062 1063 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1060 def describe_destinations(params = {}, = {}) req = build_request(:describe_destinations, params) req.send_request() end |
#describe_export_tasks(params = {}) ⇒ Types::DescribeExportTasksResponse
Lists the specified export tasks. You can list all your export tasks or filter the results based on task ID or task status.
1118 1119 1120 1121 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1118 def describe_export_tasks(params = {}, = {}) req = build_request(:describe_export_tasks, params) req.send_request() end |
#describe_log_groups(params = {}) ⇒ Types::DescribeLogGroupsResponse
Lists the specified log groups. You can list all your log groups or filter the results by prefix. The results are ASCII-sorted by log group name.
CloudWatch Logs doesn’t support IAM policies that control access to the ‘DescribeLogGroups` action by using the `aws:ResourceTag/key-name ` condition key. Other CloudWatch Logs actions do support the use of the `aws:ResourceTag/key-name ` condition key to control access. For more information about using tags to control access, see [Controlling access to Amazon Web Services resources using tags].
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account and view data from the linked source accounts. For more information, see [CloudWatch cross-account observability].
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1227 1228 1229 1230 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1227 def describe_log_groups(params = {}, = {}) req = build_request(:describe_log_groups, params) req.send_request() end |
#describe_log_streams(params = {}) ⇒ Types::DescribeLogStreamsResponse
Lists the log streams for the specified log group. You can list all the log streams or filter the results by prefix. You can also control how the results are ordered.
You can specify the log group to search by using either ‘logGroupIdentifier` or `logGroupName`. You must include one of these two parameters, but you can’t include both.
This operation has a limit of five transactions per second, after which transactions are throttled.
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account and view data from the linked source accounts. For more information, see [CloudWatch cross-account observability].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1339 1340 1341 1342 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1339 def describe_log_streams(params = {}, = {}) req = build_request(:describe_log_streams, params) req.send_request() end |
#describe_metric_filters(params = {}) ⇒ Types::DescribeMetricFiltersResponse
Lists the specified metric filters. You can list all of the metric filters or filter the results by log name, prefix, metric name, or metric namespace. The results are ASCII-sorted by filter name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1412 1413 1414 1415 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1412 def describe_metric_filters(params = {}, = {}) req = build_request(:describe_metric_filters, params) req.send_request() end |
#describe_queries(params = {}) ⇒ Types::DescribeQueriesResponse
Returns a list of CloudWatch Logs Insights queries that are scheduled, running, or have been run recently in this account. You can request all queries or limit it to queries of a specific log group or queries with a certain status.
1465 1466 1467 1468 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1465 def describe_queries(params = {}, = {}) req = build_request(:describe_queries, params) req.send_request() end |
#describe_query_definitions(params = {}) ⇒ Types::DescribeQueryDefinitionsResponse
This operation returns a paginated list of your saved CloudWatch Logs Insights query definitions.
You can use the ‘queryDefinitionNamePrefix` parameter to limit the results to only the query definitions that have names that start with a certain string.
1517 1518 1519 1520 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1517 def describe_query_definitions(params = {}, = {}) req = build_request(:describe_query_definitions, params) req.send_request() end |
#describe_resource_policies(params = {}) ⇒ Types::DescribeResourcePoliciesResponse
Lists the resource policies in this account.
1556 1557 1558 1559 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1556 def describe_resource_policies(params = {}, = {}) req = build_request(:describe_resource_policies, params) req.send_request() end |
#describe_subscription_filters(params = {}) ⇒ Types::DescribeSubscriptionFiltersResponse
Lists the subscription filters for the specified log group. You can list all the subscription filters or filter the results by prefix. The results are ASCII-sorted by filter name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1612 1613 1614 1615 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1612 def describe_subscription_filters(params = {}, = {}) req = build_request(:describe_subscription_filters, params) req.send_request() end |
#disassociate_kms_key(params = {}) ⇒ Struct
Disassociates the associated KMS key from the specified log group.
After the KMS key is disassociated from the log group, CloudWatch Logs stops encrypting newly ingested data for the log group. All previously ingested data remains encrypted, and CloudWatch Logs requires permissions for the KMS key whenever the encrypted data is requested.
Note that it can take up to 5 minutes for this operation to take effect.
1642 1643 1644 1645 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1642 def disassociate_kms_key(params = {}, = {}) req = build_request(:disassociate_kms_key, params) req.send_request() end |
#filter_log_events(params = {}) ⇒ Types::FilterLogEventsResponse
Lists log events from the specified log group. You can list all the log events or filter the results using a filter pattern, a time range, and the name of the log stream.
You must have the ‘logs:FilterLogEvents` permission to perform this operation.
You can specify the log group to search by using either ‘logGroupIdentifier` or `logGroupName`. You must include one of these two parameters, but you can’t include both.
By default, this operation returns as many log events as can fit in 1 MB (up to 10,000 log events) or all the events found within the specified time range. If the results include a token, that means there are more log events available. You can get additional results by specifying the token in a subsequent call. This operation can return empty results while there are more log events available through the token.
The returned log events are sorted by event timestamp, the timestamp when the event was ingested by CloudWatch Logs, and the ID of the ‘PutLogEvents` request.
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account and view data from the linked source accounts. For more information, see [CloudWatch cross-account observability].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1799 1800 1801 1802 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1799 def filter_log_events(params = {}, = {}) req = build_request(:filter_log_events, params) req.send_request() end |
#get_data_protection_policy(params = {}) ⇒ Types::GetDataProtectionPolicyResponse
Returns information about a log group data protection policy.
1832 1833 1834 1835 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1832 def get_data_protection_policy(params = {}, = {}) req = build_request(:get_data_protection_policy, params) req.send_request() end |
#get_log_events(params = {}) ⇒ Types::GetLogEventsResponse
Lists log events from the specified log stream. You can list all of the log events or filter using a time range.
By default, this operation returns as many log events as can fit in a response size of 1MB (up to 10,000 log events). You can get additional log events by specifying one of the tokens in a subsequent call. This operation can return empty results while there are more log events available through the token.
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account and view data from the linked source accounts. For more information, see [CloudWatch cross-account observability].
You can specify the log group to search by using either ‘logGroupIdentifier` or `logGroupName`. You must include one of these two parameters, but you can’t include both.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1951 1952 1953 1954 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1951 def get_log_events(params = {}, = {}) req = build_request(:get_log_events, params) req.send_request() end |
#get_log_group_fields(params = {}) ⇒ Types::GetLogGroupFieldsResponse
Returns a list of the fields that are included in log events in the specified log group. Includes the percentage of log events that contain each field. The search is limited to a time period that you specify.
You can specify the log group to search by using either ‘logGroupIdentifier` or `logGroupName`. You must specify one of these parameters, but you can’t specify both.
In the results, fields that start with ‘@` are fields generated by CloudWatch Logs. For example, `@timestamp` is the timestamp of each log event. For more information about the fields that are generated by CloudWatch logs, see [Supported Logs and Discovered Fields].
The response results are sorted by the frequency percentage, starting with the highest percentage.
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account and view data from the linked source accounts. For more information, see [CloudWatch cross-account observability].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData-discoverable-fields.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
2031 2032 2033 2034 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2031 def get_log_group_fields(params = {}, = {}) req = build_request(:get_log_group_fields, params) req.send_request() end |
#get_log_record(params = {}) ⇒ Types::GetLogRecordResponse
Retrieves all of the fields and values of a single log event. All fields are retrieved, even if the original query that produced the ‘logRecordPointer` retrieved only a subset of fields. Fields are returned as field name/field value pairs.
The full unparsed log event is returned within ‘@message`.
2077 2078 2079 2080 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2077 def get_log_record(params = {}, = {}) req = build_request(:get_log_record, params) req.send_request() end |
#get_query_results(params = {}) ⇒ Types::GetQueryResultsResponse
Returns the results from the specified query.
Only the fields requested in the query are returned, along with a ‘@ptr` field, which is the identifier for the log record. You can use the value of `@ptr` in a [GetLogRecord] operation to get the full log record.
‘GetQueryResults` does not start running a query. To run a query, use [StartQuery].
If the value of the ‘Status` field in the output is `Running`, this operation returns only partial results. If you see a value of `Scheduled` or `Running` for the status, you can retry the operation later to see the final results.
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account to start queries in linked source accounts. For more information, see [CloudWatch cross-account observability].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogRecord.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html [3]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
2138 2139 2140 2141 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2138 def get_query_results(params = {}, = {}) req = build_request(:get_query_results, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with a CloudWatch Logs resource. Currently, log groups and destinations support tagging.
2181 2182 2183 2184 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2181 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tags_log_group(params = {}) ⇒ Types::ListTagsLogGroupResponse
The ListTagsLogGroup operation is on the path to deprecation. We recommend that you use [ListTagsForResource] instead.
Lists the tags for the specified log group.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html
2217 2218 2219 2220 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2217 def (params = {}, = {}) req = build_request(:list_tags_log_group, params) req.send_request() end |
#put_account_policy(params = {}) ⇒ Types::PutAccountPolicyResponse
Creates an account-level data protection policy that applies to all log groups in the account. A data protection policy can help safeguard sensitive data that’s ingested by your log groups by auditing and masking the sensitive log data. Each account can have only one account-level policy.
Sensitive data is detected and masked when it is ingested into a log group. When you set a data protection policy, log events ingested into the log groups before that time are not masked.
If you use ‘PutAccountPolicy` to create a data protection policy for your whole account, it applies to both existing log groups and all log groups that are created later in this account. The account policy is applied to existing log groups with eventual consistency. It might take up to 5 minutes before sensitive data in existing log groups begins to be masked.
By default, when a user views a log event that includes masked data, the sensitive data is replaced by asterisks. A user who has the ‘logs:Unmask` permission can use a [GetLogEvents] or
- FilterLogEvents][2
-
operation with the ‘unmask` parameter set to
‘true` to view the unmasked log events. Users with the `logs:Unmask` can also view unmasked data in the CloudWatch Logs console by running a CloudWatch Logs Insights query with the `unmask` query command.
For more information, including a list of types of data that can be audited and masked, see [Protect sensitive log data with masking].
To use the ‘PutAccountPolicy` operation, you must be signed on with the `logs:PutDataProtectionPolicy` and `logs:PutAccountPolicy` permissions.
The ‘PutAccountPolicy` operation applies to all log groups in the account. You can also use [PutDataProtectionPolicy] to create a data protection policy that applies to just one log group. If a log group has its own data protection policy and the account also has an account-level data protection policy, then the two policies are cumulative. Any sensitive term specified in either policy is masked.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogEvents.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_FilterLogEvents.html [3]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data.html [4]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html
2352 2353 2354 2355 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2352 def put_account_policy(params = {}, = {}) req = build_request(:put_account_policy, params) req.send_request() end |
#put_data_protection_policy(params = {}) ⇒ Types::PutDataProtectionPolicyResponse
Creates a data protection policy for the specified log group. A data protection policy can help safeguard sensitive data that’s ingested by the log group by auditing and masking the sensitive log data.
Sensitive data is detected and masked when it is ingested into the log group. When you set a data protection policy, log events ingested into the log group before that time are not masked.
By default, when a user views a log event that includes masked data, the sensitive data is replaced by asterisks. A user who has the ‘logs:Unmask` permission can use a [GetLogEvents] or
- FilterLogEvents][2
-
operation with the ‘unmask` parameter set to
‘true` to view the unmasked log events. Users with the `logs:Unmask` can also view unmasked data in the CloudWatch Logs console by running a CloudWatch Logs Insights query with the `unmask` query command.
For more information, including a list of types of data that can be audited and masked, see [Protect sensitive log data with masking].
The ‘PutDataProtectionPolicy` operation applies to only the specified log group. You can also use [PutAccountPolicy] to create an account-level data protection policy that applies to all log groups in the account, including both existing log groups and log groups that are created level. If a log group has its own data protection policy and the account also has an account-level data protection policy, then the two policies are cumulative. Any sensitive term specified in either policy is masked.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogEvents.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_FilterLogEvents.html [3]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data.html [4]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutAccountPolicy.html
2462 2463 2464 2465 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2462 def put_data_protection_policy(params = {}, = {}) req = build_request(:put_data_protection_policy, params) req.send_request() end |
#put_destination(params = {}) ⇒ Types::PutDestinationResponse
Creates or updates a destination. This operation is used only to create destinations for cross-account subscriptions.
A destination encapsulates a physical resource (such as an Amazon Kinesis stream). With a destination, you can subscribe to a real-time stream of log events for a different account, ingested using [PutLogEvents].
Through an access policy, a destination controls what is written to it. By default, ‘PutDestination` does not set any access policy with the destination, which means a cross-account user cannot call
- PutSubscriptionFilter][2
-
against this destination. To enable this,
the destination owner must call [PutDestinationPolicy] after ‘PutDestination`.
To perform a ‘PutDestination` operation, you must also have the `iam:PassRole` permission.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutSubscriptionFilter.html [3]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestinationPolicy.html
2540 2541 2542 2543 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2540 def put_destination(params = {}, = {}) req = build_request(:put_destination, params) req.send_request() end |
#put_destination_policy(params = {}) ⇒ Struct
Creates or updates an access policy associated with an existing destination. An access policy is an [IAM policy document] that is used to authorize claims to register a subscription filter against a given destination.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/policies_overview.html
2593 2594 2595 2596 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2593 def put_destination_policy(params = {}, = {}) req = build_request(:put_destination_policy, params) req.send_request() end |
#put_log_events(params = {}) ⇒ Types::PutLogEventsResponse
Uploads a batch of log events to the specified log stream.
The sequence token is now ignored in ‘PutLogEvents` actions. `PutLogEvents` actions are always accepted and never return `InvalidSequenceTokenException` or `DataAlreadyAcceptedException` even if the sequence token is not valid. You can use parallel `PutLogEvents` actions on the same log stream.
The batch of events must satisfy the following constraints:
-
The maximum batch size is 1,048,576 bytes. This size is calculated as the sum of all event messages in UTF-8, plus 26 bytes for each log event.
-
None of the log events in the batch can be more than 2 hours in the future.
-
None of the log events in the batch can be more than 14 days in the past. Also, none of the log events can be from earlier than the retention period of the log group.
-
The log events in the batch must be in chronological order by their timestamp. The timestamp is the time that the event occurred, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`. (In Amazon Web Services Tools for PowerShell and the Amazon Web Services SDK for .NET, the timestamp is specified in .NET format: `yyyy-mm-ddThh:mm:ss`. For example, `2017-09-15T13:45:30`.)
-
A batch of log events in a single request cannot span more than 24 hours. Otherwise, the operation fails.
-
Each log event can be no larger than 256 KB.
-
The maximum number of log events in a batch is 10,000.
-
The quota of five requests per second per log stream has been removed. Instead, ‘PutLogEvents` actions are throttled based on a per-second per-account quota. You can request an increase to the per-second throttling quota by using the Service Quotas service.
If a call to ‘PutLogEvents` returns “UnrecognizedClientException” the most likely cause is a non-valid Amazon Web Services access key ID or secret key.
2690 2691 2692 2693 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2690 def put_log_events(params = {}, = {}) req = build_request(:put_log_events, params) req.send_request() end |
#put_metric_filter(params = {}) ⇒ Struct
Creates or updates a metric filter and associates it with the specified log group. With metric filters, you can configure rules to extract metric data from log events ingested through [PutLogEvents].
The maximum number of metric filters that can be associated with a log group is 100.
When you create a metric filter, you can also optionally assign a unit and dimensions to the metric that is created.
Metrics extracted from log events are charged as custom metrics. To prevent unexpected high charges, do not specify high-cardinality fields such as ‘IPAddress` or `requestID` as dimensions. Each different value found for a dimension is treated as a separate metric and accrues charges as a separate custom metric.
CloudWatch Logs disables a metric filter if it generates 1,000
different name/value pairs for your specified dimensions within a certain amount of time. This helps to prevent accidental high charges.
You can also set up a billing alarm to alert you if your charges are
higher than expected. For more information, see [ Creating a Billing Alarm to Monitor Your Estimated Amazon Web Services Charges].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/monitor_estimated_charges_with_cloudwatch.html
2764 2765 2766 2767 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2764 def put_metric_filter(params = {}, = {}) req = build_request(:put_metric_filter, params) req.send_request() end |
#put_query_definition(params = {}) ⇒ Types::PutQueryDefinitionResponse
Creates or updates a query definition for CloudWatch Logs Insights. For more information, see [Analyzing Log Data with CloudWatch Logs Insights].
To update a query definition, specify its ‘queryDefinitionId` in your request. The values of `name`, `queryString`, and `logGroupNames` are changed to the values that you specify in your update operation. No current values are retained from the current query definition. For example, imagine updating a current query definition that includes log groups. If you don’t specify the ‘logGroupNames` parameter in your update operation, the query definition changes to contain no log groups.
You must have the ‘logs:PutQueryDefinition` permission to be able to perform this operation.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AnalyzingLogData.html
2850 2851 2852 2853 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2850 def put_query_definition(params = {}, = {}) req = build_request(:put_query_definition, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53. An account can have up to 10 resource policies per Amazon Web Services Region.
2916 2917 2918 2919 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2916 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#put_retention_policy(params = {}) ⇒ Struct
Sets the retention of the specified log group. With a retention policy, you can configure the number of days for which to retain log events in the specified log group.
<note markdown=“1”> CloudWatch Logs doesn’t immediately delete log events when they reach their retention setting. It typically takes up to 72 hours after that before log events are deleted, but in rare situations might take longer.
To illustrate, imagine that you change a log group to have a longer
retention setting when it contains log events that are past the expiration date, but haven’t been deleted. Those log events will take up to 72 hours to be deleted after the new retention date is reached. To make sure that log data is deleted permanently, keep a log group at its lower retention setting until 72 hours after the previous retention period ends. Alternatively, wait to change the retention setting until you confirm that the earlier log events are deleted.
</note>
2969 2970 2971 2972 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2969 def put_retention_policy(params = {}, = {}) req = build_request(:put_retention_policy, params) req.send_request() end |
#put_subscription_filter(params = {}) ⇒ Struct
Creates or updates a subscription filter and associates it with the specified log group. With subscription filters, you can subscribe to a real-time stream of log events ingested through [PutLogEvents] and have them delivered to a specific destination. When log events are sent to the receiving service, they are Base64 encoded and compressed with the GZIP format.
The following destinations are supported for subscription filters:
-
An Amazon Kinesis data stream belonging to the same account as the subscription filter, for same-account delivery.
-
A logical destination that belongs to a different account, for cross-account delivery.
-
An Amazon Kinesis Data Firehose delivery stream that belongs to the same account as the subscription filter, for same-account delivery.
-
An Lambda function that belongs to the same account as the subscription filter, for same-account delivery.
Each log group can have up to two subscription filters associated with it. If you are updating an existing filter, you must specify the correct name in ‘filterName`.
To perform a ‘PutSubscriptionFilter` operation for any destination except a Lambda function, you must also have the `iam:PassRole` permission.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html
3077 3078 3079 3080 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3077 def put_subscription_filter(params = {}, = {}) req = build_request(:put_subscription_filter, params) req.send_request() end |
#start_query(params = {}) ⇒ Types::StartQueryResponse
Schedules a query of a log group using CloudWatch Logs Insights. You specify the log group and time range to query and the query string to use.
For more information, see [CloudWatch Logs Insights Query Syntax].
Queries time out after 60 minutes of runtime. If your queries are timing out, reduce the time range being searched or partition your query into a number of queries.
If you are using CloudWatch cross-account observability, you can use this operation in a monitoring account to start a query in a linked source account. For more information, see [CloudWatch cross-account observability]. For a cross-account ‘StartQuery` operation, the query definition must be defined in the monitoring account.
You can have up to 30 concurrent CloudWatch Logs insights queries, including queries that have been added to dashboards.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Unified-Cross-Account.html
3183 3184 3185 3186 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3183 def start_query(params = {}, = {}) req = build_request(:start_query, params) req.send_request() end |
#stop_query(params = {}) ⇒ Types::StopQueryResponse
Stops a CloudWatch Logs Insights query that is in progress. If the query has already ended, the operation returns an error indicating that the specified query is not running.
3214 3215 3216 3217 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3214 def stop_query(params = {}, = {}) req = build_request(:stop_query, params) req.send_request() end |
#tag_log_group(params = {}) ⇒ Struct
The TagLogGroup operation is on the path to deprecation. We recommend that you use [TagResource] instead.
Adds or updates the specified tags for the specified log group.
To list the tags for a log group, use [ListTagsForResource]. To remove tags, use [UntagResource].
For more information about tags, see [Tag Log Groups in Amazon CloudWatch Logs] in the *Amazon CloudWatch Logs User Guide*.
CloudWatch Logs doesn’t support IAM policies that prevent users from assigning specified tags to log groups using the ‘aws:Resource/key-name ` or `aws:TagKeys` condition keys. For more information about using tags to control access, see [Controlling access to Amazon Web Services resources using tags].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html [3]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html [4]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html#log-group-tagging [5]: docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html
3265 3266 3267 3268 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3265 def tag_log_group(params = {}, = {}) req = build_request(:tag_log_group, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch Logs resource. Currently, the only CloudWatch Logs resources that can be tagged are log groups and destinations.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
Tags don’t have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the ‘TagResource` action with a resource that already has tags. If you specify a new tag key for the alarm, this tag is appended to the list of tags associated with the alarm. If you specify a tag key that is already associated with the alarm, the new tag value that you specify replaces the previous value for that tag.
You can associate as many as 50 tags with a CloudWatch Logs resource.
3323 3324 3325 3326 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3323 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#test_metric_filter(params = {}) ⇒ Types::TestMetricFilterResponse
Tests the filter pattern of a metric filter against a sample of log event messages. You can use this operation to validate the correctness of a metric filter pattern.
3364 3365 3366 3367 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3364 def test_metric_filter(params = {}, = {}) req = build_request(:test_metric_filter, params) req.send_request() end |
#untag_log_group(params = {}) ⇒ Struct
The UntagLogGroup operation is on the path to deprecation. We recommend that you use [UntagResource] instead.
Removes the specified tags from the specified log group.
To list the tags for a log group, use [ListTagsForResource]. To add tags, use [TagResource].
CloudWatch Logs doesn’t support IAM policies that prevent users from assigning specified tags to log groups using the ‘aws:Resource/key-name ` or `aws:TagKeys` condition keys.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html [3]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html
3406 3407 3408 3409 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3406 def untag_log_group(params = {}, = {}) req = build_request(:untag_log_group, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
3446 3447 3448 3449 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3446 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3470 3471 3472 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 3470 def waiter_names [] end |