Class: Aws::CloudWatchLogs::Types::AddKeyEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This object defines one key that will be added with the addKeys processor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The key of the new entry to be added to the log event



89
90
91
92
93
94
95
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 89

class AddKeyEntry < Struct.new(
  :key,
  :value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#overwrite_if_existsBoolean

Specifies whether to overwrite the value if the key already exists in the log event. If you omit this, the default is false.



89
90
91
92
93
94
95
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 89

class AddKeyEntry < Struct.new(
  :key,
  :value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the new entry to be added to the log event



89
90
91
92
93
94
95
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 89

class AddKeyEntry < Struct.new(
  :key,
  :value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end