Class: Aws::CloudWatchLogs::Types::CancelImportTaskResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::CancelImportTaskResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Integer
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
-
#import_id ⇒ String
The ID of the cancelled import task.
-
#import_statistics ⇒ Types::ImportStatistics
Statistics about the import progress at the time of cancellation.
-
#import_status ⇒ String
The final status of the import task.
-
#last_updated_time ⇒ Integer
The timestamp when the import task was cancelled, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Instance Attribute Details
#creation_time ⇒ Integer
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
552 553 554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 552 class CancelImportTaskResponse < Struct.new( :import_id, :import_statistics, :import_status, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The ID of the cancelled import task.
552 553 554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 552 class CancelImportTaskResponse < Struct.new( :import_id, :import_statistics, :import_status, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#import_statistics ⇒ Types::ImportStatistics
Statistics about the import progress at the time of cancellation.
552 553 554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 552 class CancelImportTaskResponse < Struct.new( :import_id, :import_statistics, :import_status, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The final status of the import task. This will be set to CANCELLED.
552 553 554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 552 class CancelImportTaskResponse < Struct.new( :import_id, :import_statistics, :import_status, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Integer
The timestamp when the import task was cancelled, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
552 553 554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 552 class CancelImportTaskResponse < Struct.new( :import_id, :import_statistics, :import_status, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |