Class: Aws::CloudWatchLogs::Types::ConfigurationTemplate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

A structure containing information about the deafult settings and available settings that you can use to configure a [delivery] or a [delivery destination].

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_Delivery.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeliveryDestination.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_action_for_allow_vended_logs_delivery_for_resourceString

The action permissions that a caller needs to have to be able to successfully create a delivery source on the desired resource type when calling [PutDeliverySource].

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_field_delimitersArray<String>

The valid values that a caller can use as field delimiters when calling [CreateDelivery] or [UpdateDeliveryConfiguration] on a delivery that delivers in ‘Plain`, `W3C`, or `Raw` format.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UpdateDeliveryConfiguration.html

Returns:

  • (Array<String>)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_fieldsArray<Types::RecordField>

The allowed fields that a caller can use in the ‘recordFields` parameter of a [CreateDelivery] or

UpdateDeliveryConfiguration][2

operation.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UpdateDeliveryConfiguration.html

Returns:



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_output_formatsArray<String>

The list of delivery destination output formats that are supported by this log source.

Returns:

  • (Array<String>)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#allowed_suffix_path_fieldsArray<String>

The list of variable fields that can be used in the suffix path of a delivery that delivers to an S3 bucket.

Returns:

  • (Array<String>)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#default_delivery_config_valuesTypes::ConfigurationTemplateDeliveryConfigValues

A mapping that displays the default value of each property within a delivery’s configuration, if it is not specified in the request.



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_destination_typeString

A string specifying which destination type this configuration template applies to.

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_source_configurationArray<Types::DeliverySourceConfigurationSchema>

The schema of the delivery source configuration that is available for this log type. Each element describes a configuration that can be set when calling [PutDeliverySource], including the configuration name, type, and default value.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#log_typeString

A string specifying which log type this configuration template applies to.

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

A string specifying which resource type this configuration template applies to.

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#s3_tables_integrationTypes::S3TablesIntegration

The S3 Tables integration configuration for this configuration template, including the datasource name and type.



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

A string specifying which service this configuration template applies to. For more information about supported services see [Enable logging from Amazon Web Services services.].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 661

class ConfigurationTemplate < Struct.new(
  :service,
  :log_type,
  :resource_type,
  :delivery_destination_type,
  :default_delivery_config_values,
  :allowed_fields,
  :allowed_output_formats,
  :allowed_action_for_allow_vended_logs_delivery_for_resource,
  :allowed_field_delimiters,
  :allowed_suffix_path_fields,
  :delivery_source_configuration,
  :s3_tables_integration)
  SENSITIVE = []
  include Aws::Structure
end