Class: Aws::CloudWatchLogs::Types::CreateDeliveryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delivery_destination_arnString

The ARN of the delivery destination to use for this delivery.



794
795
796
797
798
799
800
801
802
803
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 794

class CreateDeliveryRequest < Struct.new(
  :delivery_source_name,
  :delivery_destination_arn,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_source_nameString

The name of the delivery source to use for this delivery.



794
795
796
797
798
799
800
801
802
803
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 794

class CreateDeliveryRequest < Struct.new(
  :delivery_source_name,
  :delivery_destination_arn,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#field_delimiterString

The field delimiter to use between record fields when the final output format of a delivery is in Plain, W3C, or Raw format.



794
795
796
797
798
799
800
801
802
803
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 794

class CreateDeliveryRequest < Struct.new(
  :delivery_source_name,
  :delivery_destination_arn,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#record_fieldsArray<String>

The list of record fields to be delivered to the destination, in order. If the delivery’s log source has mandatory fields, they must be included in this list.



794
795
796
797
798
799
800
801
802
803
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 794

class CreateDeliveryRequest < Struct.new(
  :delivery_source_name,
  :delivery_destination_arn,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#s3_delivery_configurationTypes::S3DeliveryConfiguration

This structure contains parameters that are valid only when the delivery’s delivery destination is an S3 bucket.



794
795
796
797
798
799
800
801
802
803
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 794

class CreateDeliveryRequest < Struct.new(
  :delivery_source_name,
  :delivery_destination_arn,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

An optional list of key-value pairs to associate with the resource.

For more information about tagging, see [Tagging Amazon Web Services resources]

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html



794
795
796
797
798
799
800
801
802
803
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 794

class CreateDeliveryRequest < Struct.new(
  :delivery_source_name,
  :delivery_destination_arn,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end