Class: Aws::CloudWatchLogs::Types::CreateExportTaskRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::CreateExportTaskRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
When making an API call, you may pass CreateExportTaskRequest data as a hash:
{
task_name: "ExportTaskName",
log_group_name: "LogGroupName", # required
log_stream_name_prefix: "LogStreamName",
from: 1, # required
to: 1, # required
destination: "ExportDestinationBucket", # required
destination_prefix: "ExportDestinationPrefix",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
The name of S3 bucket for the exported log data.
-
#destination_prefix ⇒ String
The prefix used as the start of the key for every object exported.
-
#from ⇒ Integer
The start time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
-
#log_group_name ⇒ String
The name of the log group.
-
#log_stream_name_prefix ⇒ String
Export only log streams that match the provided prefix.
-
#task_name ⇒ String
The name of the export task.
-
#to ⇒ Integer
The end time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Instance Attribute Details
#destination ⇒ String
The name of S3 bucket for the exported log data. The bucket must be in the same Amazon Web Services region.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |
#destination_prefix ⇒ String
The prefix used as the start of the key for every object exported. If you don't specify a value, the default is `exportedlogs`.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |
#from ⇒ Integer
The start time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp earlier than this time are not exported.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefix ⇒ String
Export only log streams that match the provided prefix. If you don't specify a value, no prefix filter is applied.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |
#task_name ⇒ String
The name of the export task.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |
#to ⇒ Integer
The end time of the range for the request, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp later than this time are not exported.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 115 class CreateExportTaskRequest < Struct.new( :task_name, :log_group_name, :log_stream_name_prefix, :from, :to, :destination, :destination_prefix) SENSITIVE = [] include Aws::Structure end |