Class: Aws::CloudWatchLogs::Types::CreateLookupTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the lookup table. The description can be up to 1024 characters long.

Returns:

  • (String)


1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1189

class CreateLookupTableRequest < Struct.new(
  :lookup_table_name,
  :description,
  :table_body,
  :query_id,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ARN of the KMS key to use to encrypt the lookup table data. If you don't specify a key, the data is encrypted with an Amazon Web Services-owned key.

Returns:

  • (String)


1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1189

class CreateLookupTableRequest < Struct.new(
  :lookup_table_name,
  :description,
  :table_body,
  :query_id,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#lookup_table_nameString

The name of the lookup table. The name must be unique within your account and Region. The name can contain only alphanumeric characters and underscores, and can be up to 256 characters long.

Returns:

  • (String)


1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1189

class CreateLookupTableRequest < Struct.new(
  :lookup_table_name,
  :description,
  :table_body,
  :query_id,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_idString

The ID of a completed or cancelled CloudWatch Logs query whose results populate the lookup table. A cancelled query populates the table with the partial results that were available when the query was stopped.

You must specify either tableBody or queryId, but not both.

Returns:

  • (String)


1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1189

class CreateLookupTableRequest < Struct.new(
  :lookup_table_name,
  :description,
  :table_body,
  :query_id,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#table_bodyString

The CSV content of the lookup table. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.

You must specify either tableBody or queryId, but not both.

Returns:

  • (String)


1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1189

class CreateLookupTableRequest < Struct.new(
  :lookup_table_name,
  :description,
  :table_body,
  :query_id,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A list of key-value pairs to associate with the lookup table. You can associate as many as 50 tags with a lookup table. Tags can help you organize and categorize your resources.

Returns:

  • (Hash<String,String>)


1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1189

class CreateLookupTableRequest < Struct.new(
  :lookup_table_name,
  :description,
  :table_body,
  :query_id,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end