Class: Aws::CloudWatchLogs::Types::CreateLookupTableResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atInteger

The time when the lookup table was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.

Returns:

  • (Integer)


1209
1210
1211
1212
1213
1214
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1209

class CreateLookupTableResponse < Struct.new(
  :lookup_table_arn,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#lookup_table_arnString

The ARN of the lookup table that was created.

Returns:

  • (String)


1209
1210
1211
1212
1213
1214
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1209

class CreateLookupTableResponse < Struct.new(
  :lookup_table_arn,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end