Class: Aws::CloudWatchLogs::Types::CreateScheduledQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An optional description for the scheduled query to help identify its purpose and functionality.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configurationTypes::DestinationConfiguration

Configuration for where to deliver query results. Supports Amazon S3 destinations for storing query output and lookup table destinations for automatically refreshing lookup tables with query results. You can configure one or both destination types.



1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#end_time_offsetInteger

The time offset in seconds that defines the end of the lookback period for the query. Together with startTimeOffset, this determines the time window relative to the execution time over which the query runs.

Returns:

  • (Integer)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The ARN of the IAM role that grants permissions to execute the query and deliver results to the specified destination. The role must have permissions to read from the specified log groups and write to the destination.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

An array of log group names or ARNs to query. You can specify between 1 and 50 log groups. Log groups can be identified by name or full ARN.

Returns:

  • (Array<String>)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the scheduled query. The name must be unique within your account and region. Length must be between 1 and 300 characters.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_languageString

The query language to use for the scheduled query. Valid values are CWLI, PPL, and SQL.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The query string to execute. This is the same query syntax used in CloudWatch Logs Insights. Maximum length is 10,000 characters.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_end_timeInteger

The end time for the scheduled query in Unix epoch format. The query will stop executing after this time.

Returns:

  • (Integer)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expressionString

A cron expression that defines when the scheduled query runs. The expression uses standard cron syntax and supports minute-level precision. Maximum length is 256 characters.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_start_timeInteger

The start time for the scheduled query in Unix epoch format. The query will not execute before this time.

Returns:

  • (Integer)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_offsetInteger

The time offset in seconds that defines the lookback period for the query. This determines how far back in time the query searches from the execution time.

Returns:

  • (Integer)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The initial state of the scheduled query. Valid values are ENABLED and DISABLED. Default is ENABLED.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Key-value pairs to associate with the scheduled query for resource management and cost allocation.

Returns:

  • (Hash<String,String>)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#timezoneString

The timezone for evaluating the schedule expression. This determines when the scheduled query executes relative to the specified timezone.

Returns:

  • (String)


1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1303

class CreateScheduledQueryRequest < Struct.new(
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end