Class: Aws::CloudWatchLogs::Types::DataSourceFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Filter criteria for data sources, used to specify which data sources to include in operations based on name and type.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name pattern to filter data sources by.

Returns:

  • (String)


1289
1290
1291
1292
1293
1294
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1289

class DataSourceFilter < Struct.new(
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type pattern to filter data sources by.

Returns:

  • (String)


1289
1290
1291
1292
1293
1294
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1289

class DataSourceFilter < Struct.new(
  :name,
  :type)
  SENSITIVE = []
  include Aws::Structure
end