Class: Aws::CloudWatchLogs::Types::DeleteDataProtectionPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DeleteDataProtectionPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass DeleteDataProtectionPolicyRequest data as a hash:
{
log_group_identifier: "LogGroupIdentifier", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_identifier ⇒ String
The name or ARN of the log group that you want to delete the data protection policy for.
Instance Attribute Details
#log_group_identifier ⇒ String
The name or ARN of the log group that you want to delete the data protection policy for.
242 243 244 245 246 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 242 class DeleteDataProtectionPolicyRequest < Struct.new( :log_group_identifier) SENSITIVE = [] include Aws::Structure end |