Class: Aws::CloudWatchLogs::Types::DeleteIntegrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#forceBoolean

Specify true to force the deletion of the integration even if vended logs dashboards currently exist.

The default is false.

Returns:

  • (Boolean)


1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1492

class DeleteIntegrationRequest < Struct.new(
  :integration_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration to delete. To find the name of your integration, use [ListIntegrations].

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListIntegrations.html

Returns:

  • (String)


1492
1493
1494
1495
1496
1497
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1492

class DeleteIntegrationRequest < Struct.new(
  :integration_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end