Class: Aws::CloudWatchLogs::Types::DeleteSyslogConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DeleteSyslogConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_identifier ⇒ String
The name or ARN of the log group to remove the syslog configuration from.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint associated with the syslog configuration to delete.
Instance Attribute Details
#log_group_identifier ⇒ String
The name or ARN of the log group to remove the syslog configuration from.
1804 1805 1806 1807 1808 1809 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1804 class DeleteSyslogConfigurationRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint associated with the syslog configuration to delete.
1804 1805 1806 1807 1808 1809 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1804 class DeleteSyslogConfigurationRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |