Class: Aws::CloudWatchLogs::Types::Delivery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains information about one delivery in your account.

A delivery is a connection between a logical delivery source and a logical delivery destination.

For more information, see CreateDelivery.

To update an existing delivery configuration, use UpdateDeliveryConfiguration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) that uniquely identifies this delivery.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_destination_arnString

The ARN of the delivery destination that is associated with this delivery.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_destination_typeString

Displays whether the delivery destination associated with this delivery is CloudWatch Logs, Amazon S3, Firehose, or X-Ray.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#delivery_source_nameString

The name of the delivery source that is associated with this delivery.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#field_delimiterString

The field delimiter that is used between record fields when the final output format of a delivery is in Plain, W3C, or Raw format.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique ID that identifies this delivery in your account.

Returns:

  • (String)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#record_fieldsArray<String>

The record fields used in this delivery.

Returns:

  • (Array<String>)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#s3_delivery_configurationTypes::S3DeliveryConfiguration

This structure contains delivery configurations that apply only when the delivery destination resource is an S3 bucket.



1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that have been assigned to this delivery.

Returns:

  • (Hash<String,String>)


1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1898

class Delivery < Struct.new(
  :id,
  :arn,
  :delivery_source_name,
  :delivery_destination_arn,
  :delivery_destination_type,
  :record_fields,
  :field_delimiter,
  :s3_delivery_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end