Class: Aws::CloudWatchLogs::Types::DeliverySourceConfigurationSchema

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

A structure that describes a single configuration for a log type, including its name, value type, default value, and the range of supported values.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_valueString

The default value of the configuration that is used when a value is not specified in a PutDeliverySource request.

Returns:

  • (String)


2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2147

class DeliverySourceConfigurationSchema < Struct.new(
  :key_name,
  :value_type,
  :default_value,
  :supported_values,
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#key_nameString

The name of the configuration.

Returns:

  • (String)


2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2147

class DeliverySourceConfigurationSchema < Struct.new(
  :key_name,
  :value_type,
  :default_value,
  :supported_values,
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#max_valueFloat

The maximum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

Returns:

  • (Float)


2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2147

class DeliverySourceConfigurationSchema < Struct.new(
  :key_name,
  :value_type,
  :default_value,
  :supported_values,
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#min_valueFloat

The minimum numeric value allowed for the configuration. This applies only when the valueType is a numeric type.

Returns:

  • (Float)


2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2147

class DeliverySourceConfigurationSchema < Struct.new(
  :key_name,
  :value_type,
  :default_value,
  :supported_values,
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#supported_valuesArray<String>

The list of allowed values for the configuration. Empty for free-form configuration.

Returns:

  • (Array<String>)


2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2147

class DeliverySourceConfigurationSchema < Struct.new(
  :key_name,
  :value_type,
  :default_value,
  :supported_values,
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end

#value_typeString

The data type of the configuration value. Valid values are string, boolean, int, double, and long.

Returns:

  • (String)


2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2147

class DeliverySourceConfigurationSchema < Struct.new(
  :key_name,
  :value_type,
  :default_value,
  :supported_values,
  :min_value,
  :max_value)
  SENSITIVE = []
  include Aws::Structure
end