Class: Aws::CloudWatchLogs::Types::DescribeAccountPoliciesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_identifiersArray<String>

If you are using an account that is set up as a monitoring account for CloudWatch unified cross-account observability, you can use this to specify the account ID of a source account. If you do, the operation returns the account policy for the specified account. Currently, you can specify only one account ID in this parameter.

If you omit this parameter, only the policy in the current account is returned.

Returns:

  • (Array<String>)


2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2186

class DescribeAccountPoliciesRequest < Struct.new(
  :policy_type,
  :policy_name,
  :account_identifiers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2186

class DescribeAccountPoliciesRequest < Struct.new(
  :policy_type,
  :policy_name,
  :account_identifiers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#policy_nameString

Use this parameter to limit the returned policies to only the policy with the name that you specify.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2186

class DescribeAccountPoliciesRequest < Struct.new(
  :policy_type,
  :policy_name,
  :account_identifiers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#policy_typeString

Use this parameter to limit the returned policies to only the policies that match the policy type that you specify.

Returns:

  • (String)


2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2186

class DescribeAccountPoliciesRequest < Struct.new(
  :policy_type,
  :policy_name,
  :account_identifiers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end