Class: Aws::CloudWatchLogs::Types::DescribeConfigurationTemplatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delivery_destination_typesArray<String>

Use this parameter to filter the response to include only the configuration templates that apply to the delivery destination types that you specify here.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2047

class DescribeConfigurationTemplatesRequest < Struct.new(
  :service,
  :log_types,
  :resource_types,
  :delivery_destination_types,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

Use this parameter to limit the number of configuration templates that are returned in the response.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2047

class DescribeConfigurationTemplatesRequest < Struct.new(
  :service,
  :log_types,
  :resource_types,
  :delivery_destination_types,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#log_typesArray<String>

Use this parameter to filter the response to include only the configuration templates that apply to the log types that you specify here.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2047

class DescribeConfigurationTemplatesRequest < Struct.new(
  :service,
  :log_types,
  :resource_types,
  :delivery_destination_types,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 24 hours.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2047

class DescribeConfigurationTemplatesRequest < Struct.new(
  :service,
  :log_types,
  :resource_types,
  :delivery_destination_types,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typesArray<String>

Use this parameter to filter the response to include only the configuration templates that apply to the resource types that you specify here.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2047

class DescribeConfigurationTemplatesRequest < Struct.new(
  :service,
  :log_types,
  :resource_types,
  :delivery_destination_types,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#serviceString

Use this parameter to filter the response to include only the configuration templates that apply to the Amazon Web Services service that you specify here.



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2047

class DescribeConfigurationTemplatesRequest < Struct.new(
  :service,
  :log_types,
  :resource_types,
  :delivery_destination_types,
  :next_token,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end