Class: Aws::CloudWatchLogs::Types::DescribeDestinationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeDestinationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass DescribeDestinationsRequest data as a hash:
{
destination_name_prefix: "DestinationName",
next_token: "NextToken",
limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_name_prefix ⇒ String
The prefix to match.
-
#limit ⇒ Integer
The maximum number of items returned.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#destination_name_prefix ⇒ String
The prefix to match. If you don't specify a value, no prefix filter is applied.
444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 444 class DescribeDestinationsRequest < Struct.new( :destination_name_prefix, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of items returned. If you don't specify a value, the default maximum value of 50 items is used.
444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 444 class DescribeDestinationsRequest < Struct.new( :destination_name_prefix, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
444 445 446 447 448 449 450 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 444 class DescribeDestinationsRequest < Struct.new( :destination_name_prefix, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |