Class: Aws::CloudWatchLogs::Types::DescribeExportTasksRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeExportTasksRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass DescribeExportTasksRequest data as a hash:
{
task_id: "ExportTaskId",
status_code: "CANCELLED", # accepts CANCELLED, COMPLETED, FAILED, PENDING, PENDING_CANCEL, RUNNING
next_token: "NextToken",
limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of items returned.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#status_code ⇒ String
The status code of the export task.
-
#task_id ⇒ String
The ID of the export task.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.
499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 499 class DescribeExportTasksRequest < Struct.new( :task_id, :status_code, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 499 class DescribeExportTasksRequest < Struct.new( :task_id, :status_code, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ String
The status code of the export task. Specifying a status code filters the results to zero or more export tasks.
499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 499 class DescribeExportTasksRequest < Struct.new( :task_id, :status_code, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#task_id ⇒ String
The ID of the export task. Specifying a task ID filters the results to zero or one export tasks.
499 500 501 502 503 504 505 506 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 499 class DescribeExportTasksRequest < Struct.new( :task_id, :status_code, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |