Class: Aws::CloudWatchLogs::Types::DescribeFieldIndexesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#index_categoriesArray<String>

The index categories to return. The following values are supported:

  • DEFAULT: Fields that CloudWatch Logs indexes by default. Examples include @logStream and @data_format.

  • CUSTOM: Fields that you added manually to the field index policy. CloudWatch Logs always indexes these fields. These fields count toward the quota of 20 fields for each log group.

  • AUTO: Fields that CloudWatch Logs indexes automatically based on your query patterns and usage. These fields do not count toward the field index quota. CloudWatch Logs might update these fields based on changes in your query patterns. To keep a field indexed permanently, add it to an account-level or log-group level field index policy.

  • INACTIVE: Fields that CloudWatch Logs indexed before but does not index now. This happens if you remove a field from the field index policy or if CloudWatch Logs automatically selects a different field based on your queries.

If you omit this parameter, the response includes the DEFAULT, CUSTOM, and INACTIVE categories.

For more information about automatically indexed fields and using the AUTO category, see Automatically indexed fields.

Returns:

  • (Array<String>)


2533
2534
2535
2536
2537
2538
2539
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2533

class DescribeFieldIndexesRequest < Struct.new(
  :log_group_identifiers,
  :index_categories,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

An array containing the names or ARNs of the log groups that you want to retrieve field indexes for.

Returns:

  • (Array<String>)


2533
2534
2535
2536
2537
2538
2539
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2533

class DescribeFieldIndexesRequest < Struct.new(
  :log_group_identifiers,
  :index_categories,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 24 hours.

Returns:

  • (String)


2533
2534
2535
2536
2537
2538
2539
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2533

class DescribeFieldIndexesRequest < Struct.new(
  :log_group_identifiers,
  :index_categories,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end