Class: Aws::CloudWatchLogs::Types::DescribeImportTaskBatchesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeImportTaskBatchesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#batch_import_status ⇒ Array<String>
Optional filter to list import batches by their status.
-
#import_id ⇒ String
The ID of the import task to get batch information for.
-
#limit ⇒ Integer
The maximum number of import batches to return in the response.
-
#next_token ⇒ String
The pagination token for the next set of results.
Instance Attribute Details
#batch_import_status ⇒ Array<String>
Optional filter to list import batches by their status. Accepts multiple status values: IN_PROGRESS, CANCELLED, COMPLETED and FAILED.
2419 2420 2421 2422 2423 2424 2425 2426 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2419 class DescribeImportTaskBatchesRequest < Struct.new( :import_id, :batch_import_status, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The ID of the import task to get batch information for.
2419 2420 2421 2422 2423 2424 2425 2426 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2419 class DescribeImportTaskBatchesRequest < Struct.new( :import_id, :batch_import_status, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of import batches to return in the response. Default: 10
2419 2420 2421 2422 2423 2424 2425 2426 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2419 class DescribeImportTaskBatchesRequest < Struct.new( :import_id, :batch_import_status, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the next set of results.
2419 2420 2421 2422 2423 2424 2425 2426 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2419 class DescribeImportTaskBatchesRequest < Struct.new( :import_id, :batch_import_status, :limit, :next_token) SENSITIVE = [] include Aws::Structure end |