Class: Aws::CloudWatchLogs::Types::DescribeImportTasksResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#importsArray<Types::Import>

The list of import tasks that match the request filters.

Returns:



2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2589

class DescribeImportTasksResponse < Struct.new(
  :imports,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token to use when requesting the next set of results. Not present if there are no additional results to retrieve.

Returns:

  • (String)


2589
2590
2591
2592
2593
2594
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2589

class DescribeImportTasksResponse < Struct.new(
  :imports,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end