Class: Aws::CloudWatchLogs::Types::DescribeLogGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeLogGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_identifiers ⇒ Array<String>
When ‘includeLinkedAccounts` is set to `True`, use this parameter to specify the list of accounts to search.
-
#include_linked_accounts ⇒ Boolean
If you are using a monitoring account, set this to ‘True` to have the operation return log groups in the accounts listed in `accountIdentifiers`.
-
#limit ⇒ Integer
The maximum number of items returned.
-
#log_group_name_pattern ⇒ String
If you specify a string for this parameter, the operation returns only log groups that have names that match the string based on a case-sensitive substring search.
-
#log_group_name_prefix ⇒ String
The prefix to match.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#account_identifiers ⇒ Array<String>
When ‘includeLinkedAccounts` is set to `True`, use this parameter to specify the list of accounts to search. You can specify as many as 20 account IDs in the array.
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 481 class DescribeLogGroupsRequest < Struct.new( :account_identifiers, :log_group_name_prefix, :log_group_name_pattern, :next_token, :limit, :include_linked_accounts) SENSITIVE = [] include Aws::Structure end |
#include_linked_accounts ⇒ Boolean
If you are using a monitoring account, set this to ‘True` to have the operation return log groups in the accounts listed in `accountIdentifiers`.
If this parameter is set to ‘true` and `accountIdentifiers` contains a null value, the operation returns all log groups in the monitoring account and all log groups in all source accounts that are linked to the monitoring account.
<note markdown=“1”> If you specify ‘includeLinkedAccounts` in your request, then `metricFilterCount`, `retentionInDays`, and `storedBytes` are not included in the response.
</note>
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 481 class DescribeLogGroupsRequest < Struct.new( :account_identifiers, :log_group_name_prefix, :log_group_name_pattern, :next_token, :limit, :include_linked_accounts) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of items returned. If you don’t specify a value, the default is up to 50 items.
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 481 class DescribeLogGroupsRequest < Struct.new( :account_identifiers, :log_group_name_prefix, :log_group_name_pattern, :next_token, :limit, :include_linked_accounts) SENSITIVE = [] include Aws::Structure end |
#log_group_name_pattern ⇒ String
If you specify a string for this parameter, the operation returns only log groups that have names that match the string based on a case-sensitive substring search. For example, if you specify ‘Foo`, log groups named `FooBar`, `aws/Foo`, and `GroupFoo` would match, but `foo`, `F/o/o` and `Froo` would not match.
<note markdown=“1”> ‘logGroupNamePattern` and `logGroupNamePrefix` are mutually exclusive. Only one of these parameters can be passed.
</note>
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 481 class DescribeLogGroupsRequest < Struct.new( :account_identifiers, :log_group_name_prefix, :log_group_name_pattern, :next_token, :limit, :include_linked_accounts) SENSITIVE = [] include Aws::Structure end |
#log_group_name_prefix ⇒ String
The prefix to match.
<note markdown=“1”> ‘logGroupNamePrefix` and `logGroupNamePattern` are mutually exclusive. Only one of these parameters can be passed.
</note>
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 481 class DescribeLogGroupsRequest < Struct.new( :account_identifiers, :log_group_name_prefix, :log_group_name_pattern, :next_token, :limit, :include_linked_accounts) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
481 482 483 484 485 486 487 488 489 490 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 481 class DescribeLogGroupsRequest < Struct.new( :account_identifiers, :log_group_name_prefix, :log_group_name_pattern, :next_token, :limit, :include_linked_accounts) SENSITIVE = [] include Aws::Structure end |