Class: Aws::CloudWatchLogs::Types::DescribeLogStreamsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeLogStreamsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
When making an API call, you may pass DescribeLogStreamsRequest data as a hash:
{
log_group_name: "LogGroupName", # required
log_stream_name_prefix: "LogStreamName",
order_by: "LogStreamName", # accepts LogStreamName, LastEventTime
descending: false,
next_token: "NextToken",
limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#descending ⇒ Boolean
If the value is true, results are returned in descending order.
-
#limit ⇒ Integer
The maximum number of items returned.
-
#log_group_name ⇒ String
The name of the log group.
-
#log_stream_name_prefix ⇒ String
The prefix to match.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#order_by ⇒ String
If the value is `LogStreamName`, the results are ordered by log stream name.
Instance Attribute Details
#descending ⇒ Boolean
If the value is true, results are returned in descending order. If the value is to false, results are returned in ascending order. The default value is false.
636 637 638 639 640 641 642 643 644 645 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 636 class DescribeLogStreamsRequest < Struct.new( :log_group_name, :log_stream_name_prefix, :order_by, :descending, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.
636 637 638 639 640 641 642 643 644 645 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 636 class DescribeLogStreamsRequest < Struct.new( :log_group_name, :log_stream_name_prefix, :order_by, :descending, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
636 637 638 639 640 641 642 643 644 645 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 636 class DescribeLogStreamsRequest < Struct.new( :log_group_name, :log_stream_name_prefix, :order_by, :descending, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefix ⇒ String
The prefix to match.
If `orderBy` is `LastEventTime`, you cannot specify this parameter.
636 637 638 639 640 641 642 643 644 645 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 636 class DescribeLogStreamsRequest < Struct.new( :log_group_name, :log_stream_name_prefix, :order_by, :descending, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
636 637 638 639 640 641 642 643 644 645 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 636 class DescribeLogStreamsRequest < Struct.new( :log_group_name, :log_stream_name_prefix, :order_by, :descending, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#order_by ⇒ String
If the value is `LogStreamName`, the results are ordered by log stream name. If the value is `LastEventTime`, the results are ordered by the event time. The default value is `LogStreamName`.
If you order the results by event time, you cannot specify the `logStreamNamePrefix` parameter.
`lastEventTimestamp` represents the time of the most recent log event in the log stream in CloudWatch Logs. This number is expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. `lastEventTimestamp` updates on an eventual consistency basis. It typically updates in less than an hour from ingestion, but in rare situations might take longer.
636 637 638 639 640 641 642 643 644 645 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 636 class DescribeLogStreamsRequest < Struct.new( :log_group_name, :log_stream_name_prefix, :order_by, :descending, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |