Class: Aws::CloudWatchLogs::Types::DescribeLookupTablesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeLookupTablesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lookup_table_name_prefix ⇒ String
A prefix to filter lookup tables by name.
-
#max_results ⇒ Integer
The maximum number of lookup tables to return in the response.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#lookup_table_name_prefix ⇒ String
A prefix to filter lookup tables by name. Only tables whose names start with this prefix are returned. If you don’t specify a prefix, all tables in the account and Region are returned.
2876 2877 2878 2879 2880 2881 2882 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2876 class DescribeLookupTablesRequest < Struct.new( :lookup_table_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of lookup tables to return in the response. The default value is 50 and the maximum value is 100.
2876 2877 2878 2879 2880 2881 2882 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2876 class DescribeLookupTablesRequest < Struct.new( :lookup_table_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
2876 2877 2878 2879 2880 2881 2882 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2876 class DescribeLookupTablesRequest < Struct.new( :lookup_table_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |