Class: Aws::CloudWatchLogs::Types::DescribeQueryDefinitionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

Limits the number of returned query definitions to the specified number.



2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2831

class DescribeQueryDefinitionsRequest < Struct.new(
  :query_language,
  :query_definition_name_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 24 hours.



2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2831

class DescribeQueryDefinitionsRequest < Struct.new(
  :query_language,
  :query_definition_name_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#query_definition_name_prefixString

Use this parameter to filter your results to only the query definitions that have names that start with the prefix you specify.



2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2831

class DescribeQueryDefinitionsRequest < Struct.new(
  :query_language,
  :query_definition_name_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#query_languageString

The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see [Supported query languages].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData_Languages.html



2831
2832
2833
2834
2835
2836
2837
2838
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2831

class DescribeQueryDefinitionsRequest < Struct.new(
  :query_language,
  :query_definition_name_prefix,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end