Class: Aws::CloudWatchLogs::Types::DescribeResourcePoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeResourcePoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass DescribeResourcePoliciesRequest data as a hash:
{
next_token: "NextToken",
limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of resource policies to be displayed with one call of this API.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of resource policies to be displayed with one call of this API.
871 872 873 874 875 876 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 871 class DescribeResourcePoliciesRequest < Struct.new( :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
871 872 873 874 875 876 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 871 class DescribeResourcePoliciesRequest < Struct.new( :next_token, :limit) SENSITIVE = [] include Aws::Structure end |