Class: Aws::CloudWatchLogs::Types::DestinationConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Configuration for where to deliver scheduled query results. Specifies the destination type and associated settings for result delivery.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lookup_table_configurationTypes::LookupTableConfiguration

Configuration for delivering query results to a lookup table. The query results automatically populate or refresh the specified lookup table on each scheduled execution.



3261
3262
3263
3264
3265
3266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3261

class DestinationConfiguration < Struct.new(
  :s3_configuration,
  :lookup_table_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#s3_configurationTypes::S3Configuration

Configuration for delivering query results to Amazon S3.



3261
3262
3263
3264
3265
3266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3261

class DestinationConfiguration < Struct.new(
  :s3_configuration,
  :lookup_table_configuration)
  SENSITIVE = []
  include Aws::Structure
end