Class: Aws::CloudWatchLogs::Types::DisassociateKmsKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DisassociateKmsKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_name ⇒ String
The name of the log group.
-
#resource_identifier ⇒ String
Specifies the target for this operation.
Instance Attribute Details
#log_group_name ⇒ String
The name of the log group.
In your DisassociateKmsKey operation, you must specify either the
resourceIdentifier parameter or the logGroup parameter, but you
can't specify both.
3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3307 class DisassociateKmsKeyRequest < Struct.new( :log_group_name, :resource_identifier) SENSITIVE = [] include Aws::Structure end |
#resource_identifier ⇒ String
Specifies the target for this operation. You must specify one of the following:
-
Specify the ARN of a log group to stop having CloudWatch Logs use the KMS key to encrypt log events that are ingested and stored by that log group. After you run this operation, CloudWatch Logs encrypts ingested log events with the default CloudWatch Logs method. The log group ARN must be in the following format. Replace REGION and ACCOUNT_ID with your Region and account ID.
arn:aws:logs:REGION:ACCOUNT_ID:log-group:LOG_GROUP_NAME -
Specify the following ARN to stop using this key to encrypt the results of future StartQuery operations in this account. Replace REGION and ACCOUNT_ID with your Region and account ID.
arn:aws:logs:REGION:ACCOUNT_ID:query-result:*
In your DisssociateKmsKey operation, you must specify either the
resourceIdentifier parameter or the logGroup parameter, but you
can't specify both.
3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3307 class DisassociateKmsKeyRequest < Struct.new( :log_group_name, :resource_identifier) SENSITIVE = [] include Aws::Structure end |