Class: Aws::CloudWatchLogs::Types::Entity

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

The entity associated with the log events in a PutLogEvents call.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesHash<String,String>

Additional attributes of the entity that are not used to specify the identity of the entity. A list of key-value pairs.

For details about how to use the attributes, see How to add related information to telemetry in the CloudWatch User Guide.



3407
3408
3409
3410
3411
3412
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3407

class Entity < Struct.new(
  :key_attributes,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end

#key_attributesHash<String,String>

The attributes of the entity which identify the specific entity, as a list of key-value pairs. Entities with the same keyAttributes are considered to be the same entity.

There are five allowed attributes (key names): Type, ResourceType, Identifier Name, and Environment.

For details about how to use the key attributes, see How to add related information to telemetry in the CloudWatch User Guide.



3407
3408
3409
3410
3411
3412
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3407

class Entity < Struct.new(
  :key_attributes,
  :attributes)
  SENSITIVE = []
  include Aws::Structure
end