Class: Aws::CloudWatchLogs::Types::FilterLogEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::FilterLogEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
The end of the time range, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#filter_pattern ⇒ String
The filter pattern to use.
-
#interleaved ⇒ Boolean
If the value is true, the operation attempts to provide responses that contain events from multiple log streams within the log group, interleaved in a single response.
-
#limit ⇒ Integer
The maximum number of events to return.
-
#log_group_identifier ⇒ String
Specify either the name or ARN of the log group to view log events from.
-
#log_group_name ⇒ String
The name of the log group to search.
-
#log_stream_name_prefix ⇒ String
Filters the results to include only events from log streams that have names starting with this prefix.
-
#log_stream_names ⇒ Array<String>
Filters the results to only logs from the log streams in this list.
-
#next_token ⇒ String
The token for the next set of events to return.
-
#start_time ⇒ Integer
The start of the time range, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#unmask ⇒ Boolean
Specify
trueto display the log event fields with all sensitive data unmasked and visible.
Instance Attribute Details
#end_time ⇒ Integer
The end of the time range, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`. Events with a timestamp later than this time are not returned.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#filter_pattern ⇒ String
The filter pattern to use. For more information, see [Filter and Pattern Syntax].
If not provided, all the events are matched.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#interleaved ⇒ Boolean
If the value is true, the operation attempts to provide responses that contain events from multiple log streams within the log group, interleaved in a single response. If the value is false, all the matched log events in the first log stream are searched first, then those in the next log stream, and so on.
Important As of June 17, 2019, this parameter is ignored and the value is assumed to be true. The response from this operation always interleaves events from multiple log streams within a log group.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of events to return. The default is 10,000 events.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_group_identifier ⇒ String
Specify either the name or ARN of the log group to view log events from. If the log group is in a source account and you are using a monitoring account, you must use the log group ARN.
<note markdown=“1”> You must include either logGroupIdentifier or logGroupName, but not both.
</note>
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group to search.
<note markdown=“1”> You must include either logGroupIdentifier or logGroupName, but not both.
</note>
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefix ⇒ String
Filters the results to include only events from log streams that have names starting with this prefix.
If you specify a value for both logStreamNamePrefix and logStreamNames, the action returns an InvalidParameterException error.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_stream_names ⇒ Array<String>
Filters the results to only logs from the log streams in this list.
If you specify a value for both logStreamNames and logStreamNamePrefix, the action returns an InvalidParameterException error.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of events to return. (You received this token from a previous call.)
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Integer
The start of the time range, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`. Events with a timestamp before this time are not returned.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |
#unmask ⇒ Boolean
Specify true to display the log event fields with all sensitive data unmasked and visible. The default is false.
To use this operation with this parameter, you must be signed into an account with the logs:Unmask permission.
3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3381 class FilterLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_names, :log_stream_name_prefix, :start_time, :end_time, :filter_pattern, :next_token, :limit, :interleaved, :unmask) SENSITIVE = [] include Aws::Structure end |