Class: Aws::CloudWatchLogs::Types::GetDataProtectionPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetDataProtectionPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass GetDataProtectionPolicyRequest data as a hash:
{
log_group_identifier: "LogGroupIdentifier", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_identifier ⇒ String
The name or ARN of the log group that contains the data protection policy that you want to see.
Instance Attribute Details
#log_group_identifier ⇒ String
The name or ARN of the log group that contains the data protection policy that you want to see.
1406 1407 1408 1409 1410 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1406 class GetDataProtectionPolicyRequest < Struct.new( :log_group_identifier) SENSITIVE = [] include Aws::Structure end |