Class: Aws::CloudWatchLogs::Types::GetIntegrationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetIntegrationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_details ⇒ Types::IntegrationDetails
A structure that contains information about the integration configuration.
-
#integration_name ⇒ String
The name of the integration.
-
#integration_status ⇒ String
The current status of this integration.
-
#integration_type ⇒ String
The type of integration.
Instance Attribute Details
#integration_details ⇒ Types::IntegrationDetails
A structure that contains information about the integration configuration. For an integration with OpenSearch Service, this includes information about OpenSearch Service resources such as the collection, the workspace, and policies.
3909 3910 3911 3912 3913 3914 3915 3916 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3909 class GetIntegrationResponse < Struct.new( :integration_name, :integration_type, :integration_status, :integration_details) SENSITIVE = [] include Aws::Structure end |
#integration_name ⇒ String
The name of the integration.
3909 3910 3911 3912 3913 3914 3915 3916 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3909 class GetIntegrationResponse < Struct.new( :integration_name, :integration_type, :integration_status, :integration_details) SENSITIVE = [] include Aws::Structure end |
#integration_status ⇒ String
The current status of this integration.
3909 3910 3911 3912 3913 3914 3915 3916 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3909 class GetIntegrationResponse < Struct.new( :integration_name, :integration_type, :integration_status, :integration_details) SENSITIVE = [] include Aws::Structure end |
#integration_type ⇒ String
The type of integration. Integrations with OpenSearch Service have
the type OPENSEARCH.
3909 3910 3911 3912 3913 3914 3915 3916 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3909 class GetIntegrationResponse < Struct.new( :integration_name, :integration_type, :integration_status, :integration_details) SENSITIVE = [] include Aws::Structure end |