Class: Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector to retrieve information about.
Instance Attribute Details
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector to retrieve information about. You can find the ARNs of log anomaly detectors in your account by using the ListLogAnomalyDetectors operation.
4002 4003 4004 4005 4006 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4002 class GetLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn) SENSITIVE = [] include Aws::Structure end |