Class: Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anomaly_detector_statusString

Specifies whether the anomaly detector is currently active. To change its status, use the enabled parameter in the UpdateLogAnomalyDetector operation.

Returns:

  • (String)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#anomaly_visibility_timeInteger

The number of days used as the life cycle of anomalies. After this time, anomalies are automatically baselined and the anomaly detector model will treat new occurrences of similar event as normal.

Returns:

  • (Integer)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_time_stampInteger

The date and time when this anomaly detector was created.

Returns:

  • (Integer)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#detector_nameString

The name of the log anomaly detector

Returns:

  • (String)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_frequencyString

Specifies how often the anomaly detector runs and look for anomalies. Set this value according to the frequency that the log group receives new logs. For example, if the log group receives new log events every 10 minutes, then setting evaluationFrequency to FIFTEEN_MIN might be appropriate.

Returns:

  • (String)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#filter_patternString

A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.

Returns:

  • (String)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ARN of the KMS key assigned to this anomaly detector, if any.

Returns:

  • (String)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time_stampInteger

The date and time when this anomaly detector was most recently modified.

Returns:

  • (Integer)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_arn_listArray<String>

An array of structures, where each structure contains the ARN of a log group associated with this anomaly detector.

Returns:

  • (Array<String>)


4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
4074
4075
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4063

class GetLogAnomalyDetectorResponse < Struct.new(
  :detector_name,
  :log_group_arn_list,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_detector_status,
  :kms_key_id,
  :creation_time_stamp,
  :last_modified_time_stamp,
  :anomaly_visibility_time)
  SENSITIVE = []
  include Aws::Structure
end