Class: Aws::CloudWatchLogs::Types::GetQueryResultsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_itemsInteger

The maximum number of log events to return in the response. The maximum is 10,000 log events.

Returns:

  • (Integer)


4194
4195
4196
4197
4198
4199
4200
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4194

class GetQueryResultsRequest < Struct.new(
  :query_id,
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 1 hour.

Returns:

  • (String)


4194
4195
4196
4197
4198
4199
4200
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4194

class GetQueryResultsRequest < Struct.new(
  :query_id,
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#query_idString

The ID number of the query.

Returns:

  • (String)


4194
4195
4196
4197
4198
4199
4200
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4194

class GetQueryResultsRequest < Struct.new(
  :query_id,
  :next_token,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end