Class: Aws::CloudWatchLogs::Types::Grok

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This processor uses pattern matching to parse and structure unstructured data. This processor can also extract fields from log messages.

For more information about this processor including examples, see

grok][1

in the *CloudWatch Logs User Guide*.

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-Grok

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#matchString

The grok pattern to match against the log event. For a list of supported grok patterns, see [Supported grok patterns].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#Grok-Patterns

Returns:

  • (String)


4117
4118
4119
4120
4121
4122
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4117

class Grok < Struct.new(
  :source,
  :match)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The path to the field in the log event that you want to parse. If you omit this value, the whole log message is parsed.

Returns:

  • (String)


4117
4118
4119
4120
4121
4122
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4117

class Grok < Struct.new(
  :source,
  :match)
  SENSITIVE = []
  include Aws::Structure
end