Class: Aws::CloudWatchLogs::Types::Import
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::Import
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
An import job to move data from CloudTrail Event Data Store to CloudWatch.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Integer
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
-
#error_message ⇒ String
Error message related to any failed imports.
-
#import_destination_arn ⇒ String
The ARN of the managed CloudWatch Logs log group where the events are being imported to.
-
#import_filter ⇒ Types::ImportFilter
The filter criteria used for this import task.
-
#import_id ⇒ String
The unique identifier of the import task.
-
#import_source_arn ⇒ String
The ARN of the CloudTrail Lake Event Data Store being imported from.
-
#import_statistics ⇒ Types::ImportStatistics
Statistics about the import progress.
-
#import_status ⇒ String
The current status of the import task.
-
#last_updated_time ⇒ Integer
The timestamp when the import task was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Instance Attribute Details
#creation_time ⇒ Integer
The timestamp when the import task was created, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
Error message related to any failed imports
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#import_destination_arn ⇒ String
The ARN of the managed CloudWatch Logs log group where the events are being imported to.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#import_filter ⇒ Types::ImportFilter
The filter criteria used for this import task.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#import_id ⇒ String
The unique identifier of the import task.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#import_source_arn ⇒ String
The ARN of the CloudTrail Lake Event Data Store being imported from.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#import_statistics ⇒ Types::ImportStatistics
Statistics about the import progress
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#import_status ⇒ String
The current status of the import task. Valid values are IN_PROGRESS, CANCELLED, COMPLETED and FAILED.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Integer
The timestamp when the import task was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4576 class Import < Struct.new( :import_id, :import_source_arn, :import_status, :import_destination_arn, :import_statistics, :import_filter, :creation_time, :last_updated_time, :error_message) SENSITIVE = [] include Aws::Structure end |