Class: Aws::CloudWatchLogs::Types::InputLogEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::InputLogEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Represents a log event, which is a record of activity that was recorded by the application or resource being monitored.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The raw event message.
-
#timestamp ⇒ Integer
The time the event occurred, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`.
Instance Attribute Details
#message ⇒ String
The raw event message.
1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1466 class InputLogEvent < Struct.new( :timestamp, :message) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Integer
The time the event occurred, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`.
1466 1467 1468 1469 1470 1471 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1466 class InputLogEvent < Struct.new( :timestamp, :message) SENSITIVE = [] include Aws::Structure end |