Class: Aws::CloudWatchLogs::Types::InvalidSequenceTokenException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

The sequence token is not valid. You can get the correct sequence token in the expectedSequenceToken field in the InvalidSequenceTokenException message.

PutLogEvents actions are now always accepted and never return InvalidSequenceTokenException regardless of receiving an invalid sequence token.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_sequence_tokenString

Returns:

  • (String)


5016
5017
5018
5019
5020
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5016

class InvalidSequenceTokenException < Struct.new(
  :expected_sequence_token)
  SENSITIVE = []
  include Aws::Structure
end