Class: Aws::CloudWatchLogs::Types::ListAggregateLogGroupSummariesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregate_log_group_summariesArray<Types::AggregateLogGroupSummary>

The list of aggregate log group summaries grouped by the specified data source characteristics.



4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4747

class ListAggregateLogGroupSummariesResponse < Struct.new(
  :aggregate_log_group_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 24 hours.

Returns:

  • (String)


4747
4748
4749
4750
4751
4752
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4747

class ListAggregateLogGroupSummariesResponse < Struct.new(
  :aggregate_log_group_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end