Class: Aws::CloudWatchLogs::Types::ListAnomaliesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListAnomaliesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomalies ⇒ Array<Types::Anomaly>
An array of structures, where each structure contains information about one anomaly that a log anomaly detector has found.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#anomalies ⇒ Array<Types::Anomaly>
An array of structures, where each structure contains information about one anomaly that a log anomaly detector has found.
4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4798 class ListAnomaliesResponse < Struct.new( :anomalies, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
4798 4799 4800 4801 4802 4803 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4798 class ListAnomaliesResponse < Struct.new( :anomalies, :next_token) SENSITIVE = [] include Aws::Structure end |