Class: Aws::CloudWatchLogs::Types::ListLogGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListLogGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_identifiers ⇒ Array<String>
When
includeLinkedAccountsis set totrue, use this parameter to specify the list of accounts to search. -
#data_sources ⇒ Array<Types::DataSourceFilter>
An array of data source filters to filter log groups by their associated data sources.
-
#field_index_names ⇒ Array<String>
An array of field index names to filter log groups that have specific field indexes.
-
#include_linked_accounts ⇒ Boolean
If you are using a monitoring account, set this to
trueto have the operation return log groups in the accounts listed inaccountIdentifiers. -
#limit ⇒ Integer
The maximum number of log groups to return.
-
#log_group_class ⇒ String
Use this parameter to limit the results to only those log groups in the specified log group class.
-
#log_group_name_pattern ⇒ String
Use this parameter to limit the returned log groups to only those with names that match the pattern that you specify.
-
#log_group_tags ⇒ Array<Types::TagFilter>
An array of tag filters to return only log groups that have specific tags.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#account_identifiers ⇒ Array<String>
When includeLinkedAccounts is set to true, use this parameter to
specify the list of accounts to search. You can specify as many as
20 account IDs in the array.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Array<Types::DataSourceFilter>
An array of data source filters to filter log groups by their associated data sources. You can filter by data source name, type, or both. Multiple filters within the same dimension are combined with OR logic, while filters across different dimensions are combined with AND logic.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#field_index_names ⇒ Array<String>
An array of field index names to filter log groups that have specific field indexes. Only log groups containing all specified field indexes are returned. You can specify 1 to 20 field index names, each with 1 to 512 characters.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#include_linked_accounts ⇒ Boolean
If you are using a monitoring account, set this to true to have
the operation return log groups in the accounts listed in
accountIdentifiers.
If this parameter is set to true and accountIdentifiers contains
a null value, the operation returns all log groups in the monitoring
account and all log groups in all source accounts that are linked to
the monitoring account.
The default for this parameter is false.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of log groups to return. If you omit this parameter, the default is up to 50 log groups.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#log_group_class ⇒ String
Use this parameter to limit the results to only those log groups in the specified log group class. If you omit this parameter, log groups of all classes can be returned.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#log_group_name_pattern ⇒ String
Use this parameter to limit the returned log groups to only those with names that match the pattern that you specify. This parameter is a regular expression that can match prefixes and substrings, and supports wildcard matching and matching multiple patterns, as in the following examples.
-
Use
^to match log group names by prefix. -
For a substring match, specify the string to match. All matches are case sensitive
-
To match multiple patterns, separate them with a
|as in the example^/aws/lambda|discovery
You can specify as many as five different regular expression
patterns in this field, each of which must be between 3 and 24
characters. You can include the ^ symbol as many as five times,
and include the | symbol as many as four times.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#log_group_tags ⇒ Array<Types::TagFilter>
An array of tag filters to return only log groups that have specific tags. Multiple filters are combined with AND logic.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5480 class ListLogGroupsRequest < Struct.new( :log_group_name_pattern, :log_group_class, :include_linked_accounts, :account_identifiers, :next_token, :limit, :data_sources, :field_index_names, :log_group_tags) SENSITIVE = [] include Aws::Structure end |