Class: Aws::CloudWatchLogs::Types::ListScheduledQueriesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of scheduled queries to return. Valid range is 1 to 1000.

Returns:

  • (Integer)


5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536

class ListScheduledQueriesRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :schedule_type)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 24 hours.

Returns:

  • (String)


5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536

class ListScheduledQueriesRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :schedule_type)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_typeString

Filter scheduled queries by schedule type. Valid values are CUSTOMER_MANAGED and AWS_MANAGED. If not specified, scheduled queries of all schedule types are returned.

Returns:

  • (String)


5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536

class ListScheduledQueriesRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :schedule_type)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

Filter scheduled queries by state. Valid values are ENABLED and DISABLED. If not specified, all scheduled queries are returned.

Returns:

  • (String)


5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536

class ListScheduledQueriesRequest < Struct.new(
  :max_results,
  :next_token,
  :state,
  :schedule_type)
  SENSITIVE = []
  include Aws::Structure
end