Class: Aws::CloudWatchLogs::Types::ListSyslogConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_identifierString

The name or ARN of the log group to filter syslog configurations for.

Returns:

  • (String)


5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628

class ListSyslogConfigurationsRequest < Struct.new(
  :log_group_identifier,
  :vpc_endpoint_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of syslog configurations to return in the response.

Returns:

  • (Integer)


5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628

class ListSyslogConfigurationsRequest < Struct.new(
  :log_group_identifier,
  :vpc_endpoint_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. You received this token from a previous call.

Returns:

  • (String)


5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628

class ListSyslogConfigurationsRequest < Struct.new(
  :log_group_identifier,
  :vpc_endpoint_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the VPC endpoint to filter syslog configurations for.

Returns:

  • (String)


5628
5629
5630
5631
5632
5633
5634
5635
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628

class ListSyslogConfigurationsRequest < Struct.new(
  :log_group_identifier,
  :vpc_endpoint_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end