Class: Aws::CloudWatchLogs::Types::ListTagsForResourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListTagsForResourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#tags ⇒ Hash<String,String>
The list of tags associated with the requested resource.>.
Instance Attribute Details
#tags ⇒ Hash<String,String>
The list of tags associated with the requested resource.>
5157 5158 5159 5160 5161 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5157 class ListTagsForResourceResponse < Struct.new( :tags) SENSITIVE = [] include Aws::Structure end |