Class: Aws::CloudWatchLogs::Types::LiveTailSessionStart
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LiveTailSessionStart
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This object contains information about this Live Tail session, including the log groups included and the log stream filters, if any.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern.
-
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
-
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
-
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
-
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
-
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
5547 5548 5549 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 def event_type @event_type end |
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern. For example, a filter pattern of ‘error 404` displays only log events that include both `error` and `404`.
For more information about filter pattern syntax, see [Filter and Pattern Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html
5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
5547 5548 5549 5550 5551 5552 5553 5554 5555 5556 5557 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5547 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |