Class: Aws::CloudWatchLogs::Types::LiveTailSessionUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LiveTailSessionUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This object contains the log events and metadata for a Live Tail session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
-
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
5910 5911 5912 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5910 def event_type @event_type end |
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
5910 5911 5912 5913 5914 5915 5916 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5910 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
A sessionResults array can include as many as 500 log events. If
the number of log events matching the request exceeds 500 per
second, the log events are sampled down to 500 log events to be
included in each sessionUpdate structure.
5910 5911 5912 5913 5914 5915 5916 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5910 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |