Class: Aws::CloudWatchLogs::Types::LogEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LogEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains the information for one sample log event that is associated with an anomaly found by a log anomaly detector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The message content of the log event.
-
#timestamp ⇒ Integer
The time stamp of the log event.
Instance Attribute Details
#message ⇒ String
The message content of the log event.
5402 5403 5404 5405 5406 5407 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5402 class LogEvent < Struct.new( :timestamp, :message) SENSITIVE = [] include Aws::Structure end |
#timestamp ⇒ Integer
The time stamp of the log event.
5402 5403 5404 5405 5406 5407 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5402 class LogEvent < Struct.new( :timestamp, :message) SENSITIVE = [] include Aws::Structure end |