Class: Aws::CloudWatchLogs::Types::LogGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LogGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Represents a log group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the log group.
-
#creation_time ⇒ Integer
The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
-
#data_protection_status ⇒ String
Displays whether this log group has a protection policy, or whether it had one in the past.
-
#deletion_protection_enabled ⇒ Boolean
Indicates whether deletion protection is enabled for this log group.
-
#inherited_properties ⇒ Array<String>
Displays all the properties that this log group has inherited from account-level settings.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data.
-
#log_group_arn ⇒ String
The Amazon Resource Name (ARN) of the log group.
-
#log_group_class ⇒ String
This specifies the log group class for this log group.
-
#log_group_name ⇒ String
The name of the log group.
-
#metric_filter_count ⇒ Integer
The number of metric filters.
-
#retention_in_days ⇒ Integer
The number of days to retain the log events in the specified log group.
-
#stored_bytes ⇒ Integer
The number of bytes stored.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the log group. This version of the ARN includes a trailing ‘:*` after the log group name.
Use this version to refer to the ARN in IAM policies when specifying permissions for most API actions. The exception is when specifying permissions for [TagResource], [UntagResource], and [ListTagsForResource]. The permissions for those three actions require the ARN version that doesn’t include a trailing ‘:*`.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html [3]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Integer
The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#data_protection_status ⇒ String
Displays whether this log group has a protection policy, or whether it had one in the past. For more information, see [PutDataProtectionPolicy].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_enabled ⇒ Boolean
Indicates whether deletion protection is enabled for this log group. When enabled, deletion protection blocks all deletion operations until it is explicitly disabled.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#inherited_properties ⇒ Array<String>
Displays all the properties that this log group has inherited from account-level settings.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#log_group_arn ⇒ String
The Amazon Resource Name (ARN) of the log group. This version of the ARN doesn’t include a trailing ‘:*` after the log group name.
Use this version to refer to the ARN in the following situations:
-
In the ‘logGroupIdentifier` input field in many CloudWatch Logs APIs.
-
In the ‘resourceArn` field in tagging APIs
-
In IAM policies, when specifying permissions for [TagResource], [UntagResource], and [ListTagsForResource].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagResource.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagResource.html [3]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsForResource.html
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#log_group_class ⇒ String
This specifies the log group class for this log group. There are three classes:
-
The ‘Standard` log class supports all CloudWatch Logs features.
-
The ‘Infrequent Access` log class supports a subset of CloudWatch Logs features and incurs lower costs.
-
Use the ‘Delivery` log class only for delivering Lambda logs to store in Amazon S3 or Amazon Data Firehose. Log events in log groups in the Delivery class are kept in CloudWatch Logs for only one day. This log class doesn’t offer rich CloudWatch Logs capabilities such as CloudWatch Logs Insights queries.
For details about the features supported by the Standard and Infrequent Access classes, see [Log classes]
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch_Logs_Log_Classes.html
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#metric_filter_count ⇒ Integer
The number of metric filters.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days to retain the log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1096, 1827, 2192, 2557, 2922, 3288, and 3653.
To set a log group so that its log events do not expire, use [DeleteRetentionPolicy].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteRetentionPolicy.html
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |
#stored_bytes ⇒ Integer
The number of bytes stored.
5250 5251 5252 5253 5254 5255 5256 5257 5258 5259 5260 5261 5262 5263 5264 5265 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5250 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id, :data_protection_status, :inherited_properties, :log_group_class, :log_group_arn, :deletion_protection_enabled) SENSITIVE = [] include Aws::Structure end |