Class: Aws::CloudWatchLogs::Types::LowerCaseString

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This processor converts a string to lowercase.

For more information about this processor including examples, see lowerCaseString in the CloudWatch Logs User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#with_keysArray<String>

The array caontaining the keys of the fields to convert to lowercase.

Returns:

  • (Array<String>)


6224
6225
6226
6227
6228
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6224

class LowerCaseString < Struct.new(
  :with_keys)
  SENSITIVE = []
  include Aws::Structure
end