Class: Aws::CloudWatchLogs::Types::MalformedQueryException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

The query string is not valid. Details about this error are displayed in a QueryCompileError object. For more information, see QueryCompileError.

For more information about valid query syntax, see CloudWatch Logs Insights Query Syntax.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#query_compile_errorTypes::QueryCompileError

Reserved.



6248
6249
6250
6251
6252
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6248

class MalformedQueryException < Struct.new(
  :query_compile_error)
  SENSITIVE = []
  include Aws::Structure
end