Class: Aws::CloudWatchLogs::Types::MetricFilter
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::MetricFilter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Metric filters express how CloudWatch Logs would extract metric observations from ingested log events and transform them into metric data in a CloudWatch metric.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_on_transformed_logs ⇒ Boolean
This parameter is valid only for log groups that have an active log transformer.
-
#creation_time ⇒ Integer
The creation time of the metric filter, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#emit_system_field_dimensions ⇒ Array<String>
The list of system fields that are emitted as additional dimensions in the generated metrics.
-
#field_selection_criteria ⇒ String
The filter expression that specifies which log events are processed by this metric filter based on system fields.
-
#filter_name ⇒ String
The name of the metric filter.
-
#filter_pattern ⇒ String
A symbolic description of how CloudWatch Logs should interpret the data in each log event.
-
#log_group_name ⇒ String
The name of the log group.
-
#metric_transformations ⇒ Array<Types::MetricTransformation>
The metric transformations.
Instance Attribute Details
#apply_on_transformed_logs ⇒ Boolean
This parameter is valid only for log groups that have an active log transformer. For more information about log transformers, see [PutTransformer].
If this value is true, the metric filter is applied on the transformed version of the log events instead of the original ingested log events.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutTransformer.html
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Integer
The creation time of the metric filter, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#emit_system_field_dimensions ⇒ Array<String>
The list of system fields that are emitted as additional dimensions in the generated metrics. Returns the emitSystemFieldDimensions value if it was specified when the metric filter was created.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#field_selection_criteria ⇒ String
The filter expression that specifies which log events are processed by this metric filter based on system fields. Returns the fieldSelectionCriteria value if it was specified when the metric filter was created.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#filter_name ⇒ String
The name of the metric filter.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#filter_pattern ⇒ String
A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#metric_transformations ⇒ Array<Types::MetricTransformation>
The metric transformations.
5818 5819 5820 5821 5822 5823 5824 5825 5826 5827 5828 5829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5818 class MetricFilter < Struct.new( :filter_name, :filter_pattern, :metric_transformations, :creation_time, :log_group_name, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |