Class: Aws::CloudWatchLogs::Types::MoveKeys

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This processor moves a key from one field to another. The original key is deleted.

For more information about this processor including examples, see moveKeys in the CloudWatch Logs User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entriesArray<Types::MoveKeyEntry>

An array of objects, where each object contains the information about one key to move.

Returns:



6602
6603
6604
6605
6606
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6602

class MoveKeys < Struct.new(
  :entries)
  SENSITIVE = []
  include Aws::Structure
end