Class: Aws::CloudWatchLogs::Types::OpenSearchCollection
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::OpenSearchCollection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about the OpenSearch Service collection used for this integration. An OpenSearch Service collection is a logical grouping of one or more indexes that represent an analytics workload. For more information, see Creating and managing OpenSearch Service Serverless collections.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collection_arn ⇒ String
The ARN of the collection.
-
#collection_endpoint ⇒ String
The endpoint of the collection.
-
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
Instance Attribute Details
#collection_arn ⇒ String
The ARN of the collection.
6589 6590 6591 6592 6593 6594 6595 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6589 class OpenSearchCollection < Struct.new( :collection_endpoint, :collection_arn, :status) SENSITIVE = [] include Aws::Structure end |
#collection_endpoint ⇒ String
The endpoint of the collection.
6589 6590 6591 6592 6593 6594 6595 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6589 class OpenSearchCollection < Struct.new( :collection_endpoint, :collection_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
6589 6590 6591 6592 6593 6594 6595 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6589 class OpenSearchCollection < Struct.new( :collection_endpoint, :collection_arn, :status) SENSITIVE = [] include Aws::Structure end |