Class: Aws::CloudWatchLogs::Types::OpenSearchResourceStatus

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains information about the status of an OpenSearch Service resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statusString

The current status of this resource.

Returns:

  • (String)


6862
6863
6864
6865
6866
6867
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6862

class OpenSearchResourceStatus < Struct.new(
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message with additional information about the status of this resource.

Returns:

  • (String)


6862
6863
6864
6865
6866
6867
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6862

class OpenSearchResourceStatus < Struct.new(
  :status,
  :status_message)
  SENSITIVE = []
  include Aws::Structure
end