Class: Aws::CloudWatchLogs::Types::ParseCloudfront
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ParseCloudfront
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This processor parses CloudFront vended logs, extract fields, and convert them into JSON format. Encoded field values are decoded. Values that are integers and doubles are treated as such. For more information about this processor including examples, see parseCloudfront
For more information about CloudFront log format, see Configure and use standard logs (access logs).
If you use this processor, it must be the first processor in your transformer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source ⇒ String
Omit this parameter and the whole log message will be processed by this processor.
Instance Attribute Details
#source ⇒ String
Omit this parameter and the whole log message will be processed by
this processor. No other value than @message is allowed for
source.
7040 7041 7042 7043 7044 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7040 class ParseCloudfront < Struct.new( :source) SENSITIVE = [] include Aws::Structure end |