Class: Aws::CloudWatchLogs::Types::ParseKeyValue

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This processor parses a specified field in the original log event into key-value pairs.

For more information about this processor including examples, see parseKeyValue in the CloudWatch Logs User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destinationString

The destination field to put the extracted key-value pairs into



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#field_delimiterString

The field delimiter string that is used between key-value pairs in the original log events. If you omit this, the ampersand & character is used.



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#key_prefixString

If you want to add a prefix to all transformed keys, specify it here.



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#key_value_delimiterString

The delimiter string to use between the key and value in each pair in the transformed log event.

If you omit this, the equal = character is used.



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#non_match_valueString

A value to insert into the value field in the result, when a key-value pair is not successfully split.



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#overwrite_if_existsBoolean

Specifies whether to overwrite the value if the destination key already exists. If you omit this, the default is false.



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

Path to the field in the log event that will be parsed. Use dot notation to access child fields. For example, store.book



7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7207

class ParseKeyValue < Struct.new(
  :source,
  :destination,
  :field_delimiter,
  :key_value_delimiter,
  :key_prefix,
  :non_match_value,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end