Class: Aws::CloudWatchLogs::Types::ParseToOCSF

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This processor converts logs into Open Cybersecurity Schema Framework (OCSF) events.

For more information about this processor including examples, see parseToOCSF in the CloudWatch Logs User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_sourceString

Specify the service or process that produces the log events that will be converted with this processor.

Returns:

  • (String)


7307
7308
7309
7310
7311
7312
7313
7314
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7307

class ParseToOCSF < Struct.new(
  :source,
  :event_source,
  :ocsf_version,
  :mapping_version)
  SENSITIVE = []
  include Aws::Structure
end

#mapping_versionString

The version of the OCSF mapping to use for parsing log data.

Returns:

  • (String)


7307
7308
7309
7310
7311
7312
7313
7314
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7307

class ParseToOCSF < Struct.new(
  :source,
  :event_source,
  :ocsf_version,
  :mapping_version)
  SENSITIVE = []
  include Aws::Structure
end

#ocsf_versionString

Specify which version of the OCSF schema to use for the transformed log events.

Returns:

  • (String)


7307
7308
7309
7310
7311
7312
7313
7314
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7307

class ParseToOCSF < Struct.new(
  :source,
  :event_source,
  :ocsf_version,
  :mapping_version)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The path to the field in the log event that you want to parse. If you omit this value, the whole log message is parsed.

Returns:

  • (String)


7307
7308
7309
7310
7311
7312
7313
7314
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7307

class ParseToOCSF < Struct.new(
  :source,
  :event_source,
  :ocsf_version,
  :mapping_version)
  SENSITIVE = []
  include Aws::Structure
end