Class: Aws::CloudWatchLogs::Types::ParseVPC
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ParseVPC
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Use this processor to parse Amazon VPC vended logs, extract fields, and and convert them into a JSON format. This processor always processes the entire log event message.
This processor doesn’t support custom log formats, such as NAT gateway logs. For more information about custom log formats in Amazon VPC, see [ parseVPC] For more information about this processor including examples, see [ parseVPC].
If you use this processor, it must be the first processor in your transformer.
[1]: docs.aws.amazon.com/vpc/latest/userguide/flow-logs-records-examples.html#flow-log-example-tcp-flag [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-parseVPC
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source ⇒ String
Omit this parameter and the whole log message will be processed by this processor.
Instance Attribute Details
#source ⇒ String
Omit this parameter and the whole log message will be processed by this processor. No other value than ‘@message` is allowed for source.
6718 6719 6720 6721 6722 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6718 class ParseVPC < Struct.new( :source) SENSITIVE = [] include Aws::Structure end |