Class: Aws::CloudWatchLogs::Types::Processor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains the information about one processor in a log transformer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_keysTypes::AddKeys

Use this parameter to include the addKeys processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#copy_valueTypes::CopyValue

Use this parameter to include the copyValue processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#csvTypes::CSV

Use this parameter to include the CSV processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#date_time_converterTypes::DateTimeConverter

Use this parameter to include the datetimeConverter processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#delete_keysTypes::DeleteKeys

Use this parameter to include the deleteKeys processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#grokTypes::Grok

Use this parameter to include the grok processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#list_to_mapTypes::ListToMap

Use this parameter to include the listToMap processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#lower_case_stringTypes::LowerCaseString

Use this parameter to include the lowerCaseString processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#move_keysTypes::MoveKeys

Use this parameter to include the moveKeys processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_cloudfrontTypes::ParseCloudfront

Use this parameter to include the parseCloudfront processor in your transformer.

If you use this processor, it must be the first processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_jsonTypes::ParseJSON

Use this parameter to include the parseJSON processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_key_valueTypes::ParseKeyValue

Use this parameter to include the parseKeyValue processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_postgresTypes::ParsePostgres

Use this parameter to include the parsePostGres processor in your transformer.

If you use this processor, it must be the first processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_route_53Types::ParseRoute53

Use this parameter to include the parseRoute53 processor in your transformer.

If you use this processor, it must be the first processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_to_ocsfTypes::ParseToOCSF

Use this parameter to convert logs into Open Cybersecurity Schema (OCSF) format.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_vpcTypes::ParseVPC

Use this parameter to include the parseVPC processor in your transformer.

If you use this processor, it must be the first processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#parse_wafTypes::ParseWAF

Use this parameter to include the parseWAF processor in your transformer.

If you use this processor, it must be the first processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#rename_keysTypes::RenameKeys

Use this parameter to include the renameKeys processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#split_stringTypes::SplitString

Use this parameter to include the splitString processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#substitute_stringTypes::SubstituteString

Use this parameter to include the substituteString processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#trim_stringTypes::TrimString

Use this parameter to include the trimString processor in your transformer.

Returns:



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#type_converterTypes::TypeConverter

Use this parameter to include the typeConverter processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end

#upper_case_stringTypes::UpperCaseString

Use this parameter to include the upperCaseString processor in your transformer.



7595
7596
7597
7598
7599
7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
7612
7613
7614
7615
7616
7617
7618
7619
7620
7621
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595

class Processor < Struct.new(
  :add_keys,
  :copy_value,
  :csv,
  :date_time_converter,
  :delete_keys,
  :grok,
  :list_to_map,
  :lower_case_string,
  :move_keys,
  :parse_cloudfront,
  :parse_json,
  :parse_key_value,
  :parse_route_53,
  :parse_to_ocsf,
  :parse_postgres,
  :parse_vpc,
  :parse_waf,
  :rename_keys,
  :split_string,
  :substitute_string,
  :trim_string,
  :type_converter,
  :upper_case_string)
  SENSITIVE = []
  include Aws::Structure
end