Class: Aws::CloudWatchLogs::Types::PutAccountPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutAccountPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_document ⇒ String
Specify the data protection policy, in JSON.
-
#policy_name ⇒ String
A name for the policy.
-
#policy_type ⇒ String
Currently the only valid value for this parameter is ‘DATA_PROTECTION_POLICY`.
-
#scope ⇒ String
Currently the only valid value for this parameter is ‘ALL`, which specifies that the data protection policy applies to all log groups in the account.
Instance Attribute Details
#policy_document ⇒ String
Specify the data protection policy, in JSON.
This policy must include two JSON blocks:
-
The first block must include both a ‘DataIdentifer` array and an `Operation` property with an `Audit` action. The `DataIdentifer` array lists the types of sensitive data that you want to mask. For more information about the available options, see [Types of data that you can mask].
The ‘Operation` property with an `Audit` action is required to find the sensitive data terms. This `Audit` action must contain a `FindingsDestination` object. You can optionally use that `FindingsDestination` object to list one or more destinations to send audit findings to. If you specify destinations such as log groups, Kinesis Data Firehose streams, and S3 buckets, they must already exist.
-
The second block must include both a ‘DataIdentifer` array and an `Operation` property with an `Deidentify` action. The `DataIdentifer` array must exactly match the `DataIdentifer` array in the first block of the policy.
The ‘Operation` property with the `Deidentify` action is what actually masks the data, and it must contain the ` “MaskConfig”: {}` object. The ` “MaskConfig”: {}` object must be empty.
For an example data protection policy, see the Examples section on this page.
The contents of the two ‘DataIdentifer` arrays must match exactly.
In addition to the two JSON blocks, the ‘policyDocument` can also include `Name`, `Description`, and `Version` fields. The `Name` is different than the operation’s ‘policyName` parameter, and is used as a dimension when CloudWatch Logs reports audit findings metrics to CloudWatch.
The JSON specified in ‘policyDocument` can be up to 30,720 characters.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/mask-sensitive-log-data-types.html
3351 3352 3353 3354 3355 3356 3357 3358 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3351 class PutAccountPolicyRequest < Struct.new( :policy_name, :policy_document, :policy_type, :scope) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
A name for the policy. This must be unique within the account.
3351 3352 3353 3354 3355 3356 3357 3358 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3351 class PutAccountPolicyRequest < Struct.new( :policy_name, :policy_document, :policy_type, :scope) SENSITIVE = [] include Aws::Structure end |
#policy_type ⇒ String
Currently the only valid value for this parameter is ‘DATA_PROTECTION_POLICY`.
3351 3352 3353 3354 3355 3356 3357 3358 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3351 class PutAccountPolicyRequest < Struct.new( :policy_name, :policy_document, :policy_type, :scope) SENSITIVE = [] include Aws::Structure end |
#scope ⇒ String
Currently the only valid value for this parameter is ‘ALL`, which specifies that the data protection policy applies to all log groups in the account. If you omit this parameter, the default of `ALL` is used.
3351 3352 3353 3354 3355 3356 3357 3358 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3351 class PutAccountPolicyRequest < Struct.new( :policy_name, :policy_document, :policy_type, :scope) SENSITIVE = [] include Aws::Structure end |