Class: Aws::CloudWatchLogs::Types::PutDataProtectionPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDataProtectionPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_time ⇒ Integer
The date and time that this policy was most recently updated.
-
#log_group_identifier ⇒ String
The log group name or ARN that you specified in your request.
-
#policy_document ⇒ String
The data protection policy used for this log group.
Instance Attribute Details
#last_updated_time ⇒ Integer
The date and time that this policy was most recently updated.
2283 2284 2285 2286 2287 2288 2289 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2283 class PutDataProtectionPolicyResponse < Struct.new( :log_group_identifier, :policy_document, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#log_group_identifier ⇒ String
The log group name or ARN that you specified in your request.
2283 2284 2285 2286 2287 2288 2289 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2283 class PutDataProtectionPolicyResponse < Struct.new( :log_group_identifier, :policy_document, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#policy_document ⇒ String
The data protection policy used for this log group.
2283 2284 2285 2286 2287 2288 2289 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2283 class PutDataProtectionPolicyResponse < Struct.new( :log_group_identifier, :policy_document, :last_updated_time) SENSITIVE = [] include Aws::Structure end |