Class: Aws::CloudWatchLogs::Types::PutDeliveryDestinationPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDeliveryDestinationPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ Types::Policy
The contents of the policy that you just created.
Instance Attribute Details
#policy ⇒ Types::Policy
The contents of the policy that you just created.
2871 2872 2873 2874 2875 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2871 class PutDeliveryDestinationPolicyResponse < Struct.new( :policy) SENSITIVE = [] include Aws::Structure end |