Class: Aws::CloudWatchLogs::Types::PutDeliveryDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDeliveryDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_destination_configuration ⇒ Types::DeliveryDestinationConfiguration
A structure that contains the ARN of the Amazon Web Services resource that will receive the logs.
-
#delivery_destination_type ⇒ String
The type of delivery destination.
-
#name ⇒ String
A name for this delivery destination.
-
#output_format ⇒ String
The format for the logs that this delivery destination will receive.
-
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
Instance Attribute Details
#delivery_destination_configuration ⇒ Types::DeliveryDestinationConfiguration
A structure that contains the ARN of the Amazon Web Services resource that will receive the logs.
deliveryDestinationConfiguration is required for CloudWatch Logs,
Amazon S3, Firehose log delivery destinations and not required for
X-Ray trace delivery destinations. deliveryDestinationType is
needed for X-Ray trace delivery destinations but not required for
other logs delivery destinations.
8081 8082 8083 8084 8085 8086 8087 8088 8089 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8081 class PutDeliveryDestinationRequest < Struct.new( :name, :output_format, :delivery_destination_configuration, :delivery_destination_type, :tags) SENSITIVE = [] include Aws::Structure end |
#delivery_destination_type ⇒ String
The type of delivery destination. This parameter specifies the target service where log data will be delivered. Valid values include:
-
S3- Amazon S3 for long-term storage and analytics -
CWL- CloudWatch Logs for centralized log management -
FH- Amazon Kinesis Data Firehose for real-time data streaming -
XRAY- Amazon Web Services X-Ray for distributed tracing and application monitoring
The delivery destination type determines the format and configuration options available for log delivery.
8081 8082 8083 8084 8085 8086 8087 8088 8089 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8081 class PutDeliveryDestinationRequest < Struct.new( :name, :output_format, :delivery_destination_configuration, :delivery_destination_type, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for this delivery destination. This name must be unique for all delivery destinations in your account.
8081 8082 8083 8084 8085 8086 8087 8088 8089 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8081 class PutDeliveryDestinationRequest < Struct.new( :name, :output_format, :delivery_destination_configuration, :delivery_destination_type, :tags) SENSITIVE = [] include Aws::Structure end |
#output_format ⇒ String
The format for the logs that this delivery destination will receive.
8081 8082 8083 8084 8085 8086 8087 8088 8089 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8081 class PutDeliveryDestinationRequest < Struct.new( :name, :output_format, :delivery_destination_configuration, :delivery_destination_type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
For more information about tagging, see Tagging Amazon Web Services resources
8081 8082 8083 8084 8085 8086 8087 8088 8089 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8081 class PutDeliveryDestinationRequest < Struct.new( :name, :output_format, :delivery_destination_configuration, :delivery_destination_type, :tags) SENSITIVE = [] include Aws::Structure end |