Class: Aws::CloudWatchLogs::Types::PutDeliverySourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDeliverySourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_type ⇒ String
Defines the type of log that the source is sending.
-
#name ⇒ String
A name for this delivery source.
-
#resource_arn ⇒ String
The ARN of the Amazon Web Services resource that is generating and sending logs.
-
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
Instance Attribute Details
#log_type ⇒ String
Defines the type of log that the source is sending.
-
For Amazon Bedrock Agents, the valid values are
APPLICATION_LOGSandEVENT_LOGS. -
For Amazon Bedrock Knowledge Bases, the valid value is
APPLICATION_LOGS. -
For Amazon Bedrock AgentCore Runtime, the valid values are
APPLICATION_LOGS,USAGE_LOGSandTRACES. -
For Amazon Bedrock AgentCore Tools, the valid values are
APPLICATION_LOGS,USAGE_LOGSandTRACES. -
For Amazon Bedrock AgentCore Identity, the valid values are
APPLICATION_LOGSandTRACES. -
For Amazon Bedrock AgentCore Gateway, the valid values are
APPLICATION_LOGSandTRACES. -
For CloudFront, the valid value is
ACCESS_LOGS. -
For Amazon CodeWhisperer, the valid value is
EVENT_LOGS. -
For Elemental MediaPackage, the valid values are
EGRESS_ACCESS_LOGSandINGRESS_ACCESS_LOGS. -
For Elemental MediaTailor, the valid values are
AD_DECISION_SERVER_LOGS,MANIFEST_SERVICE_LOGS, andTRANSCODE_LOGS. -
For Entity Resolution, the valid value is
WORKFLOW_LOGS. -
For IAM Identity Center, the valid value is
ERROR_LOGS. -
For Network Firewall Proxy, the valid values are
ALERT_LOGS,ALLOW_LOGS, andDENY_LOGS. -
For Network Load Balancer, the valid value is
NLB_ACCESS_LOGS. -
For PCS, the valid values are
PCS_SCHEDULER_LOGSandPCS_JOBCOMP_LOGS. -
For Quick Suite, the valid values are
CHAT_LOGSandFEEDBACK_LOGS. -
For Amazon Web Services RTB Fabric, the valid values is
APPLICATION_LOGS. -
For Amazon Q, the valid values are
EVENT_LOGSandSYNC_JOB_LOGS. -
For Amazon SES mail manager, the valid values are
APPLICATION_LOGSandTRAFFIC_POLICY_DEBUG_LOGS. -
For Amazon WorkMail, the valid values are
ACCESS_CONTROL_LOGS,AUTHENTICATION_LOGS,WORKMAIL_AVAILABILITY_PROVIDER_LOGS,WORKMAIL_MAILBOX_ACCESS_LOGS, andWORKMAIL_PERSONAL_ACCESS_TOKEN_LOGS. -
For Amazon VPC Route Server, the valid value is
EVENT_LOGS.
7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7533 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for this delivery source. This name must be unique for all delivery sources in your account.
7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7533 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the Amazon Web Services resource that is generating and sending logs. For example, arn:aws:workmail:us-east-1:123456789012:organization/m-1234EXAMPLEabcd1234abcd1234abcd1234
7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7533 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
For more information about tagging, see [Tagging Amazon Web Services resources]
7533 7534 7535 7536 7537 7538 7539 7540 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7533 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |