Class: Aws::CloudWatchLogs::Types::PutDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_nameString

A name for the destination.



8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8327

class PutDestinationRequest < Struct.new(
  :destination_name,
  :target_arn,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis PutRecord operation on the destination stream.



8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8327

class PutDestinationRequest < Struct.new(
  :destination_name,
  :target_arn,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

An optional list of key-value pairs to associate with the resource.

For more information about tagging, see Tagging Amazon Web Services resources



8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8327

class PutDestinationRequest < Struct.new(
  :destination_name,
  :target_arn,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The ARN of an Amazon Kinesis stream to which to deliver matching log events.



8327
8328
8329
8330
8331
8332
8333
8334
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8327

class PutDestinationRequest < Struct.new(
  :destination_name,
  :target_arn,
  :role_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end