Method: Aws::CloudWatchLogs::Types::PutIndexPolicyRequest#policy_document

Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

#policy_documentString

The index policy document, in JSON format. The following is an example of an index policy document that creates indexes with different types.

‘“policyDocument”: “[ ”TransactionId“ ], ”FieldsV2“: {”RequestId“: {”type“: ”FIELD_INDEX“, ”APIName“: ”FACET“, ”StatusCode“: ”FACET“}}”`

You can use FieldsV2 to specify the type for each field. Supported types are FIELD_INDEX and FACET. Field names within Fields and FieldsV2 must be mutually exclusive.

The policy document must include at least one field index. For more information about the fields that can be included and other restrictions, see [Field index syntax and quotas].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatchLogs-Field-Indexing-Syntax.html

Returns:

  • (String)


7710
7711
7712
7713
7714
7715
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7710

class PutIndexPolicyRequest < Struct.new(
  :log_group_identifier,
  :policy_document)
  SENSITIVE = []
  include Aws::Structure
end