Class: Aws::CloudWatchLogs::Types::PutIntegrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integration_nameString

The name of the integration that you just created.



7772
7773
7774
7775
7776
7777
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7772

class PutIntegrationResponse < Struct.new(
  :integration_name,
  :integration_status)
  SENSITIVE = []
  include Aws::Structure
end

#integration_statusString

The status of the integration that you just created.

After you create an integration, it takes a few minutes to complete. During this time, you’ll see the status as PROVISIONING.



7772
7773
7774
7775
7776
7777
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7772

class PutIntegrationResponse < Struct.new(
  :integration_name,
  :integration_status)
  SENSITIVE = []
  include Aws::Structure
end