Class: Aws::CloudWatchLogs::Types::PutLogEventsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_eventsArray<Types::InputLogEvent>

The log events.

Returns:



2090
2091
2092
2093
2094
2095
2096
2097
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2090

class PutLogEventsRequest < Struct.new(
  :log_group_name,
  :log_stream_name,
  :log_events,
  :sequence_token)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2090

class PutLogEventsRequest < Struct.new(
  :log_group_name,
  :log_stream_name,
  :log_events,
  :sequence_token)
  SENSITIVE = []
  include Aws::Structure
end

#log_stream_nameString

The name of the log stream.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2090

class PutLogEventsRequest < Struct.new(
  :log_group_name,
  :log_stream_name,
  :log_events,
  :sequence_token)
  SENSITIVE = []
  include Aws::Structure
end

#sequence_tokenString

The sequence token obtained from the response of the previous `PutLogEvents` call. An upload in a newly created log stream does not require a sequence token. You can also get the sequence token using [DescribeLogStreams]. If you call `PutLogEvents` twice within a narrow time period using the same value for `sequenceToken`, both calls might be successful or one might be rejected.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeLogStreams.html

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2090

class PutLogEventsRequest < Struct.new(
  :log_group_name,
  :log_stream_name,
  :log_events,
  :sequence_token)
  SENSITIVE = []
  include Aws::Structure
end