Class: Aws::CloudWatchLogs::Types::PutLogEventsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_sequence_tokenString

The next sequence token.

This field has been deprecated.

The sequence token is now ignored in PutLogEvents actions. PutLogEvents actions are always accepted even if the sequence token is not valid. You can use parallel PutLogEvents actions on the same log stream and you do not need to wait for the response of a previous PutLogEvents action to obtain the nextSequenceToken value.

Returns:

  • (String)


8427
8428
8429
8430
8431
8432
8433
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8427

class PutLogEventsResponse < Struct.new(
  :next_sequence_token,
  :rejected_log_events_info,
  :rejected_entity_info)
  SENSITIVE = []
  include Aws::Structure
end

#rejected_entity_infoTypes::RejectedEntityInfo

Information about why the entity is rejected when calling PutLogEvents. Only returned when the entity is rejected.

When the entity is rejected, the events may still be accepted.



8427
8428
8429
8430
8431
8432
8433
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8427

class PutLogEventsResponse < Struct.new(
  :next_sequence_token,
  :rejected_log_events_info,
  :rejected_entity_info)
  SENSITIVE = []
  include Aws::Structure
end

#rejected_log_events_infoTypes::RejectedLogEventsInfo

The rejected events.



8427
8428
8429
8430
8431
8432
8433
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8427

class PutLogEventsResponse < Struct.new(
  :next_sequence_token,
  :rejected_log_events_info,
  :rejected_entity_info)
  SENSITIVE = []
  include Aws::Structure
end