Class: Aws::CloudWatchLogs::Types::PutQueryDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutQueryDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_names ⇒ Array<String>
Use this parameter to include specific log groups as part of your query definition.
-
#name ⇒ String
A name for the query definition.
-
#query_definition_id ⇒ String
If you are updating a query definition, use this parameter to specify the ID of the query definition that you want to update.
-
#query_string ⇒ String
The query string to use for this definition.
Instance Attribute Details
#log_group_names ⇒ Array<String>
Use this parameter to include specific log groups as part of your query definition.
If you are updating a query definition and you omit this parameter, then the updated definition will contain no log groups.
2498 2499 2500 2501 2502 2503 2504 2505 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2498 class PutQueryDefinitionRequest < Struct.new( :name, :query_definition_id, :log_group_names, :query_string) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the query definition. If you are saving numerous query definitions, we recommend that you name them. This way, you can find the ones you want by using the first part of the name as a filter in the ‘queryDefinitionNamePrefix` parameter of [DescribeQueryDefinitions].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeQueryDefinitions.html
2498 2499 2500 2501 2502 2503 2504 2505 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2498 class PutQueryDefinitionRequest < Struct.new( :name, :query_definition_id, :log_group_names, :query_string) SENSITIVE = [] include Aws::Structure end |
#query_definition_id ⇒ String
If you are updating a query definition, use this parameter to specify the ID of the query definition that you want to update. You can use [DescribeQueryDefinitions] to retrieve the IDs of your saved query definitions.
If you are creating a query definition, do not specify this parameter. CloudWatch generates a unique ID for the new query definition and include it in the response to this operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeQueryDefinitions.html
2498 2499 2500 2501 2502 2503 2504 2505 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2498 class PutQueryDefinitionRequest < Struct.new( :name, :query_definition_id, :log_group_names, :query_string) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string to use for this definition. For more information, see [CloudWatch Logs Insights Query Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html
2498 2499 2500 2501 2502 2503 2504 2505 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2498 class PutQueryDefinitionRequest < Struct.new( :name, :query_definition_id, :log_group_names, :query_string) SENSITIVE = [] include Aws::Structure end |