Class: Aws::CloudWatchLogs::Types::PutResourcePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_revision_idString

The expected revision ID of the resource policy. Required when resourceArn is provided to prevent concurrent modifications. Use null when creating a resource policy for the first time.

Returns:

  • (String)


8679
8680
8681
8682
8683
8684
8685
8686
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8679

class PutResourcePolicyRequest < Struct.new(
  :policy_name,
  :policy_document,
  :resource_arn,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

Details of the new policy, including the identity of the principal that is enabled to put logs to this account. This is formatted as a JSON string. This parameter is required.

The following example creates a resource policy enabling the Route 53 service to put DNS query logs in to the specified log group. Replace "logArn" with the ARN of your CloudWatch Logs resource, such as a log group or log stream.

CloudWatch Logs also supports aws:SourceArn and aws:SourceAccount condition context keys.

In the example resource policy, you would replace the value of SourceArn with the resource making the call from RouteĀ 53 to CloudWatch Logs. You would also replace the value of SourceAccount with the Amazon Web Services account ID making that call.

{ "Version": "2012-10-17", "Statement": [ { "Sid": "Route53LogsToCloudWatchLogs", "Effect": "Allow", "Principal": { "Service": [ "route53.amazonaws.com" ] }, "Action": "logs:PutLogEvents", "Resource": "logArn", "Condition": { "ArnLike": { "aws:SourceArn": "myRoute53ResourceArn" }, "StringEquals": { "aws:SourceAccount": "myAwsAccountId" } } } ] }

Returns:

  • (String)


8679
8680
8681
8682
8683
8684
8685
8686
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8679

class PutResourcePolicyRequest < Struct.new(
  :policy_name,
  :policy_document,
  :resource_arn,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#policy_nameString

Name of the new policy. This parameter is required.

Returns:

  • (String)


8679
8680
8681
8682
8683
8684
8685
8686
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8679

class PutResourcePolicyRequest < Struct.new(
  :policy_name,
  :policy_document,
  :resource_arn,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The ARN of the CloudWatch Logs resource to which the resource policy needs to be added or attached. Currently only supports LogGroup ARN.

Returns:

  • (String)


8679
8680
8681
8682
8683
8684
8685
8686
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8679

class PutResourcePolicyRequest < Struct.new(
  :policy_name,
  :policy_document,
  :resource_arn,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end