Class: Aws::CloudWatchLogs::Types::PutStorageTierPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#storage_tierString

The storage tier to set for the account. Use INTELLIGENT_TIERING to automatically optimize storage costs by moving log data to the appropriate tier based on access frequency.

Returns:

  • (String)


8822
8823
8824
8825
8826
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8822

class PutStorageTierPolicyRequest < Struct.new(
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end