Class: Aws::CloudWatchLogs::Types::PutStorageTierPolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_updated_timeInteger

The time when the storage tier policy was last updated, expressed as the number of milliseconds after January 1, 1970 00:00:00 UTC.

Returns:

  • (Integer)


8758
8759
8760
8761
8762
8763
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8758

class PutStorageTierPolicyResponse < Struct.new(
  :storage_tier,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#storage_tierString

The storage tier for the account.

Returns:

  • (String)


8758
8759
8760
8761
8762
8763
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8758

class PutStorageTierPolicyResponse < Struct.new(
  :storage_tier,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end