Class: Aws::CloudWatchLogs::Types::PutSubscriptionFilterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_on_transformed_logsBoolean

This parameter is valid only for log groups that have an active log transformer. For more information about log transformers, see [PutTransformer].

If the log group uses either a log-group level or account-level transformer, and you specify true, the subscription filter will be applied on the transformed version of the log events instead of the original ingested log events.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutTransformer.html



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#destination_arnString

The ARN of the destination to deliver matching log events to. Currently, the supported destinations are:

  • An Amazon Kinesis stream belonging to the same account as the subscription filter, for same-account delivery.

  • A logical destination (specified using an ARN) belonging to a different account, for cross-account delivery.

    If you’re setting up a cross-account subscription, the destination must have an IAM policy associated with it. The IAM policy must allow the sender to send logs to the destination. For more information, see [PutDestinationPolicy].

  • A Kinesis Data Firehose delivery stream belonging to the same account as the subscription filter, for same-account delivery.

  • A Lambda function belonging to the same account as the subscription filter, for same-account delivery.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestinationPolicy.html



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#distributionString

The method used to distribute log data to the destination. By default, log data is grouped by log stream, but the grouping can be set to random for a more even distribution. This property is only applicable when the destination is an Amazon Kinesis data stream.



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#emit_system_fieldsArray<String>

A list of system fields to include in the log events sent to the subscription destination. Valid values are ‘@aws.account` and `@aws.region`. These fields provide source information for centralized log data in the forwarded payload.



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#field_selection_criteriaString

A filter expression that specifies which log events should be processed by this subscription filter based on system fields such as source account and source region. Uses selection criteria syntax with operators like ‘=`, `!=`, AND, OR, IN, `NOT IN`. Example: `@aws.region NOT IN [“cn-north-1”]` or `@aws.account = “123456789012” AND @aws.region = “us-east-1”`. Maximum length: 2000 characters.



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#filter_nameString

A name for the subscription filter. If you are updating an existing filter, you must specify the correct name in filterName. To find the name of the filter currently associated with a log group, use [DescribeSubscriptionFilters].

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeSubscriptionFilters.html



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#filter_patternString

A filter pattern for subscribing to a filtered stream of log events.



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group.



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of an IAM role that grants CloudWatch Logs permissions to deliver ingested log events to the destination stream. You don’t need to provide the ARN when you are working with a logical destination for cross-account delivery.



8192
8193
8194
8195
8196
8197
8198
8199
8200
8201
8202
8203
8204
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8192

class PutSubscriptionFilterRequest < Struct.new(
  :log_group_name,
  :filter_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end