Class: Aws::CloudWatchLogs::Types::PutSyslogConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutSyslogConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_identifier ⇒ String
The name or ARN of the log group to associate with the syslog configuration.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint to use for syslog ingestion.
Instance Attribute Details
#log_group_identifier ⇒ String
The name or ARN of the log group to associate with the syslog configuration.
8765 8766 8767 8768 8769 8770 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8765 class PutSyslogConfigurationRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint to use for syslog ingestion.
8765 8766 8767 8768 8769 8770 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8765 class PutSyslogConfigurationRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id) SENSITIVE = [] include Aws::Structure end |