Class: Aws::CloudWatchLogs::Types::QueryDefinition
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::QueryDefinition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains details about a saved CloudWatch Logs Insights query definition.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_modified ⇒ Integer
The date that the query definition was most recently modified.
-
#log_group_names ⇒ Array<String>
If this query definition contains a list of log groups that it is limited to, that list appears here.
-
#name ⇒ String
The name of the query definition.
-
#parameters ⇒ Array<Types::QueryParameter>
If this query definition contains a list of query parameters that define placeholder variables for the query string, that list appears here.
-
#query_definition_id ⇒ String
The unique ID of the query definition.
-
#query_language ⇒ String
The query language used for this query.
-
#query_string ⇒ String
The query string to use for this definition.
Instance Attribute Details
#last_modified ⇒ Integer
The date that the query definition was most recently modified.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |
#log_group_names ⇒ Array<String>
If this query definition contains a list of log groups that it is limited to, that list appears here.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the query definition.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::QueryParameter>
If this query definition contains a list of query parameters that define placeholder variables for the query string, that list appears here.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |
#query_definition_id ⇒ String
The unique ID of the query definition.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see Supported query languages.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string to use for this definition. For more information, see CloudWatch Logs Insights Query Syntax.
9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9077 class QueryDefinition < Struct.new( :query_language, :query_definition_id, :name, :query_string, :last_modified, :log_group_names, :parameters) SENSITIVE = [] include Aws::Structure end |