Class: Aws::CloudWatchLogs::Types::QueryStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::QueryStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Contains the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the log events that were scanned.
If the query involved log groups that have field index policies, the estimated number of skipped log events and the total bytes of those skipped log events are included. Using field indexes to skip log events in queries reduces scan volume and improves performance. For more information, see [Create field indexes to improve query performance and reduce scan volume].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatchLogs-Field-Indexing.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes_scanned ⇒ Float
The total number of bytes in the log events scanned during the query.
-
#estimated_bytes_skipped ⇒ Float
An estimate of the number of bytes in the log events that were skipped when processing this query, because the query contained an indexed field.
-
#estimated_records_skipped ⇒ Float
An estimate of the number of log events that were skipped when processing this query, because the query contained an indexed field.
-
#log_groups_scanned ⇒ Float
The number of log groups that were scanned by this query.
-
#records_matched ⇒ Float
The number of log events that matched the query string.
-
#records_scanned ⇒ Float
The total number of log events scanned during the query.
Instance Attribute Details
#bytes_scanned ⇒ Float
The total number of bytes in the log events scanned during the query.
8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8458 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :estimated_records_skipped, :bytes_scanned, :estimated_bytes_skipped, :log_groups_scanned) SENSITIVE = [] include Aws::Structure end |
#estimated_bytes_skipped ⇒ Float
An estimate of the number of bytes in the log events that were skipped when processing this query, because the query contained an indexed field. Skipping these entries lowers query costs and improves the query performance time. For more information about field indexes, see [PutIndexPolicy].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutIndexPolicy.html
8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8458 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :estimated_records_skipped, :bytes_scanned, :estimated_bytes_skipped, :log_groups_scanned) SENSITIVE = [] include Aws::Structure end |
#estimated_records_skipped ⇒ Float
An estimate of the number of log events that were skipped when processing this query, because the query contained an indexed field. Skipping these entries lowers query costs and improves the query performance time. For more information about field indexes, see [PutIndexPolicy].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutIndexPolicy.html
8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8458 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :estimated_records_skipped, :bytes_scanned, :estimated_bytes_skipped, :log_groups_scanned) SENSITIVE = [] include Aws::Structure end |
#log_groups_scanned ⇒ Float
The number of log groups that were scanned by this query.
8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8458 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :estimated_records_skipped, :bytes_scanned, :estimated_bytes_skipped, :log_groups_scanned) SENSITIVE = [] include Aws::Structure end |
#records_matched ⇒ Float
The number of log events that matched the query string.
8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8458 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :estimated_records_skipped, :bytes_scanned, :estimated_bytes_skipped, :log_groups_scanned) SENSITIVE = [] include Aws::Structure end |
#records_scanned ⇒ Float
The total number of log events scanned during the query.
8458 8459 8460 8461 8462 8463 8464 8465 8466 8467 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8458 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :estimated_records_skipped, :bytes_scanned, :estimated_bytes_skipped, :log_groups_scanned) SENSITIVE = [] include Aws::Structure end |