Class: Aws::CloudWatchLogs::Types::RejectedEntityInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::RejectedEntityInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
If an entity is rejected when a PutLogEvents request was made, this
includes details about the reason for the rejection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_type ⇒ String
The type of error that caused the rejection of the entity when calling
PutLogEvents.
Instance Attribute Details
#error_type ⇒ String
The type of error that caused the rejection of the entity when
calling PutLogEvents.
9154 9155 9156 9157 9158 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9154 class RejectedEntityInfo < Struct.new( :error_type) SENSITIVE = [] include Aws::Structure end |