Class: Aws::CloudWatchLogs::Types::RenameKeyEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This object defines one key that will be renamed with the renameKey processor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The key to rename

Returns:

  • (String)


9208
9209
9210
9211
9212
9213
9214
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9208

class RenameKeyEntry < Struct.new(
  :key,
  :rename_to,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#overwrite_if_existsBoolean

Specifies whether to overwrite the existing value if the destination key already exists. The default is false

Returns:

  • (Boolean)


9208
9209
9210
9211
9212
9213
9214
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9208

class RenameKeyEntry < Struct.new(
  :key,
  :rename_to,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end

#rename_toString

The string to use for the new key name

Returns:

  • (String)


9208
9209
9210
9211
9212
9213
9214
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9208

class RenameKeyEntry < Struct.new(
  :key,
  :rename_to,
  :overwrite_if_exists)
  SENSITIVE = []
  include Aws::Structure
end