Class: Aws::CloudWatchLogs::Types::RenameKeys

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Use this processor to rename keys in a log event.

For more information about this processor including examples, see renameKeys in the CloudWatch Logs User Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entriesArray<Types::RenameKeyEntry>

An array of RenameKeyEntry objects, where each object contains the information about a single key to rename.

Returns:



9232
9233
9234
9235
9236
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9232

class RenameKeys < Struct.new(
  :entries)
  SENSITIVE = []
  include Aws::Structure
end