Class: Aws::CloudWatchLogs::Types::S3Configuration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::S3Configuration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Configuration for Amazon S3 destination where scheduled query results are delivered.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_identifier ⇒ String
The Amazon S3 URI where query results are delivered.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS encryption key.
-
#owner_account_id ⇒ String
The Amazon Web Services accountId for the bucket owning account.
-
#role_arn ⇒ String
The ARN of the IAM role that grants permissions to write query results to the specified Amazon S3 destination.
Instance Attribute Details
#destination_identifier ⇒ String
The Amazon S3 URI where query results are delivered. Must be a valid S3 URI format.
9312 9313 9314 9315 9316 9317 9318 9319 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9312 class S3Configuration < Struct.new( :destination_identifier, :role_arn, :owner_account_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS encryption key. Must belong to the same Amazon Web Services Region as the destination Amazon S3 bucket.
9312 9313 9314 9315 9316 9317 9318 9319 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9312 class S3Configuration < Struct.new( :destination_identifier, :role_arn, :owner_account_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#owner_account_id ⇒ String
The Amazon Web Services accountId for the bucket owning account.
9312 9313 9314 9315 9316 9317 9318 9319 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9312 class S3Configuration < Struct.new( :destination_identifier, :role_arn, :owner_account_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that grants permissions to write query results to the specified Amazon S3 destination.
9312 9313 9314 9315 9316 9317 9318 9319 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9312 class S3Configuration < Struct.new( :destination_identifier, :role_arn, :owner_account_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |