Class: Aws::CloudWatchLogs::Types::SplitStringEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This object defines one log field that will be split with the splitString processor.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#delimiterString

The separator characters to split the string entry on.

Returns:

  • (String)


9671
9672
9673
9674
9675
9676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9671

class SplitStringEntry < Struct.new(
  :source,
  :delimiter)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The key of the field to split.

Returns:

  • (String)


9671
9672
9673
9674
9675
9676
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9671

class SplitStringEntry < Struct.new(
  :source,
  :delimiter)
  SENSITIVE = []
  include Aws::Structure
end