Class: Aws::CloudWatchLogs::Types::StartLiveTailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::StartLiveTailRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_event_filter_pattern ⇒ String
An optional pattern to use to filter the results to include only log events that match the pattern.
-
#log_group_identifiers ⇒ Array<String>
An array where each item in the array is a log group to include in the Live Tail session.
-
#log_stream_name_prefixes ⇒ Array<String>
If you specify this parameter, then only log events in the log streams that have names that start with the prefixes that you specify here are included in the Live Tail session.
-
#log_stream_names ⇒ Array<String>
If you specify this parameter, then only log events in the log streams that you specify here are included in the Live Tail session.
Instance Attribute Details
#log_event_filter_pattern ⇒ String
An optional pattern to use to filter the results to include only log
events that match the pattern. For example, a filter pattern of
error 404 causes only log events that include both error and
404 to be included in the Live Tail stream.
Regular expression filter patterns are supported.
For more information about filter pattern syntax, see Filter and Pattern Syntax.
9878 9879 9880 9881 9882 9883 9884 9885 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9878 class StartLiveTailRequest < Struct.new( :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
An array where each item in the array is a log group to include in the Live Tail session.
Specify each log group by its ARN.
If you specify an ARN, the ARN can't end with an asterisk (*).
9878 9879 9880 9881 9882 9883 9884 9885 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9878 class StartLiveTailRequest < Struct.new( :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefixes ⇒ Array<String>
If you specify this parameter, then only log events in the log streams that have names that start with the prefixes that you specify here are included in the Live Tail session.
If you specify this field, you can't also specify the
logStreamNames field.
logGroupIdentifiers.
9878 9879 9880 9881 9882 9883 9884 9885 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9878 class StartLiveTailRequest < Struct.new( :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern) SENSITIVE = [] include Aws::Structure end |
#log_stream_names ⇒ Array<String>
If you specify this parameter, then only log events in the log streams that you specify here are included in the Live Tail session.
If you specify this field, you can't also specify the
logStreamNamePrefixes field.
logGroupIdentifiers.
9878 9879 9880 9881 9882 9883 9884 9885 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9878 class StartLiveTailRequest < Struct.new( :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern) SENSITIVE = [] include Aws::Structure end |