Class: Aws::CloudWatchLogs::Types::StartLiveTailResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::StartLiveTailResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#response_stream ⇒ Types::StartLiveTailResponseStream
An object that includes the stream returned by your request.
Instance Attribute Details
#response_stream ⇒ Types::StartLiveTailResponseStream
An object that includes the stream returned by your request. It can include both log events and exceptions.
7417 7418 7419 7420 7421 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7417 class StartLiveTailResponse < Struct.new( :response_stream) SENSITIVE = [] include Aws::Structure end |