Class: Aws::CloudWatchLogs::Types::StartLiveTailResponseStream
- Inherits:
-
Enumerator
- Object
- Enumerator
- Aws::CloudWatchLogs::Types::StartLiveTailResponseStream
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This object includes the stream returned by your StartLiveTail request.
EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream
Instance Method Summary collapse
Instance Method Details
#event_types ⇒ Object
11052 11053 11054 11055 11056 11057 11058 11059 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 11052 def event_types [ :session_start, :session_update, :session_timeout_exception, :session_streaming_exception ] end |