Class: Aws::CloudWatchLogs::Types::SubscriptionFilter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Represents a subscription filter.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_on_transformed_logsBoolean

This parameter is valid only for log groups that have an active log transformer. For more information about log transformers, see [PutTransformer].

If this value is true, the subscription filter is applied on the transformed version of the log events instead of the original ingested log events.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutTransformer.html

Returns:

  • (Boolean)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeInteger

The creation time of the subscription filter, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.

Returns:

  • (Integer)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#destination_arnString

The Amazon Resource Name (ARN) of the destination.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#distributionString

The method used to distribute log data to the destination, which can be either random or grouped by log stream.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#emit_system_fieldsArray<String>

The list of system fields that are included in the log events sent to the subscription destination. Returns the emitSystemFields value if it was specified when the subscription filter was created.

Returns:

  • (Array<String>)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#field_selection_criteriaString

The filter expression that specifies which log events are processed by this subscription filter based on system fields. Returns the fieldSelectionCriteria value if it was specified when the subscription filter was created.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#filter_nameString

The name of the subscription filter.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#filter_patternString

A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group.

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Returns:

  • (String)


9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
9284
9285
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9272

class SubscriptionFilter < Struct.new(
  :filter_name,
  :log_group_name,
  :filter_pattern,
  :destination_arn,
  :role_arn,
  :distribution,
  :apply_on_transformed_logs,
  :creation_time,
  :field_selection_criteria,
  :emit_system_fields)
  SENSITIVE = []
  include Aws::Structure
end