Class: Aws::CloudWatchLogs::Types::SubstituteStringEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::SubstituteStringEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This object defines one log field key that will be replaced using the substituteString processor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#from ⇒ String
The regular expression string to be replaced.
-
#source ⇒ String
The key to modify.
-
#to ⇒ String
The string to be substituted for each match of
from.
Instance Attribute Details
#from ⇒ String
The regular expression string to be replaced. Special regex characters such as [ and ] must be escaped using \\ when using double quotes and with \ when using single quotes. For more information, see Class Pattern on the Oracle web site.
10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10027 class SubstituteStringEntry < Struct.new( :source, :from, :to) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The key to modify
10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10027 class SubstituteStringEntry < Struct.new( :source, :from, :to) SENSITIVE = [] include Aws::Structure end |
#to ⇒ String
The string to be substituted for each match of from
10027 10028 10029 10030 10031 10032 10033 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10027 class SubstituteStringEntry < Struct.new( :source, :from, :to) SENSITIVE = [] include Aws::Structure end |