Class: Aws::CloudWatchLogs::Types::SuppressionPeriod

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

If you are suppressing an anomaly temporariliy, this structure defines how long the suppression period is to be.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#suppression_unitString

Specifies whether the value of ‘value` is in seconds, minutes, or hours.

Returns:

  • (String)


9361
9362
9363
9364
9365
9366
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9361

class SuppressionPeriod < Struct.new(
  :value,
  :suppression_unit)
  SENSITIVE = []
  include Aws::Structure
end

#valueInteger

Specifies the number of seconds, minutes or hours to suppress this anomaly. There is no maximum.

Returns:

  • (Integer)


9361
9362
9363
9364
9365
9366
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9361

class SuppressionPeriod < Struct.new(
  :value,
  :suppression_unit)
  SENSITIVE = []
  include Aws::Structure
end