Class: Aws::CloudWatchLogs::Types::SyslogConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Contains information about a syslog configuration associated with a log group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atInteger

The time when the syslog configuration was created, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.

Returns:

  • (Integer)


10022
10023
10024
10025
10026
10027
10028
10029
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022

class SyslogConfiguration < Struct.new(
  :log_group_arn,
  :source_type,
  :vpc_endpoint_id,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_arnString

The ARN of the log group associated with this syslog configuration.

Returns:

  • (String)


10022
10023
10024
10025
10026
10027
10028
10029
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022

class SyslogConfiguration < Struct.new(
  :log_group_arn,
  :source_type,
  :vpc_endpoint_id,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The source type for the syslog configuration.

Returns:

  • (String)


10022
10023
10024
10025
10026
10027
10028
10029
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022

class SyslogConfiguration < Struct.new(
  :log_group_arn,
  :source_type,
  :vpc_endpoint_id,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the VPC endpoint used for syslog ingestion.

Returns:

  • (String)


10022
10023
10024
10025
10026
10027
10028
10029
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022

class SyslogConfiguration < Struct.new(
  :log_group_arn,
  :source_type,
  :vpc_endpoint_id,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end