Class: Aws::CloudWatchLogs::Types::TriggerHistoryRecord

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

A record of a scheduled query execution, including execution status, timestamp, and destination processing results.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destinationsArray<Types::ScheduledQueryDestination>

Information about destination processing for this query execution.



9520
9521
9522
9523
9524
9525
9526
9527
9528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520

class TriggerHistoryRecord < Struct.new(
  :query_id,
  :execution_status,
  :triggered_timestamp,
  :error_message,
  :destinations)
  SENSITIVE = []
  include Aws::Structure
end

#error_messageString

Error message if the query execution failed.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520

class TriggerHistoryRecord < Struct.new(
  :query_id,
  :execution_status,
  :triggered_timestamp,
  :error_message,
  :destinations)
  SENSITIVE = []
  include Aws::Structure
end

#execution_statusString

The execution status of the scheduled query run.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520

class TriggerHistoryRecord < Struct.new(
  :query_id,
  :execution_status,
  :triggered_timestamp,
  :error_message,
  :destinations)
  SENSITIVE = []
  include Aws::Structure
end

#query_idString

The unique identifier for this query execution.

Returns:

  • (String)


9520
9521
9522
9523
9524
9525
9526
9527
9528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520

class TriggerHistoryRecord < Struct.new(
  :query_id,
  :execution_status,
  :triggered_timestamp,
  :error_message,
  :destinations)
  SENSITIVE = []
  include Aws::Structure
end

#triggered_timestampInteger

The timestamp when the scheduled query execution was triggered.

Returns:

  • (Integer)


9520
9521
9522
9523
9524
9525
9526
9527
9528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520

class TriggerHistoryRecord < Struct.new(
  :query_id,
  :execution_status,
  :triggered_timestamp,
  :error_message,
  :destinations)
  SENSITIVE = []
  include Aws::Structure
end