Class: Aws::CloudWatchLogs::Types::TypeConverter
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::TypeConverter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Use this processor to convert a value type associated with the specified key to the specified type. It’s a casting processor that changes the types of the specified fields. Values can be converted into one of the following datatypes: integer, double, string and boolean.
For more information about this processor including examples, see [ trimString] in the *CloudWatch Logs User Guide*.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#entries ⇒ Array<Types::TypeConverterEntry>
An array of
TypeConverterEntryobjects, where each object contains the information about one field to change the type of.
Instance Attribute Details
#entries ⇒ Array<Types::TypeConverterEntry>
An array of TypeConverterEntry objects, where each object contains the information about one field to change the type of.
9607 9608 9609 9610 9611 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9607 class TypeConverter < Struct.new( :entries) SENSITIVE = [] include Aws::Structure end |