Class: Aws::CloudWatchLogs::Types::TypeConverterEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This object defines one value type that will be converted using the [ typeConverter][1] processor.

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-typeConverter

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

The key with the value that is to be converted to a different type.

Returns:

  • (String)


9697
9698
9699
9700
9701
9702
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9697

class TypeConverterEntry < Struct.new(
  :key,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type to convert the field value to. Valid values are integer, double, string and boolean.

Returns:

  • (String)


9697
9698
9699
9700
9701
9702
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9697

class TypeConverterEntry < Struct.new(
  :key,
  :type)
  SENSITIVE = []
  include Aws::Structure
end