Class: Aws::CloudWatchLogs::Types::UpdateAnomalyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateAnomalyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector that this operation is to act on.
-
#anomaly_id ⇒ String
If you are suppressing or unsuppressing an anomaly, specify its unique ID here.
-
#baseline ⇒ Boolean
Set this to ‘true` to prevent CloudWatch Logs from displaying this behavior as an anomaly in the future.
-
#pattern_id ⇒ String
If you are suppressing or unsuppressing an pattern, specify its unique ID here.
-
#suppression_period ⇒ Types::SuppressionPeriod
If you are temporarily suppressing an anomaly or pattern, use this structure to specify how long the suppression is to last.
-
#suppression_type ⇒ String
Use this to specify whether the suppression to be temporary or infinite.
Instance Attribute Details
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector that this operation is to act on.
10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10083 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period, :baseline) SENSITIVE = [] include Aws::Structure end |
#anomaly_id ⇒ String
If you are suppressing or unsuppressing an anomaly, specify its unique ID here. You can find anomaly IDs by using the
- ListAnomalies][1
-
operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListAnomalies.html
10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10083 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period, :baseline) SENSITIVE = [] include Aws::Structure end |
#baseline ⇒ Boolean
Set this to ‘true` to prevent CloudWatch Logs from displaying this behavior as an anomaly in the future. The behavior is then treated as baseline behavior. However, if similar but more severe occurrences of this behavior occur in the future, those will still be reported as anomalies.
The default is ‘false`
10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10083 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period, :baseline) SENSITIVE = [] include Aws::Structure end |
#pattern_id ⇒ String
If you are suppressing or unsuppressing an pattern, specify its unique ID here. You can find pattern IDs by using the
- ListAnomalies][1
-
operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListAnomalies.html
10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10083 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period, :baseline) SENSITIVE = [] include Aws::Structure end |
#suppression_period ⇒ Types::SuppressionPeriod
If you are temporarily suppressing an anomaly or pattern, use this structure to specify how long the suppression is to last.
10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10083 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period, :baseline) SENSITIVE = [] include Aws::Structure end |
#suppression_type ⇒ String
Use this to specify whether the suppression to be temporary or infinite. If you specify ‘LIMITED`, you must also specify a `suppressionPeriod`. If you specify `INFINITE`, any value for `suppressionPeriod` is ignored.
10083 10084 10085 10086 10087 10088 10089 10090 10091 10092 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10083 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period, :baseline) SENSITIVE = [] include Aws::Structure end |