Class: Aws::CloudWatchLogs::Types::UpdateLogAnomalyDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateLogAnomalyDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector that you want to update.
-
#anomaly_visibility_time ⇒ Integer
The number of days to use as the life cycle of anomalies.
-
#enabled ⇒ Boolean
Use this parameter to pause or restart the anomaly detector.
-
#evaluation_frequency ⇒ String
Specifies how often the anomaly detector runs and look for anomalies.
-
#filter_pattern ⇒ String
A symbolic description of how CloudWatch Logs should interpret the data in each log event.
Instance Attribute Details
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector that you want to update.
9821 9822 9823 9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9821 class UpdateLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn, :evaluation_frequency, :filter_pattern, :anomaly_visibility_time, :enabled) SENSITIVE = [] include Aws::Structure end |
#anomaly_visibility_time ⇒ Integer
The number of days to use as the life cycle of anomalies. After this time, anomalies are automatically baselined and the anomaly detector model will treat new occurrences of similar event as normal. Therefore, if you do not correct the cause of an anomaly during this time, it will be considered normal going forward and will not be detected.
9821 9822 9823 9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9821 class UpdateLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn, :evaluation_frequency, :filter_pattern, :anomaly_visibility_time, :enabled) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
Use this parameter to pause or restart the anomaly detector.
9821 9822 9823 9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9821 class UpdateLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn, :evaluation_frequency, :filter_pattern, :anomaly_visibility_time, :enabled) SENSITIVE = [] include Aws::Structure end |
#evaluation_frequency ⇒ String
Specifies how often the anomaly detector runs and look for anomalies. Set this value according to the frequency that the log group receives new logs. For example, if the log group receives new log events every 10 minutes, then setting evaluationFrequency to FIFTEEN_MIN might be appropriate.
9821 9822 9823 9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9821 class UpdateLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn, :evaluation_frequency, :filter_pattern, :anomaly_visibility_time, :enabled) SENSITIVE = [] include Aws::Structure end |
#filter_pattern ⇒ String
A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.
9821 9822 9823 9824 9825 9826 9827 9828 9829 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9821 class UpdateLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn, :evaluation_frequency, :filter_pattern, :anomaly_visibility_time, :enabled) SENSITIVE = [] include Aws::Structure end |