Class: Aws::CloudWatchLogs::Types::UpdateLookupTableResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateLookupTableResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_time ⇒ Integer
The time when the lookup table was last updated, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#lookup_table_arn ⇒ String
The ARN of the lookup table that was updated.
Instance Attribute Details
#last_updated_time ⇒ Integer
The time when the lookup table was last updated, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
10216 10217 10218 10219 10220 10221 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10216 class UpdateLookupTableResponse < Struct.new( :lookup_table_arn, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#lookup_table_arn ⇒ String
The ARN of the lookup table that was updated.
10216 10217 10218 10219 10220 10221 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10216 class UpdateLookupTableResponse < Struct.new( :lookup_table_arn, :last_updated_time) SENSITIVE = [] include Aws::Structure end |