Class: Aws::CloudWatchLogs::Types::UpdateScheduledQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An updated description for the scheduled query.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configurationTypes::DestinationConfiguration

The updated configuration for where to deliver query results.



9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The updated ARN of the IAM role that grants permissions to execute the query and deliver results.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#identifierString

The ARN or name of the scheduled query to update.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

The updated array of log group names or ARNs to query.

Returns:

  • (Array<String>)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#query_languageString

The updated query language for the scheduled query.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The updated query string to execute.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_end_timeInteger

The updated end time for the scheduled query in Unix epoch format.

Returns:

  • (Integer)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expressionString

The updated cron expression that defines when the scheduled query runs.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_start_timeInteger

The updated start time for the scheduled query in Unix epoch format.

Returns:

  • (Integer)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_offsetInteger

The updated time offset in seconds that defines the lookback period for the query.

Returns:

  • (Integer)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The updated state of the scheduled query.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#timezoneString

The updated timezone for evaluating the schedule expression.

Returns:

  • (String)


9888
9889
9890
9891
9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888

class UpdateScheduledQueryRequest < Struct.new(
  :identifier,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :destination_configuration,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :state)
  SENSITIVE = []
  include Aws::Structure
end