Class: Aws::CloudWatchLogs::Types::UpperCaseString
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpperCaseString
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This processor converts a string field to uppercase.
For more information about this processor including examples, see upperCaseString in the CloudWatch Logs User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#with_keys ⇒ Array<String>
The array of containing the keys of the field to convert to uppercase.
Instance Attribute Details
#with_keys ⇒ Array<String>
The array of containing the keys of the field to convert to uppercase.
10842 10843 10844 10845 10846 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10842 class UpperCaseString < Struct.new( :with_keys) SENSITIVE = [] include Aws::Structure end |