Class: Aws::CloudWatchLogs::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudWatchLogs::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudwatchlogs/client.rb
Overview
An API client for CloudWatchLogs. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::CloudWatchLogs::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_kms_key(params = {}) ⇒ Struct
Associates the specified Key Management Service customer master key (CMK) with the specified log group.
-
#cancel_export_task(params = {}) ⇒ Struct
Cancels the specified export task.
-
#create_export_task(params = {}) ⇒ Types::CreateExportTaskResponse
Creates an export task, which allows you to efficiently export data from a log group to an Amazon S3 bucket.
-
#create_log_group(params = {}) ⇒ Struct
Creates a log group with the specified name.
-
#create_log_stream(params = {}) ⇒ Struct
Creates a log stream for the specified log group.
-
#delete_destination(params = {}) ⇒ Struct
Deletes the specified destination, and eventually disables all the subscription filters that publish to it.
-
#delete_log_group(params = {}) ⇒ Struct
Deletes the specified log group and permanently deletes all the archived log events associated with the log group.
-
#delete_log_stream(params = {}) ⇒ Struct
Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream.
-
#delete_metric_filter(params = {}) ⇒ Struct
Deletes the specified metric filter.
-
#delete_query_definition(params = {}) ⇒ Types::DeleteQueryDefinitionResponse
Deletes a saved CloudWatch Logs Insights query definition.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy from this account.
-
#delete_retention_policy(params = {}) ⇒ Struct
Deletes the specified retention policy.
-
#delete_subscription_filter(params = {}) ⇒ Struct
Deletes the specified subscription filter.
-
#describe_destinations(params = {}) ⇒ Types::DescribeDestinationsResponse
Lists all your destinations.
-
#describe_export_tasks(params = {}) ⇒ Types::DescribeExportTasksResponse
Lists the specified export tasks.
-
#describe_log_groups(params = {}) ⇒ Types::DescribeLogGroupsResponse
Lists the specified log groups.
-
#describe_log_streams(params = {}) ⇒ Types::DescribeLogStreamsResponse
Lists the log streams for the specified log group.
-
#describe_metric_filters(params = {}) ⇒ Types::DescribeMetricFiltersResponse
Lists the specified metric filters.
-
#describe_queries(params = {}) ⇒ Types::DescribeQueriesResponse
Returns a list of CloudWatch Logs Insights queries that are scheduled, executing, or have been executed recently in this account.
-
#describe_query_definitions(params = {}) ⇒ Types::DescribeQueryDefinitionsResponse
This operation returns a paginated list of your saved CloudWatch Logs Insights query definitions.
-
#describe_resource_policies(params = {}) ⇒ Types::DescribeResourcePoliciesResponse
Lists the resource policies in this account.
-
#describe_subscription_filters(params = {}) ⇒ Types::DescribeSubscriptionFiltersResponse
Lists the subscription filters for the specified log group.
-
#disassociate_kms_key(params = {}) ⇒ Struct
Disassociates the associated Key Management Service customer master key (CMK) from the specified log group.
-
#filter_log_events(params = {}) ⇒ Types::FilterLogEventsResponse
Lists log events from the specified log group.
-
#get_log_events(params = {}) ⇒ Types::GetLogEventsResponse
Lists log events from the specified log stream.
-
#get_log_group_fields(params = {}) ⇒ Types::GetLogGroupFieldsResponse
Returns a list of the fields that are included in log events in the specified log group, along with the percentage of log events that contain each field.
-
#get_log_record(params = {}) ⇒ Types::GetLogRecordResponse
Retrieves all of the fields and values of a single log event.
-
#get_query_results(params = {}) ⇒ Types::GetQueryResultsResponse
Returns the results from the specified query.
-
#list_tags_log_group(params = {}) ⇒ Types::ListTagsLogGroupResponse
Lists the tags for the specified log group.
-
#put_destination(params = {}) ⇒ Types::PutDestinationResponse
Creates or updates a destination.
-
#put_destination_policy(params = {}) ⇒ Struct
Creates or updates an access policy associated with an existing destination.
-
#put_log_events(params = {}) ⇒ Types::PutLogEventsResponse
Uploads a batch of log events to the specified log stream.
-
#put_metric_filter(params = {}) ⇒ Struct
Creates or updates a metric filter and associates it with the specified log group.
-
#put_query_definition(params = {}) ⇒ Types::PutQueryDefinitionResponse
Creates or updates a query definition for CloudWatch Logs Insights.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53.
-
#put_retention_policy(params = {}) ⇒ Struct
Sets the retention of the specified log group.
-
#put_subscription_filter(params = {}) ⇒ Struct
Creates or updates a subscription filter and associates it with the specified log group.
-
#start_query(params = {}) ⇒ Types::StartQueryResponse
Schedules a query of a log group using CloudWatch Logs Insights.
-
#stop_query(params = {}) ⇒ Types::StopQueryResponse
Stops a CloudWatch Logs Insights query that is in progress.
-
#tag_log_group(params = {}) ⇒ Struct
Adds or updates the specified tags for the specified log group.
-
#test_metric_filter(params = {}) ⇒ Types::TestMetricFilterResponse
Tests the filter pattern of a metric filter against a sample of log event messages.
-
#untag_log_group(params = {}) ⇒ Struct
Removes the specified tags from the specified log group.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
356 357 358 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 356 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2647 2648 2649 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2647 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2650 2651 2652 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2650 def errors_module Errors end |
Instance Method Details
#associate_kms_key(params = {}) ⇒ Struct
Associates the specified Key Management Service customer master key (CMK) with the specified log group.
Associating an KMS CMK with a log group overrides any existing associations between the log group and a CMK. After a CMK is associated with a log group, all newly ingested data for the log group is encrypted using the CMK. This association is stored as long as the data encrypted with the CMK is still within CloudWatch Logs. This enables CloudWatch Logs to decrypt this data whenever it is requested.
CloudWatch Logs supports only symmetric CMKs. Do not use an associate an asymmetric CMK with your log group. For more information, see [Using Symmetric and Asymmetric Keys].
It can take up to 5 minutes for this operation to take effect.
If you attempt to associate a CMK with a log group but the CMK does not exist or the CMK is disabled, you receive an `InvalidParameterException` error.
[1]: docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html
413 414 415 416 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 413 def associate_kms_key(params = {}, = {}) req = build_request(:associate_kms_key, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2625 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-cloudwatchlogs' context[:gem_version] = '1.51.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_export_task(params = {}) ⇒ Struct
Cancels the specified export task.
The task must be in the `PENDING` or `RUNNING` state.
437 438 439 440 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 437 def cancel_export_task(params = {}, = {}) req = build_request(:cancel_export_task, params) req.send_request() end |
#create_export_task(params = {}) ⇒ Types::CreateExportTaskResponse
Creates an export task, which allows you to efficiently export data from a log group to an Amazon S3 bucket. When you perform a `CreateExportTask` operation, you must use credentials that have permission to write to the S3 bucket that you specify as the destination.
This is an asynchronous call. If all the required information is provided, this operation initiates an export task and responds with the ID of the task. After the task has started, you can use
- DescribeExportTasks][1
-
to get the status of the export task. Each
account can only have one active (`RUNNING` or `PENDING`) export task at a time. To cancel an export task, use [CancelExportTask].
You can export logs from multiple log groups or multiple time ranges to the same S3 bucket. To separate out log data for each export task, you can specify a prefix to be used as the Amazon S3 key prefix for all exported objects.
Exporting to S3 buckets that are encrypted with AES-256 is supported. Exporting to S3 buckets encrypted with SSE-KMS is not supported.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeExportTasks.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CancelExportTask.html
520 521 522 523 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 520 def create_export_task(params = {}, = {}) req = build_request(:create_export_task, params) req.send_request() end |
#create_log_group(params = {}) ⇒ Struct
Creates a log group with the specified name. You can create up to 20,000 log groups per account.
You must use the following guidelines when naming a log group:
-
Log group names must be unique within a region for an Amazon Web Services account.
-
Log group names can be between 1 and 512 characters long.
-
Log group names consist of the following characters: a-z, A-Z, 0-9, '_' (underscore), '-' (hyphen), '/' (forward slash), '.' (period), and '#' (number sign)
When you create a log group, by default the log events in the log group never expire. To set a retention policy so that events expire and are deleted after a specified time, use [PutRetentionPolicy].
If you associate a Key Management Service customer master key (CMK) with the log group, ingested data is encrypted using the CMK. This association is stored as long as the data encrypted with the CMK is still within CloudWatch Logs. This enables CloudWatch Logs to decrypt this data whenever it is requested.
If you attempt to associate a CMK with the log group but the CMK does not exist or the CMK is disabled, you receive an `InvalidParameterException` error.
CloudWatch Logs supports only symmetric CMKs. Do not associate an asymmetric CMK with your log group. For more information, see [Using Symmetric and Asymmetric Keys].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutRetentionPolicy.html [2]: docs.aws.amazon.com/kms/latest/developerguide/symmetric-asymmetric.html
603 604 605 606 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 603 def create_log_group(params = {}, = {}) req = build_request(:create_log_group, params) req.send_request() end |
#create_log_stream(params = {}) ⇒ Struct
Creates a log stream for the specified log group. A log stream is a sequence of log events that originate from a single source, such as an application instance or a resource that is being monitored.
There is no limit on the number of log streams that you can create for a log group. There is a limit of 50 TPS on `CreateLogStream` operations, after which transactions are throttled.
You must use the following guidelines when naming a log stream:
-
Log stream names must be unique within the log group.
-
Log stream names can be between 1 and 512 characters long.
-
The ':' (colon) and '*' (asterisk) characters are not allowed.
643 644 645 646 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 643 def create_log_stream(params = {}, = {}) req = build_request(:create_log_stream, params) req.send_request() end |
#delete_destination(params = {}) ⇒ Struct
Deletes the specified destination, and eventually disables all the subscription filters that publish to it. This operation does not delete the physical resource encapsulated by the destination.
667 668 669 670 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 667 def delete_destination(params = {}, = {}) req = build_request(:delete_destination, params) req.send_request() end |
#delete_log_group(params = {}) ⇒ Struct
Deletes the specified log group and permanently deletes all the archived log events associated with the log group.
690 691 692 693 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 690 def delete_log_group(params = {}, = {}) req = build_request(:delete_log_group, params) req.send_request() end |
#delete_log_stream(params = {}) ⇒ Struct
Deletes the specified log stream and permanently deletes all the archived log events associated with the log stream.
717 718 719 720 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 717 def delete_log_stream(params = {}, = {}) req = build_request(:delete_log_stream, params) req.send_request() end |
#delete_metric_filter(params = {}) ⇒ Struct
Deletes the specified metric filter.
743 744 745 746 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 743 def delete_metric_filter(params = {}, = {}) req = build_request(:delete_metric_filter, params) req.send_request() end |
#delete_query_definition(params = {}) ⇒ Types::DeleteQueryDefinitionResponse
Deletes a saved CloudWatch Logs Insights query definition. A query definition contains details about a saved CloudWatch Logs Insights query.
Each `DeleteQueryDefinition` operation can delete one query definition.
You must have the `logs:DeleteQueryDefinition` permission to be able to perform this operation.
785 786 787 788 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 785 def delete_query_definition(params = {}, = {}) req = build_request(:delete_query_definition, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes a resource policy from this account. This revokes the access of the identities in that policy to put log events to this account.
808 809 810 811 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 808 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_retention_policy(params = {}) ⇒ Struct
Deletes the specified retention policy.
Log events do not expire if they belong to log groups without a retention policy.
833 834 835 836 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 833 def delete_retention_policy(params = {}, = {}) req = build_request(:delete_retention_policy, params) req.send_request() end |
#delete_subscription_filter(params = {}) ⇒ Struct
Deletes the specified subscription filter.
859 860 861 862 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 859 def delete_subscription_filter(params = {}, = {}) req = build_request(:delete_subscription_filter, params) req.send_request() end |
#describe_destinations(params = {}) ⇒ Types::DescribeDestinationsResponse
Lists all your destinations. The results are ASCII-sorted by destination name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
909 910 911 912 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 909 def describe_destinations(params = {}, = {}) req = build_request(:describe_destinations, params) req.send_request() end |
#describe_export_tasks(params = {}) ⇒ Types::DescribeExportTasksResponse
Lists the specified export tasks. You can list all your export tasks or filter the results based on task ID or task status.
967 968 969 970 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 967 def describe_export_tasks(params = {}, = {}) req = build_request(:describe_export_tasks, params) req.send_request() end |
#describe_log_groups(params = {}) ⇒ Types::DescribeLogGroupsResponse
Lists the specified log groups. You can list all your log groups or filter the results by prefix. The results are ASCII-sorted by log group name.
CloudWatch Logs doesn’t support IAM policies that control access to the `DescribeLogGroups` action by using the `aws:ResourceTag/key-name ` condition key. Other CloudWatch Logs actions do support the use of the `aws:ResourceTag/key-name ` condition key to control access. For more information about using tags to control access, see [Controlling access to Amazon Web Services resources using tags].
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1029 1030 1031 1032 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1029 def describe_log_groups(params = {}, = {}) req = build_request(:describe_log_groups, params) req.send_request() end |
#describe_log_streams(params = {}) ⇒ Types::DescribeLogStreamsResponse
Lists the log streams for the specified log group. You can list all the log streams or filter the results by prefix. You can also control how the results are ordered.
This operation has a limit of five transactions per second, after which transactions are throttled.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1112 1113 1114 1115 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1112 def describe_log_streams(params = {}, = {}) req = build_request(:describe_log_streams, params) req.send_request() end |
#describe_metric_filters(params = {}) ⇒ Types::DescribeMetricFiltersResponse
Lists the specified metric filters. You can list all of the metric filters or filter the results by log name, prefix, metric name, or metric namespace. The results are ASCII-sorted by filter name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1185 1186 1187 1188 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1185 def describe_metric_filters(params = {}, = {}) req = build_request(:describe_metric_filters, params) req.send_request() end |
#describe_queries(params = {}) ⇒ Types::DescribeQueriesResponse
Returns a list of CloudWatch Logs Insights queries that are scheduled, executing, or have been executed recently in this account. You can request all queries or limit it to queries of a specific log group or queries with a certain status.
1238 1239 1240 1241 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1238 def describe_queries(params = {}, = {}) req = build_request(:describe_queries, params) req.send_request() end |
#describe_query_definitions(params = {}) ⇒ Types::DescribeQueryDefinitionsResponse
This operation returns a paginated list of your saved CloudWatch Logs Insights query definitions.
You can use the `queryDefinitionNamePrefix` parameter to limit the results to only the query definitions that have names that start with a certain string.
1290 1291 1292 1293 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1290 def describe_query_definitions(params = {}, = {}) req = build_request(:describe_query_definitions, params) req.send_request() end |
#describe_resource_policies(params = {}) ⇒ Types::DescribeResourcePoliciesResponse
Lists the resource policies in this account.
1329 1330 1331 1332 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1329 def describe_resource_policies(params = {}, = {}) req = build_request(:describe_resource_policies, params) req.send_request() end |
#describe_subscription_filters(params = {}) ⇒ Types::DescribeSubscriptionFiltersResponse
Lists the subscription filters for the specified log group. You can list all the subscription filters or filter the results by prefix. The results are ASCII-sorted by filter name.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1385 1386 1387 1388 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1385 def describe_subscription_filters(params = {}, = {}) req = build_request(:describe_subscription_filters, params) req.send_request() end |
#disassociate_kms_key(params = {}) ⇒ Struct
Disassociates the associated Key Management Service customer master key (CMK) from the specified log group.
After the KMS CMK is disassociated from the log group, CloudWatch Logs stops encrypting newly ingested data for the log group. All previously ingested data remains encrypted, and CloudWatch Logs requires permissions for the CMK whenever the encrypted data is requested.
Note that it can take up to 5 minutes for this operation to take effect.
1416 1417 1418 1419 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1416 def disassociate_kms_key(params = {}, = {}) req = build_request(:disassociate_kms_key, params) req.send_request() end |
#filter_log_events(params = {}) ⇒ Types::FilterLogEventsResponse
Lists log events from the specified log group. You can list all the log events or filter the results using a filter pattern, a time range, and the name of the log stream.
By default, this operation returns as many log events as can fit in 1 MB (up to 10,000 log events) or all the events found within the time range that you specify. If the results include a token, then there are more log events available, and you can get additional results by specifying the token in a subsequent call. This operation can return empty results while there are more log events available through the token.
The returned log events are sorted by event timestamp, the timestamp when the event was ingested by CloudWatch Logs, and the ID of the `PutLogEvents` request.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1534 1535 1536 1537 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1534 def filter_log_events(params = {}, = {}) req = build_request(:filter_log_events, params) req.send_request() end |
#get_log_events(params = {}) ⇒ Types::GetLogEventsResponse
Lists log events from the specified log stream. You can list all of the log events or filter using a time range.
By default, this operation returns as many log events as can fit in a response size of 1MB (up to 10,000 log events). You can get additional log events by specifying one of the tokens in a subsequent call. This operation can return empty results while there are more log events available through the token.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1616 1617 1618 1619 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1616 def get_log_events(params = {}, = {}) req = build_request(:get_log_events, params) req.send_request() end |
#get_log_group_fields(params = {}) ⇒ Types::GetLogGroupFieldsResponse
Returns a list of the fields that are included in log events in the specified log group, along with the percentage of log events that contain each field. The search is limited to a time period that you specify.
In the results, fields that start with @ are fields generated by CloudWatch Logs. For example, `@timestamp` is the timestamp of each log event. For more information about the fields that are generated by CloudWatch logs, see [Supported Logs and Discovered Fields].
The response results are sorted by the frequency percentage, starting with the highest percentage.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData-discoverable-fields.html
1670 1671 1672 1673 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1670 def get_log_group_fields(params = {}, = {}) req = build_request(:get_log_group_fields, params) req.send_request() end |
#get_log_record(params = {}) ⇒ Types::GetLogRecordResponse
Retrieves all of the fields and values of a single log event. All fields are retrieved, even if the original query that produced the `logRecordPointer` retrieved only a subset of fields. Fields are returned as field name/field value pairs.
The full unparsed log event is returned within `@message`.
1708 1709 1710 1711 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1708 def get_log_record(params = {}, = {}) req = build_request(:get_log_record, params) req.send_request() end |
#get_query_results(params = {}) ⇒ Types::GetQueryResultsResponse
Returns the results from the specified query.
Only the fields requested in the query are returned, along with a `@ptr` field, which is the identifier for the log record. You can use the value of `@ptr` in a [GetLogRecord] operation to get the full log record.
`GetQueryResults` does not start a query execution. To run a query, use [StartQuery].
If the value of the `Status` field in the output is `Running`, this operation returns only partial results. If you see a value of `Scheduled` or `Running` for the status, you can retry the operation later to see the final results.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetLogRecord.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html
1763 1764 1765 1766 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1763 def get_query_results(params = {}, = {}) req = build_request(:get_query_results, params) req.send_request() end |
#list_tags_log_group(params = {}) ⇒ Types::ListTagsLogGroupResponse
Lists the tags for the specified log group.
1792 1793 1794 1795 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1792 def (params = {}, = {}) req = build_request(:list_tags_log_group, params) req.send_request() end |
#put_destination(params = {}) ⇒ Types::PutDestinationResponse
Creates or updates a destination. This operation is used only to create destinations for cross-account subscriptions.
A destination encapsulates a physical resource (such as an Amazon Kinesis stream) and enables you to subscribe to a real-time stream of log events for a different account, ingested using [PutLogEvents].
Through an access policy, a destination controls what is written to it. By default, `PutDestination` does not set any access policy with the destination, which means a cross-account user cannot call
- PutSubscriptionFilter][2
-
against this destination. To enable this,
the destination owner must call [PutDestinationPolicy] after `PutDestination`.
To perform a `PutDestination` operation, you must also have the `iam:PassRole` permission.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutSubscriptionFilter.html [3]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDestinationPolicy.html
1856 1857 1858 1859 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1856 def put_destination(params = {}, = {}) req = build_request(:put_destination, params) req.send_request() end |
#put_destination_policy(params = {}) ⇒ Struct
Creates or updates an access policy associated with an existing destination. An access policy is an [IAM policy document] that is used to authorize claims to register a subscription filter against a given destination.
If multiple Amazon Web Services accounts are sending logs to this destination, each sender account must be listed separately in the policy. The policy does not support specifying `*` as the Principal or the use of the `aws:PrincipalOrgId` global key.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/policies_overview.html
1914 1915 1916 1917 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 1914 def put_destination_policy(params = {}, = {}) req = build_request(:put_destination_policy, params) req.send_request() end |
#put_log_events(params = {}) ⇒ Types::PutLogEventsResponse
Uploads a batch of log events to the specified log stream.
You must include the sequence token obtained from the response of the previous call. An upload in a newly created log stream does not require a sequence token. You can also get the sequence token in the `expectedSequenceToken` field from `InvalidSequenceTokenException`. If you call `PutLogEvents` twice within a narrow time period using the same value for `sequenceToken`, both calls might be successful or one might be rejected.
The batch of events must satisfy the following constraints:
-
The maximum batch size is 1,048,576 bytes. This size is calculated as the sum of all event messages in UTF-8, plus 26 bytes for each log event.
-
None of the log events in the batch can be more than 2 hours in the future.
-
None of the log events in the batch can be older than 14 days or older than the retention period of the log group.
-
The log events in the batch must be in chronological order by their timestamp. The timestamp is the time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. (In Amazon Web Services Tools for PowerShell and the Amazon Web Services SDK for .NET, the timestamp is specified in .NET format: yyyy-mm-ddThh:mm:ss. For example, 2017-09-15T13:45:30.)
-
A batch of log events in a single request cannot span more than 24 hours. Otherwise, the operation fails.
-
The maximum number of log events in a batch is 10,000.
-
There is a quota of 5 requests per second per log stream. Additional requests are throttled. This quota can't be changed.
If a call to `PutLogEvents` returns “UnrecognizedClientException” the most likely cause is an invalid Amazon Web Services access key ID or secret key.
2011 2012 2013 2014 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2011 def put_log_events(params = {}, = {}) req = build_request(:put_log_events, params) req.send_request() end |
#put_metric_filter(params = {}) ⇒ Struct
Creates or updates a metric filter and associates it with the specified log group. Metric filters allow you to configure rules to extract metric data from log events ingested through [PutLogEvents].
The maximum number of metric filters that can be associated with a log group is 100.
When you create a metric filter, you can also optionally assign a unit and dimensions to the metric that is created.
Metrics extracted from log events are charged as custom metrics. To prevent unexpected high charges, do not specify high-cardinality fields such as `IPAddress` or `requestID` as dimensions. Each different value found for a dimension is treated as a separate metric and accrues charges as a separate custom metric.
To help prevent accidental high charges, Amazon disables a metric
filter if it generates 1000 different name/value pairs for the dimensions that you have specified within a certain amount of time.
You can also set up a billing alarm to alert you if your charges are
higher than expected. For more information, see [ Creating a Billing Alarm to Monitor Your Estimated Amazon Web Services Charges].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html [2]: docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/monitor_estimated_charges_with_cloudwatch.html
2085 2086 2087 2088 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2085 def put_metric_filter(params = {}, = {}) req = build_request(:put_metric_filter, params) req.send_request() end |
#put_query_definition(params = {}) ⇒ Types::PutQueryDefinitionResponse
Creates or updates a query definition for CloudWatch Logs Insights. For more information, see [Analyzing Log Data with CloudWatch Logs Insights].
To update a query definition, specify its `queryDefinitionId` in your request. The values of `name`, `queryString`, and `logGroupNames` are changed to the values that you specify in your update operation. No current values are retained from the current query definition. For example, if you update a current query definition that includes log groups, and you don't specify the `logGroupNames` parameter in your update operation, the query definition changes to contain no log groups.
You must have the `logs:PutQueryDefinition` permission to be able to perform this operation.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AnalyzingLogData.html
2171 2172 2173 2174 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2171 def put_query_definition(params = {}, = {}) req = build_request(:put_query_definition, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53. An account can have up to 10 resource policies per Amazon Web Services Region.
2237 2238 2239 2240 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2237 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#put_retention_policy(params = {}) ⇒ Struct
Sets the retention of the specified log group. A retention policy allows you to configure the number of days for which to retain log events in the specified log group.
2274 2275 2276 2277 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2274 def put_retention_policy(params = {}, = {}) req = build_request(:put_retention_policy, params) req.send_request() end |
#put_subscription_filter(params = {}) ⇒ Struct
Creates or updates a subscription filter and associates it with the specified log group. Subscription filters allow you to subscribe to a real-time stream of log events ingested through [PutLogEvents] and have them delivered to a specific destination. When log events are sent to the receiving service, they are Base64 encoded and compressed with the gzip format.
The following destinations are supported for subscription filters:
-
An Amazon Kinesis stream belonging to the same account as the subscription filter, for same-account delivery.
-
A logical destination that belongs to a different account, for cross-account delivery.
-
An Amazon Kinesis Firehose delivery stream that belongs to the same account as the subscription filter, for same-account delivery.
-
An Lambda function that belongs to the same account as the subscription filter, for same-account delivery.
Each log group can have up to two subscription filters associated with it. If you are updating an existing filter, you must specify the correct name in `filterName`.
To perform a `PutSubscriptionFilter` operation, you must also have the `iam:PassRole` permission.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutLogEvents.html
2381 2382 2383 2384 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2381 def put_subscription_filter(params = {}, = {}) req = build_request(:put_subscription_filter, params) req.send_request() end |
#start_query(params = {}) ⇒ Types::StartQueryResponse
Schedules a query of a log group using CloudWatch Logs Insights. You specify the log group and time range to query and the query string to use.
For more information, see [CloudWatch Logs Insights Query Syntax].
Queries time out after 15 minutes of execution. If your queries are timing out, reduce the time range being searched or partition your query into a number of queries.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html
2459 2460 2461 2462 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2459 def start_query(params = {}, = {}) req = build_request(:start_query, params) req.send_request() end |
#stop_query(params = {}) ⇒ Types::StopQueryResponse
Stops a CloudWatch Logs Insights query that is in progress. If the query has already ended, the operation returns an error indicating that the specified query is not running.
2490 2491 2492 2493 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2490 def stop_query(params = {}, = {}) req = build_request(:stop_query, params) req.send_request() end |
#tag_log_group(params = {}) ⇒ Struct
Adds or updates the specified tags for the specified log group.
To list the tags for a log group, use [ListTagsLogGroup]. To remove tags, use [UntagLogGroup].
For more information about tags, see [Tag Log Groups in Amazon CloudWatch Logs] in the *Amazon CloudWatch Logs User Guide*.
CloudWatch Logs doesn’t support IAM policies that prevent users from assigning specified tags to log groups using the `aws:Resource/key-name ` or `aws:TagKeys` condition keys. For more information about using tags to control access, see [Controlling access to Amazon Web Services resources using tags].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsLogGroup.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UntagLogGroup.html [3]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Working-with-log-groups-and-streams.html#log-group-tagging [4]: docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html
2537 2538 2539 2540 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2537 def tag_log_group(params = {}, = {}) req = build_request(:tag_log_group, params) req.send_request() end |
#test_metric_filter(params = {}) ⇒ Types::TestMetricFilterResponse
Tests the filter pattern of a metric filter against a sample of log event messages. You can use this operation to validate the correctness of a metric filter pattern.
2578 2579 2580 2581 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2578 def test_metric_filter(params = {}, = {}) req = build_request(:test_metric_filter, params) req.send_request() end |
#untag_log_group(params = {}) ⇒ Struct
Removes the specified tags from the specified log group.
To list the tags for a log group, use [ListTagsLogGroup]. To add tags, use [TagLogGroup].
CloudWatch Logs doesn’t support IAM policies that prevent users from assigning specified tags to log groups using the `aws:Resource/key-name ` or `aws:TagKeys` condition keys.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListTagsLogGroup.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_TagLogGroup.html
2616 2617 2618 2619 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2616 def untag_log_group(params = {}, = {}) req = build_request(:untag_log_group, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2640 2641 2642 |
# File 'lib/aws-sdk-cloudwatchlogs/client.rb', line 2640 def waiter_names [] end |