Module: Aws::CloudWatchLogs::Types
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AccountPolicy, AddKeyEntry, AddKeys, AggregateLogGroupSummary, Anomaly, AnomalyDetector, AssociateKmsKeyRequest, AssociateSourceToS3TableIntegrationRequest, AssociateSourceToS3TableIntegrationResponse, CSV, CancelExportTaskRequest, CancelImportTaskRequest, CancelImportTaskResponse, ConfigurationTemplate, ConfigurationTemplateDeliveryConfigValues, ConflictException, CopyValue, CopyValueEntry, CreateDeliveryRequest, CreateDeliveryResponse, CreateExportTaskRequest, CreateExportTaskResponse, CreateImportTaskRequest, CreateImportTaskResponse, CreateLogAnomalyDetectorRequest, CreateLogAnomalyDetectorResponse, CreateLogGroupRequest, CreateLogStreamRequest, CreateLookupTableRequest, CreateLookupTableResponse, CreateScheduledQueryRequest, CreateScheduledQueryResponse, DataAlreadyAcceptedException, DataSource, DataSourceFilter, DateTimeConverter, DeleteAccountPolicyRequest, DeleteDataProtectionPolicyRequest, DeleteDeliveryDestinationPolicyRequest, DeleteDeliveryDestinationRequest, DeleteDeliveryRequest, DeleteDeliverySourceRequest, DeleteDestinationRequest, DeleteIndexPolicyRequest, DeleteIndexPolicyResponse, DeleteIntegrationRequest, DeleteIntegrationResponse, DeleteKeys, DeleteLogAnomalyDetectorRequest, DeleteLogGroupRequest, DeleteLogStreamRequest, DeleteLookupTableRequest, DeleteMetricFilterRequest, DeleteQueryDefinitionRequest, DeleteQueryDefinitionResponse, DeleteResourcePolicyRequest, DeleteRetentionPolicyRequest, DeleteScheduledQueryRequest, DeleteScheduledQueryResponse, DeleteSubscriptionFilterRequest, DeleteTransformerRequest, Delivery, DeliveryDestination, DeliveryDestinationConfiguration, DeliverySource, DeliverySourceConfigurationSchema, DescribeAccountPoliciesRequest, DescribeAccountPoliciesResponse, DescribeConfigurationTemplatesRequest, DescribeConfigurationTemplatesResponse, DescribeDeliveriesRequest, DescribeDeliveriesResponse, DescribeDeliveryDestinationsRequest, DescribeDeliveryDestinationsResponse, DescribeDeliverySourcesRequest, DescribeDeliverySourcesResponse, DescribeDestinationsRequest, DescribeDestinationsResponse, DescribeExportTasksRequest, DescribeExportTasksResponse, DescribeFieldIndexesRequest, DescribeFieldIndexesResponse, DescribeImportTaskBatchesRequest, DescribeImportTaskBatchesResponse, DescribeImportTasksRequest, DescribeImportTasksResponse, DescribeIndexPoliciesRequest, DescribeIndexPoliciesResponse, DescribeLogGroupsRequest, DescribeLogGroupsResponse, DescribeLogStreamsRequest, DescribeLogStreamsResponse, DescribeLookupTablesRequest, DescribeLookupTablesResponse, DescribeMetricFiltersRequest, DescribeMetricFiltersResponse, DescribeQueriesRequest, DescribeQueriesResponse, DescribeQueryDefinitionsRequest, DescribeQueryDefinitionsResponse, DescribeResourcePoliciesRequest, DescribeResourcePoliciesResponse, DescribeSubscriptionFiltersRequest, DescribeSubscriptionFiltersResponse, Destination, DestinationConfiguration, DisassociateKmsKeyRequest, DisassociateSourceFromS3TableIntegrationRequest, DisassociateSourceFromS3TableIntegrationResponse, Entity, ExportTask, ExportTaskExecutionInfo, ExportTaskStatus, FieldIndex, FieldsData, FilterLogEventsRequest, FilterLogEventsResponse, FilteredLogEvent, GetDataProtectionPolicyRequest, GetDataProtectionPolicyResponse, GetDeliveryDestinationPolicyRequest, GetDeliveryDestinationPolicyResponse, GetDeliveryDestinationRequest, GetDeliveryDestinationResponse, GetDeliveryRequest, GetDeliveryResponse, GetDeliverySourceRequest, GetDeliverySourceResponse, GetIntegrationRequest, GetIntegrationResponse, GetLogAnomalyDetectorRequest, GetLogAnomalyDetectorResponse, GetLogEventsRequest, GetLogEventsResponse, GetLogFieldsRequest, GetLogFieldsResponse, GetLogGroupFieldsRequest, GetLogGroupFieldsResponse, GetLogObjectRequest, GetLogObjectResponse, GetLogObjectResponseStream, GetLogRecordRequest, GetLogRecordResponse, GetLookupTableRequest, GetLookupTableResponse, GetQueryResultsRequest, GetQueryResultsResponse, GetScheduledQueryHistoryRequest, GetScheduledQueryHistoryResponse, GetScheduledQueryRequest, GetScheduledQueryResponse, GetTransformerRequest, GetTransformerResponse, Grok, GroupingIdentifier, Import, ImportBatch, ImportFilter, ImportStatistics, IndexPolicy, InputLogEvent, IntegrationDetails, IntegrationSummary, InternalServerException, InternalStreamingException, InvalidOperationException, InvalidParameterException, InvalidSequenceTokenException, LimitExceededException, ListAggregateLogGroupSummariesRequest, ListAggregateLogGroupSummariesResponse, ListAnomaliesRequest, ListAnomaliesResponse, ListIntegrationsRequest, ListIntegrationsResponse, ListLogAnomalyDetectorsRequest, ListLogAnomalyDetectorsResponse, ListLogGroupsForQueryRequest, ListLogGroupsForQueryResponse, ListLogGroupsRequest, ListLogGroupsResponse, ListScheduledQueriesRequest, ListScheduledQueriesResponse, ListSourcesForS3TableIntegrationRequest, ListSourcesForS3TableIntegrationResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTagsLogGroupRequest, ListTagsLogGroupResponse, ListToMap, LiveTailSessionLogEvent, LiveTailSessionMetadata, LiveTailSessionStart, LiveTailSessionUpdate, LogEvent, LogFieldType, LogFieldsListItem, LogGroup, LogGroupField, LogGroupSummary, LogStream, LookupTable, LowerCaseString, MalformedQueryException, MetricFilter, MetricFilterMatchRecord, MetricTransformation, MoveKeyEntry, MoveKeys, OpenSearchApplication, OpenSearchCollection, OpenSearchDataAccessPolicy, OpenSearchDataSource, OpenSearchEncryptionPolicy, OpenSearchIntegrationDetails, OpenSearchLifecyclePolicy, OpenSearchNetworkPolicy, OpenSearchResourceConfig, OpenSearchResourceStatus, OpenSearchWorkspace, OperationAbortedException, OutputLogEvent, ParseCloudfront, ParseJSON, ParseKeyValue, ParsePostgres, ParseRoute53, ParseToOCSF, ParseVPC, ParseWAF, PatternToken, Policy, Processor, PutAccountPolicyRequest, PutAccountPolicyResponse, PutBearerTokenAuthenticationRequest, PutDataProtectionPolicyRequest, PutDataProtectionPolicyResponse, PutDeliveryDestinationPolicyRequest, PutDeliveryDestinationPolicyResponse, PutDeliveryDestinationRequest, PutDeliveryDestinationResponse, PutDeliverySourceRequest, PutDeliverySourceResponse, PutDestinationPolicyRequest, PutDestinationRequest, PutDestinationResponse, PutIndexPolicyRequest, PutIndexPolicyResponse, PutIntegrationRequest, PutIntegrationResponse, PutLogEventsRequest, PutLogEventsResponse, PutLogGroupDeletionProtectionRequest, PutMetricFilterRequest, PutQueryDefinitionRequest, PutQueryDefinitionResponse, PutResourcePolicyRequest, PutResourcePolicyResponse, PutRetentionPolicyRequest, PutSubscriptionFilterRequest, PutTransformerRequest, QueryCompileError, QueryCompileErrorLocation, QueryDefinition, QueryInfo, QueryParameter, QueryStatistics, RecordField, RejectedEntityInfo, RejectedLogEventsInfo, RenameKeyEntry, RenameKeys, ResourceAlreadyExistsException, ResourceConfig, ResourceNotFoundException, ResourcePolicy, ResultField, S3Configuration, S3DeliveryConfiguration, S3TableIntegrationSource, S3TablesIntegration, ScheduledQueryDestination, ScheduledQuerySummary, SearchedLogStream, ServiceQuotaExceededException, ServiceUnavailableException, SessionStreamingException, SessionTimeoutException, SplitString, SplitStringEntry, StartLiveTailRequest, StartLiveTailResponse, StartLiveTailResponseStream, StartQueryRequest, StartQueryResponse, StopQueryRequest, StopQueryResponse, SubscriptionFilter, SubstituteString, SubstituteStringEntry, SuppressionPeriod, TagFilter, TagLogGroupRequest, TagResourceRequest, TestMetricFilterRequest, TestMetricFilterResponse, TestTransformerRequest, TestTransformerResponse, ThrottlingException, TooManyTagsException, TransformedLogRecord, TriggerHistoryRecord, TrimString, TypeConverter, TypeConverterEntry, UnrecognizedClientException, UntagLogGroupRequest, UntagResourceRequest, UpdateAnomalyRequest, UpdateDeliveryConfigurationRequest, UpdateDeliveryConfigurationResponse, UpdateLogAnomalyDetectorRequest, UpdateLookupTableRequest, UpdateLookupTableResponse, UpdateScheduledQueryRequest, UpdateScheduledQueryResponse, UpperCaseString, ValidationException
Instance Attribute Summary collapse
-
#data ⇒ String
The actual log data content returned in the streaming response.
-
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern.
-
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
-
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
-
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
- #message ⇒ String
-
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
-
#open_search_resource_config ⇒ Types::OpenSearchResourceConfig
This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
-
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
-
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
-
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
-
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
Instance Attribute Details
#data ⇒ String
The actual log data content returned in the streaming response. This contains the fields and values of the log event in a structured format that can be parsed and processed by the client.
3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3498 class FieldsData < Struct.new( :data, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern. For example, a filter pattern of ‘error 404` displays only log events that include both `error` and `404`.
For more information about filter pattern syntax, see [Filter and Pattern Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html
5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5692 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5692 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5692 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5692 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
4941 4942 4943 4944 4945 4946 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4941 class InternalStreamingException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
4882 4883 4884 4885 4886 4887 4888 4889 4890 4891 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4882 class IntegrationDetails < Struct.new( :open_search_integration_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchIntegrationDetails < IntegrationDetails; end class Unknown < IntegrationDetails; end end |
#open_search_resource_config ⇒ Types::OpenSearchResourceConfig
This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
9101 9102 9103 9104 9105 9106 9107 9108 9109 9110 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9101 class ResourceConfig < Struct.new( :open_search_resource_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchResourceConfig < ResourceConfig; end class Unknown < ResourceConfig; end end |
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5692 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
5692 5693 5694 5695 5696 5697 5698 5699 5700 5701 5702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5692 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
5723 5724 5725 5726 5727 5728 5729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5723 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
A ‘sessionResults` array can include as many as 500 log events. If the number of log events matching the request exceeds 500 per second, the log events are sampled down to 500 log events to be included in each `sessionUpdate` structure.
5723 5724 5725 5726 5727 5728 5729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5723 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |