Module: Aws::CloudWatchLogs::Types

Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Defined Under Namespace

Classes: AccessDeniedException, AccountPolicy, AddKeyEntry, AddKeys, AggregateLogGroupSummary, Anomaly, AnomalyDetector, AssociateKmsKeyRequest, AssociateSourceToS3TableIntegrationRequest, AssociateSourceToS3TableIntegrationResponse, CSV, CancelExportTaskRequest, CancelImportTaskRequest, CancelImportTaskResponse, ConfigurationTemplate, ConfigurationTemplateDeliveryConfigValues, ConflictException, CopyValue, CopyValueEntry, CreateDeliveryRequest, CreateDeliveryResponse, CreateExportTaskRequest, CreateExportTaskResponse, CreateImportTaskRequest, CreateImportTaskResponse, CreateLogAnomalyDetectorRequest, CreateLogAnomalyDetectorResponse, CreateLogGroupRequest, CreateLogStreamRequest, CreateLookupTableRequest, CreateLookupTableResponse, CreateScheduledQueryRequest, CreateScheduledQueryResponse, DataAlreadyAcceptedException, DataSource, DataSourceFilter, DateTimeConverter, DeleteAccountPolicyRequest, DeleteDataProtectionPolicyRequest, DeleteDeliveryDestinationPolicyRequest, DeleteDeliveryDestinationRequest, DeleteDeliveryRequest, DeleteDeliverySourceRequest, DeleteDestinationRequest, DeleteIndexPolicyRequest, DeleteIndexPolicyResponse, DeleteIntegrationRequest, DeleteIntegrationResponse, DeleteKeys, DeleteLogAnomalyDetectorRequest, DeleteLogGroupRequest, DeleteLogStreamRequest, DeleteLookupTableRequest, DeleteMetricFilterRequest, DeleteQueryDefinitionRequest, DeleteQueryDefinitionResponse, DeleteResourcePolicyRequest, DeleteRetentionPolicyRequest, DeleteScheduledQueryRequest, DeleteScheduledQueryResponse, DeleteSubscriptionFilterRequest, DeleteTransformerRequest, Delivery, DeliveryDestination, DeliveryDestinationConfiguration, DeliverySource, DeliverySourceConfigurationSchema, DescribeAccountPoliciesRequest, DescribeAccountPoliciesResponse, DescribeConfigurationTemplatesRequest, DescribeConfigurationTemplatesResponse, DescribeDeliveriesRequest, DescribeDeliveriesResponse, DescribeDeliveryDestinationsRequest, DescribeDeliveryDestinationsResponse, DescribeDeliverySourcesRequest, DescribeDeliverySourcesResponse, DescribeDestinationsRequest, DescribeDestinationsResponse, DescribeExportTasksRequest, DescribeExportTasksResponse, DescribeFieldIndexesRequest, DescribeFieldIndexesResponse, DescribeImportTaskBatchesRequest, DescribeImportTaskBatchesResponse, DescribeImportTasksRequest, DescribeImportTasksResponse, DescribeIndexPoliciesRequest, DescribeIndexPoliciesResponse, DescribeLogGroupsRequest, DescribeLogGroupsResponse, DescribeLogStreamsRequest, DescribeLogStreamsResponse, DescribeLookupTablesRequest, DescribeLookupTablesResponse, DescribeMetricFiltersRequest, DescribeMetricFiltersResponse, DescribeQueriesRequest, DescribeQueriesResponse, DescribeQueryDefinitionsRequest, DescribeQueryDefinitionsResponse, DescribeResourcePoliciesRequest, DescribeResourcePoliciesResponse, DescribeSubscriptionFiltersRequest, DescribeSubscriptionFiltersResponse, Destination, DestinationConfiguration, DisassociateKmsKeyRequest, DisassociateSourceFromS3TableIntegrationRequest, DisassociateSourceFromS3TableIntegrationResponse, Entity, ExportTask, ExportTaskExecutionInfo, ExportTaskStatus, FieldIndex, FieldsData, FilterLogEventsRequest, FilterLogEventsResponse, FilteredLogEvent, GetDataProtectionPolicyRequest, GetDataProtectionPolicyResponse, GetDeliveryDestinationPolicyRequest, GetDeliveryDestinationPolicyResponse, GetDeliveryDestinationRequest, GetDeliveryDestinationResponse, GetDeliveryRequest, GetDeliveryResponse, GetDeliverySourceRequest, GetDeliverySourceResponse, GetIntegrationRequest, GetIntegrationResponse, GetLogAnomalyDetectorRequest, GetLogAnomalyDetectorResponse, GetLogEventsRequest, GetLogEventsResponse, GetLogFieldsRequest, GetLogFieldsResponse, GetLogGroupFieldsRequest, GetLogGroupFieldsResponse, GetLogObjectRequest, GetLogObjectResponse, GetLogObjectResponseStream, GetLogRecordRequest, GetLogRecordResponse, GetLookupTableRequest, GetLookupTableResponse, GetQueryResultsRequest, GetQueryResultsResponse, GetScheduledQueryHistoryRequest, GetScheduledQueryHistoryResponse, GetScheduledQueryRequest, GetScheduledQueryResponse, GetTransformerRequest, GetTransformerResponse, Grok, GroupingIdentifier, Import, ImportBatch, ImportFilter, ImportStatistics, IndexPolicy, InputLogEvent, IntegrationDetails, IntegrationSummary, InternalServerException, InternalStreamingException, InvalidOperationException, InvalidParameterException, InvalidSequenceTokenException, LimitExceededException, ListAggregateLogGroupSummariesRequest, ListAggregateLogGroupSummariesResponse, ListAnomaliesRequest, ListAnomaliesResponse, ListIntegrationsRequest, ListIntegrationsResponse, ListLogAnomalyDetectorsRequest, ListLogAnomalyDetectorsResponse, ListLogGroupsForQueryRequest, ListLogGroupsForQueryResponse, ListLogGroupsRequest, ListLogGroupsResponse, ListScheduledQueriesRequest, ListScheduledQueriesResponse, ListSourcesForS3TableIntegrationRequest, ListSourcesForS3TableIntegrationResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTagsLogGroupRequest, ListTagsLogGroupResponse, ListToMap, LiveTailSessionLogEvent, LiveTailSessionMetadata, LiveTailSessionStart, LiveTailSessionUpdate, LogEvent, LogFieldType, LogFieldsListItem, LogGroup, LogGroupField, LogGroupSummary, LogStream, LookupTable, LowerCaseString, MalformedQueryException, MetricFilter, MetricFilterMatchRecord, MetricTransformation, MoveKeyEntry, MoveKeys, OpenSearchApplication, OpenSearchCollection, OpenSearchDataAccessPolicy, OpenSearchDataSource, OpenSearchEncryptionPolicy, OpenSearchIntegrationDetails, OpenSearchLifecyclePolicy, OpenSearchNetworkPolicy, OpenSearchResourceConfig, OpenSearchResourceStatus, OpenSearchWorkspace, OperationAbortedException, OutputLogEvent, ParseCloudfront, ParseJSON, ParseKeyValue, ParsePostgres, ParseRoute53, ParseToOCSF, ParseVPC, ParseWAF, PatternToken, Policy, Processor, PutAccountPolicyRequest, PutAccountPolicyResponse, PutBearerTokenAuthenticationRequest, PutDataProtectionPolicyRequest, PutDataProtectionPolicyResponse, PutDeliveryDestinationPolicyRequest, PutDeliveryDestinationPolicyResponse, PutDeliveryDestinationRequest, PutDeliveryDestinationResponse, PutDeliverySourceRequest, PutDeliverySourceResponse, PutDestinationPolicyRequest, PutDestinationRequest, PutDestinationResponse, PutIndexPolicyRequest, PutIndexPolicyResponse, PutIntegrationRequest, PutIntegrationResponse, PutLogEventsRequest, PutLogEventsResponse, PutLogGroupDeletionProtectionRequest, PutMetricFilterRequest, PutQueryDefinitionRequest, PutQueryDefinitionResponse, PutResourcePolicyRequest, PutResourcePolicyResponse, PutRetentionPolicyRequest, PutSubscriptionFilterRequest, PutTransformerRequest, QueryCompileError, QueryCompileErrorLocation, QueryDefinition, QueryInfo, QueryParameter, QueryStatistics, RecordField, RejectedEntityInfo, RejectedLogEventsInfo, RenameKeyEntry, RenameKeys, ResourceAlreadyExistsException, ResourceConfig, ResourceNotFoundException, ResourcePolicy, ResultField, S3Configuration, S3DeliveryConfiguration, S3TableIntegrationSource, S3TablesIntegration, ScheduledQueryDestination, ScheduledQuerySummary, SearchedLogStream, ServiceQuotaExceededException, ServiceUnavailableException, SessionStreamingException, SessionTimeoutException, SplitString, SplitStringEntry, StartLiveTailRequest, StartLiveTailResponse, StartLiveTailResponseStream, StartQueryRequest, StartQueryResponse, StopQueryRequest, StopQueryResponse, SubscriptionFilter, SubstituteString, SubstituteStringEntry, SuppressionPeriod, TagFilter, TagLogGroupRequest, TagResourceRequest, TestMetricFilterRequest, TestMetricFilterResponse, TestTransformerRequest, TestTransformerResponse, ThrottlingException, TooManyTagsException, TransformedLogRecord, TriggerHistoryRecord, TrimString, TypeConverter, TypeConverterEntry, UnrecognizedClientException, UntagLogGroupRequest, UntagResourceRequest, UpdateAnomalyRequest, UpdateDeliveryConfigurationRequest, UpdateDeliveryConfigurationResponse, UpdateLogAnomalyDetectorRequest, UpdateLookupTableRequest, UpdateLookupTableResponse, UpdateScheduledQueryRequest, UpdateScheduledQueryResponse, UpperCaseString, ValidationException

Instance Attribute Summary collapse

Instance Attribute Details

#dataString

The actual log data content returned in the streaming response. This contains the fields and values of the log event in a structured format that can be parsed and processed by the client.

Returns:

  • (String)


3492
3493
3494
3495
3496
3497
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3492

class FieldsData < Struct.new(
  :data,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_event_filter_patternString

An optional pattern to filter the results to include only log events that match the pattern. For example, a filter pattern of ‘error 404` displays only log events that include both `error` and `404`.

For more information about filter pattern syntax, see [Filter and Pattern Syntax].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html

Returns:

  • (String)


5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5645

class LiveTailSessionStart < Struct.new(
  :request_id,
  :session_id,
  :log_group_identifiers,
  :log_stream_names,
  :log_stream_name_prefixes,
  :log_event_filter_pattern,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

An array of the names and ARNs of the log groups included in this Live Tail session.

Returns:

  • (Array<String>)


5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5645

class LiveTailSessionStart < Struct.new(
  :request_id,
  :session_id,
  :log_group_identifiers,
  :log_stream_names,
  :log_stream_name_prefixes,
  :log_event_filter_pattern,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_stream_name_prefixesArray<String>

If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.

Returns:

  • (Array<String>)


5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5645

class LiveTailSessionStart < Struct.new(
  :request_id,
  :session_id,
  :log_group_identifiers,
  :log_stream_names,
  :log_stream_name_prefixes,
  :log_event_filter_pattern,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#log_stream_namesArray<String>

If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.

Returns:

  • (Array<String>)


5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5645

class LiveTailSessionStart < Struct.new(
  :request_id,
  :session_id,
  :log_group_identifiers,
  :log_stream_names,
  :log_stream_name_prefixes,
  :log_event_filter_pattern,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

Returns:

  • (String)


4901
4902
4903
4904
4905
4906
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4901

class InternalStreamingException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#open_search_integration_detailsTypes::OpenSearchIntegrationDetails

This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.



4842
4843
4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4842

class IntegrationDetails < Struct.new(
  :open_search_integration_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpenSearchIntegrationDetails < IntegrationDetails; end
  class Unknown < IntegrationDetails; end
end

#open_search_resource_configTypes::OpenSearchResourceConfig

This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.



9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9054

class ResourceConfig < Struct.new(
  :open_search_resource_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpenSearchResourceConfig < ResourceConfig; end
  class Unknown < ResourceConfig; end
end

#request_idString

The unique ID generated by CloudWatch Logs to identify this Live Tail session request.

Returns:

  • (String)


5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5645

class LiveTailSessionStart < Struct.new(
  :request_id,
  :session_id,
  :log_group_identifiers,
  :log_stream_names,
  :log_stream_name_prefixes,
  :log_event_filter_pattern,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The unique ID generated by CloudWatch Logs to identify this Live Tail session.

Returns:

  • (String)


5645
5646
5647
5648
5649
5650
5651
5652
5653
5654
5655
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5645

class LiveTailSessionStart < Struct.new(
  :request_id,
  :session_id,
  :log_group_identifiers,
  :log_stream_names,
  :log_stream_name_prefixes,
  :log_event_filter_pattern,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#session_metadataTypes::LiveTailSessionMetadata

This object contains the session metadata for a Live Tail session.



5676
5677
5678
5679
5680
5681
5682
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5676

class LiveTailSessionUpdate < Struct.new(
  :session_metadata,
  :session_results,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end

#session_resultsArray<Types::LiveTailSessionLogEvent>

An array, where each member of the array includes the information for one log event in the Live Tail session.

A ‘sessionResults` array can include as many as 500 log events. If the number of log events matching the request exceeds 500 per second, the log events are sampled down to 500 log events to be included in each `sessionUpdate` structure.

Returns:



5676
5677
5678
5679
5680
5681
5682
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5676

class LiveTailSessionUpdate < Struct.new(
  :session_metadata,
  :session_results,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end