Module: Aws::CloudWatchLogs::Types
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AccountPolicy, AddKeyEntry, AddKeys, Anomaly, AnomalyDetector, AssociateKmsKeyRequest, CSV, CancelExportTaskRequest, ConfigurationTemplate, ConfigurationTemplateDeliveryConfigValues, ConflictException, CopyValue, CopyValueEntry, CreateDeliveryRequest, CreateDeliveryResponse, CreateExportTaskRequest, CreateExportTaskResponse, CreateLogAnomalyDetectorRequest, CreateLogAnomalyDetectorResponse, CreateLogGroupRequest, CreateLogStreamRequest, DataAlreadyAcceptedException, DateTimeConverter, DeleteAccountPolicyRequest, DeleteDataProtectionPolicyRequest, DeleteDeliveryDestinationPolicyRequest, DeleteDeliveryDestinationRequest, DeleteDeliveryRequest, DeleteDeliverySourceRequest, DeleteDestinationRequest, DeleteIndexPolicyRequest, DeleteIndexPolicyResponse, DeleteIntegrationRequest, DeleteIntegrationResponse, DeleteKeys, DeleteLogAnomalyDetectorRequest, DeleteLogGroupRequest, DeleteLogStreamRequest, DeleteMetricFilterRequest, DeleteQueryDefinitionRequest, DeleteQueryDefinitionResponse, DeleteResourcePolicyRequest, DeleteRetentionPolicyRequest, DeleteSubscriptionFilterRequest, DeleteTransformerRequest, Delivery, DeliveryDestination, DeliveryDestinationConfiguration, DeliverySource, DescribeAccountPoliciesRequest, DescribeAccountPoliciesResponse, DescribeConfigurationTemplatesRequest, DescribeConfigurationTemplatesResponse, DescribeDeliveriesRequest, DescribeDeliveriesResponse, DescribeDeliveryDestinationsRequest, DescribeDeliveryDestinationsResponse, DescribeDeliverySourcesRequest, DescribeDeliverySourcesResponse, DescribeDestinationsRequest, DescribeDestinationsResponse, DescribeExportTasksRequest, DescribeExportTasksResponse, DescribeFieldIndexesRequest, DescribeFieldIndexesResponse, DescribeIndexPoliciesRequest, DescribeIndexPoliciesResponse, DescribeLogGroupsRequest, DescribeLogGroupsResponse, DescribeLogStreamsRequest, DescribeLogStreamsResponse, DescribeMetricFiltersRequest, DescribeMetricFiltersResponse, DescribeQueriesRequest, DescribeQueriesResponse, DescribeQueryDefinitionsRequest, DescribeQueryDefinitionsResponse, DescribeResourcePoliciesRequest, DescribeResourcePoliciesResponse, DescribeSubscriptionFiltersRequest, DescribeSubscriptionFiltersResponse, Destination, DisassociateKmsKeyRequest, Entity, ExportTask, ExportTaskExecutionInfo, ExportTaskStatus, FieldIndex, FilterLogEventsRequest, FilterLogEventsResponse, FilteredLogEvent, GetDataProtectionPolicyRequest, GetDataProtectionPolicyResponse, GetDeliveryDestinationPolicyRequest, GetDeliveryDestinationPolicyResponse, GetDeliveryDestinationRequest, GetDeliveryDestinationResponse, GetDeliveryRequest, GetDeliveryResponse, GetDeliverySourceRequest, GetDeliverySourceResponse, GetIntegrationRequest, GetIntegrationResponse, GetLogAnomalyDetectorRequest, GetLogAnomalyDetectorResponse, GetLogEventsRequest, GetLogEventsResponse, GetLogGroupFieldsRequest, GetLogGroupFieldsResponse, GetLogRecordRequest, GetLogRecordResponse, GetQueryResultsRequest, GetQueryResultsResponse, GetTransformerRequest, GetTransformerResponse, Grok, IndexPolicy, InputLogEvent, IntegrationDetails, IntegrationSummary, InvalidOperationException, InvalidParameterException, InvalidSequenceTokenException, LimitExceededException, ListAnomaliesRequest, ListAnomaliesResponse, ListIntegrationsRequest, ListIntegrationsResponse, ListLogAnomalyDetectorsRequest, ListLogAnomalyDetectorsResponse, ListLogGroupsForQueryRequest, ListLogGroupsForQueryResponse, ListLogGroupsRequest, ListLogGroupsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTagsLogGroupRequest, ListTagsLogGroupResponse, ListToMap, LiveTailSessionLogEvent, LiveTailSessionMetadata, LiveTailSessionStart, LiveTailSessionUpdate, LogEvent, LogGroup, LogGroupField, LogGroupSummary, LogStream, LowerCaseString, MalformedQueryException, MetricFilter, MetricFilterMatchRecord, MetricTransformation, MoveKeyEntry, MoveKeys, OpenSearchApplication, OpenSearchCollection, OpenSearchDataAccessPolicy, OpenSearchDataSource, OpenSearchEncryptionPolicy, OpenSearchIntegrationDetails, OpenSearchLifecyclePolicy, OpenSearchNetworkPolicy, OpenSearchResourceConfig, OpenSearchResourceStatus, OpenSearchWorkspace, OperationAbortedException, OutputLogEvent, ParseCloudfront, ParseJSON, ParseKeyValue, ParsePostgres, ParseRoute53, ParseToOCSF, ParseVPC, ParseWAF, PatternToken, Policy, Processor, PutAccountPolicyRequest, PutAccountPolicyResponse, PutDataProtectionPolicyRequest, PutDataProtectionPolicyResponse, PutDeliveryDestinationPolicyRequest, PutDeliveryDestinationPolicyResponse, PutDeliveryDestinationRequest, PutDeliveryDestinationResponse, PutDeliverySourceRequest, PutDeliverySourceResponse, PutDestinationPolicyRequest, PutDestinationRequest, PutDestinationResponse, PutIndexPolicyRequest, PutIndexPolicyResponse, PutIntegrationRequest, PutIntegrationResponse, PutLogEventsRequest, PutLogEventsResponse, PutMetricFilterRequest, PutQueryDefinitionRequest, PutQueryDefinitionResponse, PutResourcePolicyRequest, PutResourcePolicyResponse, PutRetentionPolicyRequest, PutSubscriptionFilterRequest, PutTransformerRequest, QueryCompileError, QueryCompileErrorLocation, QueryDefinition, QueryInfo, QueryStatistics, RecordField, RejectedEntityInfo, RejectedLogEventsInfo, RenameKeyEntry, RenameKeys, ResourceAlreadyExistsException, ResourceConfig, ResourceNotFoundException, ResourcePolicy, ResultField, S3DeliveryConfiguration, SearchedLogStream, ServiceQuotaExceededException, ServiceUnavailableException, SessionStreamingException, SessionTimeoutException, SplitString, SplitStringEntry, StartLiveTailRequest, StartLiveTailResponse, StartLiveTailResponseStream, StartQueryRequest, StartQueryResponse, StopQueryRequest, StopQueryResponse, SubscriptionFilter, SubstituteString, SubstituteStringEntry, SuppressionPeriod, TagLogGroupRequest, TagResourceRequest, TestMetricFilterRequest, TestMetricFilterResponse, TestTransformerRequest, TestTransformerResponse, ThrottlingException, TooManyTagsException, TransformedLogRecord, TrimString, TypeConverter, TypeConverterEntry, UnrecognizedClientException, UntagLogGroupRequest, UntagResourceRequest, UpdateAnomalyRequest, UpdateDeliveryConfigurationRequest, UpdateDeliveryConfigurationResponse, UpdateLogAnomalyDetectorRequest, UpperCaseString, ValidationException
Instance Attribute Summary collapse
-
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern.
-
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
-
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
-
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
- #message ⇒ String
-
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
-
#open_search_resource_config ⇒ Types::OpenSearchResourceConfig
This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
-
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
-
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
-
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
-
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
Instance Attribute Details
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern. For example, a filter pattern of ‘error 404` displays only log events that include both `error` and `404`.
For more information about filter pattern syntax, see [Filter and Pattern Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html
4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4221 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4221 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4221 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4221 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
7415 7416 7417 7418 7419 7420 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7415 class SessionStreamingException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3650 class IntegrationDetails < Struct.new( :open_search_integration_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchIntegrationDetails < IntegrationDetails; end class Unknown < IntegrationDetails; end end |
#open_search_resource_config ⇒ Types::OpenSearchResourceConfig
This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
7258 7259 7260 7261 7262 7263 7264 7265 7266 7267 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7258 class ResourceConfig < Struct.new( :open_search_resource_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchResourceConfig < ResourceConfig; end class Unknown < ResourceConfig; end end |
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4221 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
4221 4222 4223 4224 4225 4226 4227 4228 4229 4230 4231 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4221 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
4252 4253 4254 4255 4256 4257 4258 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4252 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
A ‘sessionResults` array can include as many as 500 log events. If the number of log events matching the request exceeds 500 per second, the log events are sampled down to 500 log events to be included in each `sessionUpdate` structure.
4252 4253 4254 4255 4256 4257 4258 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4252 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |