Module: Aws::CloudWatchLogs::Types
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AccountPolicy, Anomaly, AnomalyDetector, AssociateKmsKeyRequest, CancelExportTaskRequest, ConflictException, CreateDeliveryRequest, CreateDeliveryResponse, CreateExportTaskRequest, CreateExportTaskResponse, CreateLogAnomalyDetectorRequest, CreateLogAnomalyDetectorResponse, CreateLogGroupRequest, CreateLogStreamRequest, DataAlreadyAcceptedException, DeleteAccountPolicyRequest, DeleteDataProtectionPolicyRequest, DeleteDeliveryDestinationPolicyRequest, DeleteDeliveryDestinationRequest, DeleteDeliveryRequest, DeleteDeliverySourceRequest, DeleteDestinationRequest, DeleteLogAnomalyDetectorRequest, DeleteLogGroupRequest, DeleteLogStreamRequest, DeleteMetricFilterRequest, DeleteQueryDefinitionRequest, DeleteQueryDefinitionResponse, DeleteResourcePolicyRequest, DeleteRetentionPolicyRequest, DeleteSubscriptionFilterRequest, Delivery, DeliveryDestination, DeliveryDestinationConfiguration, DeliverySource, DescribeAccountPoliciesRequest, DescribeAccountPoliciesResponse, DescribeDeliveriesRequest, DescribeDeliveriesResponse, DescribeDeliveryDestinationsRequest, DescribeDeliveryDestinationsResponse, DescribeDeliverySourcesRequest, DescribeDeliverySourcesResponse, DescribeDestinationsRequest, DescribeDestinationsResponse, DescribeExportTasksRequest, DescribeExportTasksResponse, DescribeLogGroupsRequest, DescribeLogGroupsResponse, DescribeLogStreamsRequest, DescribeLogStreamsResponse, DescribeMetricFiltersRequest, DescribeMetricFiltersResponse, DescribeQueriesRequest, DescribeQueriesResponse, DescribeQueryDefinitionsRequest, DescribeQueryDefinitionsResponse, DescribeResourcePoliciesRequest, DescribeResourcePoliciesResponse, DescribeSubscriptionFiltersRequest, DescribeSubscriptionFiltersResponse, Destination, DisassociateKmsKeyRequest, ExportTask, ExportTaskExecutionInfo, ExportTaskStatus, FilterLogEventsRequest, FilterLogEventsResponse, FilteredLogEvent, GetDataProtectionPolicyRequest, GetDataProtectionPolicyResponse, GetDeliveryDestinationPolicyRequest, GetDeliveryDestinationPolicyResponse, GetDeliveryDestinationRequest, GetDeliveryDestinationResponse, GetDeliveryRequest, GetDeliveryResponse, GetDeliverySourceRequest, GetDeliverySourceResponse, GetLogAnomalyDetectorRequest, GetLogAnomalyDetectorResponse, GetLogEventsRequest, GetLogEventsResponse, GetLogGroupFieldsRequest, GetLogGroupFieldsResponse, GetLogRecordRequest, GetLogRecordResponse, GetQueryResultsRequest, GetQueryResultsResponse, InputLogEvent, InvalidOperationException, InvalidParameterException, InvalidSequenceTokenException, LimitExceededException, ListAnomaliesRequest, ListAnomaliesResponse, ListLogAnomalyDetectorsRequest, ListLogAnomalyDetectorsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTagsLogGroupRequest, ListTagsLogGroupResponse, LiveTailSessionLogEvent, LiveTailSessionMetadata, LiveTailSessionStart, LiveTailSessionUpdate, LogGroup, LogGroupField, LogStream, MalformedQueryException, MetricFilter, MetricFilterMatchRecord, MetricTransformation, OperationAbortedException, OutputLogEvent, PatternToken, Policy, PutAccountPolicyRequest, PutAccountPolicyResponse, PutDataProtectionPolicyRequest, PutDataProtectionPolicyResponse, PutDeliveryDestinationPolicyRequest, PutDeliveryDestinationPolicyResponse, PutDeliveryDestinationRequest, PutDeliveryDestinationResponse, PutDeliverySourceRequest, PutDeliverySourceResponse, PutDestinationPolicyRequest, PutDestinationRequest, PutDestinationResponse, PutLogEventsRequest, PutLogEventsResponse, PutMetricFilterRequest, PutQueryDefinitionRequest, PutQueryDefinitionResponse, PutResourcePolicyRequest, PutResourcePolicyResponse, PutRetentionPolicyRequest, PutSubscriptionFilterRequest, QueryCompileError, QueryCompileErrorLocation, QueryDefinition, QueryInfo, QueryStatistics, RejectedLogEventsInfo, ResourceAlreadyExistsException, ResourceNotFoundException, ResourcePolicy, ResultField, SearchedLogStream, ServiceQuotaExceededException, ServiceUnavailableException, SessionStreamingException, SessionTimeoutException, StartLiveTailRequest, StartLiveTailResponse, StartLiveTailResponseStream, StartQueryRequest, StartQueryResponse, StopQueryRequest, StopQueryResponse, SubscriptionFilter, SuppressionPeriod, TagLogGroupRequest, TagResourceRequest, TestMetricFilterRequest, TestMetricFilterResponse, ThrottlingException, TooManyTagsException, UnrecognizedClientException, UntagLogGroupRequest, UntagResourceRequest, UpdateAnomalyRequest, UpdateLogAnomalyDetectorRequest, ValidationException
Instance Attribute Summary collapse
-
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern.
-
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
-
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
-
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
- #message ⇒ String
-
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
-
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
-
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
-
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
Instance Attribute Details
#log_event_filter_pattern ⇒ String
An optional pattern to filter the results to include only log events that match the pattern. For example, a filter pattern of ‘error 404` displays only log events that include both `error` and `404`.
For more information about filter pattern syntax, see [Filter and Pattern Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2965 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
An array of the names and ARNs of the log groups included in this Live Tail session.
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2965 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_name_prefixes ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNamePrefixes` parameter that filtered the session to only include log streams that have names that start with certain prefixes, these prefixes are listed here.
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2965 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#log_stream_names ⇒ Array<String>
If your StartLiveTail operation request included a ‘logStreamNames` parameter that filtered the session to only include certain log streams, these streams are listed here.
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2965 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
4410 4411 4412 4413 4414 4415 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4410 class SessionStreamingException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session request.
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2965 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The unique ID generated by CloudWatch Logs to identify this Live Tail session.
2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2965 class LiveTailSessionStart < Struct.new( :request_id, :session_id, :log_group_identifiers, :log_stream_names, :log_stream_name_prefixes, :log_event_filter_pattern, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_metadata ⇒ Types::LiveTailSessionMetadata
This object contains the session metadata for a Live Tail session.
2996 2997 2998 2999 3000 3001 3002 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2996 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |
#session_results ⇒ Array<Types::LiveTailSessionLogEvent>
An array, where each member of the array includes the information for one log event in the Live Tail session.
A ‘sessionResults` array can include as many as 500 log events. If the number of log events matching the request exceeds 500 per second, the log events are sampled down to 500 log events to be included in each `sessionUpdate` structure.
2996 2997 2998 2999 3000 3001 3002 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2996 class LiveTailSessionUpdate < Struct.new( :session_metadata, :session_results, :event_type) SENSITIVE = [] include Aws::Structure end |