Class: Aws::CloudWatchLogs::Types::CreateLogGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::CreateLogGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data.
-
#log_group_name ⇒ String
The name of the log group.
-
#tags ⇒ Hash<String,String>
The key-value pairs to use for the tags.
Instance Attribute Details
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data. For more information, see [Amazon Resource Names].
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#arn-syntax-kms
147 148 149 150 151 152 153 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 147 class CreateLogGroupRequest < Struct.new( :log_group_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
147 148 149 150 151 152 153 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 147 class CreateLogGroupRequest < Struct.new( :log_group_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The key-value pairs to use for the tags.
You can grant users access to certain log groups while preventing them from accessing other log groups. To do so, tag your groups and use IAM policies that refer to those tags. To assign tags when you create a log group, you must have either the ‘logs:TagResource` or `logs:TagLogGroup` permission. For more information about tagging, see [Tagging Amazon Web Services resources]. For more information about using tags to control access, see [Controlling access to Amazon Web Services resources using tags].
[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html
147 148 149 150 151 152 153 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 147 class CreateLogGroupRequest < Struct.new( :log_group_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |