Class: Aws::CloudWatchLogs::Types::CreateLogGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::CreateLogGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
When making an API call, you may pass CreateLogGroupRequest data as a hash:
{
log_group_name: "LogGroupName", # required
kms_key_id: "KmsKeyId",
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the CMK to use when encrypting log data.
-
#log_group_name ⇒ String
The name of the log group.
-
#tags ⇒ Hash<String,String>
The key-value pairs to use for the tags.
Instance Attribute Details
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the CMK to use when encrypting log data. For more information, see [Amazon Resource Names - Key Management Service].
[1]: docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html#arn-syntax-kms
183 184 185 186 187 188 189 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 183 class CreateLogGroupRequest < Struct.new( :log_group_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
183 184 185 186 187 188 189 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 183 class CreateLogGroupRequest < Struct.new( :log_group_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The key-value pairs to use for the tags.
CloudWatch Logs doesn’t support IAM policies that prevent users from assigning specified tags to log groups using the `aws:Resource/key-name ` or `aws:TagKeys` condition keys. For more information about using tags to control access, see [Controlling access to Amazon Web Services resources using tags].
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_tags.html
183 184 185 186 187 188 189 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 183 class CreateLogGroupRequest < Struct.new( :log_group_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |