Class: Aws::CloudWatchLogs::Types::CreateLookupTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::CreateLookupTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the lookup table.
-
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data.
-
#lookup_table_name ⇒ String
The name of the lookup table.
-
#query_id ⇒ String
The ID of a completed CloudWatch Logs query whose results populate the lookup table.
-
#table_body ⇒ String
The CSV content of the lookup table.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the lookup table.
Instance Attribute Details
#description ⇒ String
A description of the lookup table. The description can be up to 1024 characters long.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1187 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :query_id, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data. If you don't specify a key, the data is encrypted with an Amazon Web Services-owned key.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1187 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :query_id, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#lookup_table_name ⇒ String
The name of the lookup table. The name must be unique within your account and Region. The name can contain only alphanumeric characters and underscores, and can be up to 256 characters long.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1187 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :query_id, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The ID of a completed CloudWatch Logs query whose results populate the lookup table.
You must specify either tableBody or queryId, but not both.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1187 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :query_id, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#table_body ⇒ String
The CSV content of the lookup table. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.
You must specify either tableBody or queryId, but not both.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1187 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :query_id, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the lookup table. You can associate as many as 50 tags with a lookup table. Tags can help you organize and categorize your resources.
1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1187 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :query_id, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |