Class: Aws::CloudWatchLogs::Types::CreateLookupTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::CreateLookupTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the lookup table.
-
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data.
-
#lookup_table_name ⇒ String
The name of the lookup table.
-
#table_body ⇒ String
The CSV content of the lookup table.
-
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the lookup table.
Instance Attribute Details
#description ⇒ String
A description of the lookup table. The description can be up to 1024 characters long.
1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1178 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data. If you don’t specify a key, the data is encrypted with an Amazon Web Services-owned key.
1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1178 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#lookup_table_name ⇒ String
The name of the lookup table. The name must be unique within your account and Region. The name can contain only alphanumeric characters and underscores, and can be up to 256 characters long.
1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1178 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#table_body ⇒ String
The CSV content of the lookup table. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.
1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1178 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A list of key-value pairs to associate with the lookup table. You can associate as many as 50 tags with a lookup table. Tags can help you organize and categorize your resources.
1178 1179 1180 1181 1182 1183 1184 1185 1186 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1178 class CreateLookupTableRequest < Struct.new( :lookup_table_name, :description, :table_body, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |