Class: Aws::CloudWatchLogs::Types::DeleteIntegrationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#forceBoolean

Specify true to force the deletion of the integration even if vended logs dashboards currently exist.

The default is false.

Returns:

  • (Boolean)


1594
1595
1596
1597
1598
1599
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1594

class DeleteIntegrationRequest < Struct.new(
  :integration_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration to delete. To find the name of your integration, use ListIntegrations.

Returns:

  • (String)


1594
1595
1596
1597
1598
1599
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1594

class DeleteIntegrationRequest < Struct.new(
  :integration_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end