Class: Aws::CloudWatchLogs::Types::Delivery
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::Delivery
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about one delivery in your account.
A delivery is a connection between a logical *delivery source* and a logical *delivery destination*.
For more information, see [CreateDelivery].
To update an existing delivery configuration, use [UpdateDeliveryConfiguration].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_CreateDelivery.html [2]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UpdateDeliveryConfiguration.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies this delivery.
-
#delivery_destination_arn ⇒ String
The ARN of the delivery destination that is associated with this delivery.
-
#delivery_destination_type ⇒ String
Displays whether the delivery destination associated with this delivery is CloudWatch Logs, Amazon S3, Firehose, or X-Ray.
-
#delivery_source_name ⇒ String
The name of the delivery source that is associated with this delivery.
-
#field_delimiter ⇒ String
The field delimiter that is used between record fields when the final output format of a delivery is in ‘Plain`, `W3C`, or `Raw` format.
-
#id ⇒ String
The unique ID that identifies this delivery in your account.
-
#record_fields ⇒ Array<String>
The record fields used in this delivery.
-
#s3_delivery_configuration ⇒ Types::S3DeliveryConfiguration
This structure contains delivery configurations that apply only when the delivery destination resource is an S3 bucket.
-
#tags ⇒ Hash<String,String>
The tags that have been assigned to this delivery.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies this delivery.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#delivery_destination_arn ⇒ String
The ARN of the delivery destination that is associated with this delivery.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#delivery_destination_type ⇒ String
Displays whether the delivery destination associated with this delivery is CloudWatch Logs, Amazon S3, Firehose, or X-Ray.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#delivery_source_name ⇒ String
The name of the delivery source that is associated with this delivery.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#field_delimiter ⇒ String
The field delimiter that is used between record fields when the final output format of a delivery is in ‘Plain`, `W3C`, or `Raw` format.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique ID that identifies this delivery in your account.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#record_fields ⇒ Array<String>
The record fields used in this delivery.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#s3_delivery_configuration ⇒ Types::S3DeliveryConfiguration
This structure contains delivery configurations that apply only when the delivery destination resource is an S3 bucket.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that have been assigned to this delivery.
1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1861 class Delivery < Struct.new( :id, :arn, :delivery_source_name, :delivery_destination_arn, :delivery_destination_type, :record_fields, :field_delimiter, :s3_delivery_configuration, :tags) SENSITIVE = [] include Aws::Structure end |