Class: Aws::CloudWatchLogs::Types::DeliverySourceConfigurationSchema
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DeliverySourceConfigurationSchema
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
A structure that describes a single configuration for a log type, including its name, value type, default value, and the range of supported values.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_value ⇒ String
The default value of the configuration that is used when a value is not specified in a [PutDeliverySource] request.
-
#key_name ⇒ String
The name of the configuration.
-
#max_value ⇒ Float
The maximum numeric value allowed for the configuration.
-
#min_value ⇒ Float
The minimum numeric value allowed for the configuration.
-
#supported_values ⇒ Array<String>
The list of allowed values for the configuration.
-
#value_type ⇒ String
The data type of the configuration value.
Instance Attribute Details
#default_value ⇒ String
The default value of the configuration that is used when a value is not specified in a [PutDeliverySource] request.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDeliverySource.html
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2110 class DeliverySourceConfigurationSchema < Struct.new( :key_name, :value_type, :default_value, :supported_values, :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |
#key_name ⇒ String
The name of the configuration.
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2110 class DeliverySourceConfigurationSchema < Struct.new( :key_name, :value_type, :default_value, :supported_values, :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |
#max_value ⇒ Float
The maximum numeric value allowed for the configuration. This applies only when the ‘valueType` is a numeric type.
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2110 class DeliverySourceConfigurationSchema < Struct.new( :key_name, :value_type, :default_value, :supported_values, :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |
#min_value ⇒ Float
The minimum numeric value allowed for the configuration. This applies only when the ‘valueType` is a numeric type.
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2110 class DeliverySourceConfigurationSchema < Struct.new( :key_name, :value_type, :default_value, :supported_values, :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |
#supported_values ⇒ Array<String>
The list of allowed values for the configuration. Empty for free-form configuration.
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2110 class DeliverySourceConfigurationSchema < Struct.new( :key_name, :value_type, :default_value, :supported_values, :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |
#value_type ⇒ String
The data type of the configuration value. Valid values are ‘string`, `boolean`, `int`, `double`, and `long`.
2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2110 class DeliverySourceConfigurationSchema < Struct.new( :key_name, :value_type, :default_value, :supported_values, :min_value, :max_value) SENSITIVE = [] include Aws::Structure end |