Class: Aws::CloudWatchLogs::Types::DescribeAccountPoliciesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeAccountPoliciesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_identifiers ⇒ Array<String>
If you are using an account that is set up as a monitoring account for CloudWatch unified cross-account observability, you can use this to specify the account ID of a source account.
-
#policy_name ⇒ String
Use this parameter to limit the returned policies to only the policy with the name that you specify.
-
#policy_type ⇒ String
Use this parameter to limit the returned policies to only the policies that match the policy type that you specify.
Instance Attribute Details
#account_identifiers ⇒ Array<String>
If you are using an account that is set up as a monitoring account for CloudWatch unified cross-account observability, you can use this to specify the account ID of a source account. If you do, the operation returns the account policy for the specified account. Currently, you can specify only one account ID in this parameter.
If you omit this parameter, only the policy in the current account is returned.
449 450 451 452 453 454 455 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 449 class DescribeAccountPoliciesRequest < Struct.new( :policy_type, :policy_name, :account_identifiers) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
Use this parameter to limit the returned policies to only the policy with the name that you specify.
449 450 451 452 453 454 455 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 449 class DescribeAccountPoliciesRequest < Struct.new( :policy_type, :policy_name, :account_identifiers) SENSITIVE = [] include Aws::Structure end |
#policy_type ⇒ String
Use this parameter to limit the returned policies to only the policies that match the policy type that you specify. Currently, the only valid value is ‘DATA_PROTECTION_POLICY`.
449 450 451 452 453 454 455 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 449 class DescribeAccountPoliciesRequest < Struct.new( :policy_type, :policy_name, :account_identifiers) SENSITIVE = [] include Aws::Structure end |