Class: Aws::CloudWatchLogs::Types::DescribeConfigurationTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeConfigurationTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_destination_types ⇒ Array<String>
Use this parameter to filter the response to include only the configuration templates that apply to the delivery destination types that you specify here.
-
#limit ⇒ Integer
Use this parameter to limit the number of configuration templates that are returned in the response.
-
#log_types ⇒ Array<String>
Use this parameter to filter the response to include only the configuration templates that apply to the log types that you specify here.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#resource_types ⇒ Array<String>
Use this parameter to filter the response to include only the configuration templates that apply to the resource types that you specify here.
-
#service ⇒ String
Use this parameter to filter the response to include only the configuration templates that apply to the Amazon Web Services service that you specify here.
Instance Attribute Details
#delivery_destination_types ⇒ Array<String>
Use this parameter to filter the response to include only the configuration templates that apply to the delivery destination types that you specify here.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2219 class DescribeConfigurationTemplatesRequest < Struct.new( :service, :log_types, :resource_types, :delivery_destination_types, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Use this parameter to limit the number of configuration templates that are returned in the response.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2219 class DescribeConfigurationTemplatesRequest < Struct.new( :service, :log_types, :resource_types, :delivery_destination_types, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#log_types ⇒ Array<String>
Use this parameter to filter the response to include only the configuration templates that apply to the log types that you specify here.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2219 class DescribeConfigurationTemplatesRequest < Struct.new( :service, :log_types, :resource_types, :delivery_destination_types, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2219 class DescribeConfigurationTemplatesRequest < Struct.new( :service, :log_types, :resource_types, :delivery_destination_types, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<String>
Use this parameter to filter the response to include only the configuration templates that apply to the resource types that you specify here.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2219 class DescribeConfigurationTemplatesRequest < Struct.new( :service, :log_types, :resource_types, :delivery_destination_types, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#service ⇒ String
Use this parameter to filter the response to include only the configuration templates that apply to the Amazon Web Services service that you specify here.
2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2219 class DescribeConfigurationTemplatesRequest < Struct.new( :service, :log_types, :resource_types, :delivery_destination_types, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |