Class: Aws::CloudWatchLogs::Types::DescribeLogGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeLogGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass DescribeLogGroupsRequest data as a hash:
{
log_group_name_prefix: "LogGroupName",
next_token: "NextToken",
limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
The maximum number of items returned.
-
#log_group_name_prefix ⇒ String
The prefix to match.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#limit ⇒ Integer
The maximum number of items returned. If you don't specify a value, the default is up to 50 items.
554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 554 class DescribeLogGroupsRequest < Struct.new( :log_group_name_prefix, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_name_prefix ⇒ String
The prefix to match.
554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 554 class DescribeLogGroupsRequest < Struct.new( :log_group_name_prefix, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
554 555 556 557 558 559 560 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 554 class DescribeLogGroupsRequest < Struct.new( :log_group_name_prefix, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |