Class: Aws::CloudWatchLogs::Types::DescribeMetricFiltersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeMetricFiltersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_name_prefix ⇒ String
The prefix to match.
-
#limit ⇒ Integer
The maximum number of items returned.
-
#log_group_name ⇒ String
The name of the log group.
-
#metric_name ⇒ String
Filters results to include only those with the specified metric name.
-
#metric_namespace ⇒ String
Filters results to include only those in the specified namespace.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#filter_name_prefix ⇒ String
The prefix to match. CloudWatch Logs uses the value that you set here only if you also include the logGroupName parameter in your request.
2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2720 class DescribeMetricFiltersRequest < Struct.new( :log_group_name, :filter_name_prefix, :next_token, :limit, :metric_name, :metric_namespace) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of items returned. If you don’t specify a value, the default is up to 50 items.
2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2720 class DescribeMetricFiltersRequest < Struct.new( :log_group_name, :filter_name_prefix, :next_token, :limit, :metric_name, :metric_namespace) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2720 class DescribeMetricFiltersRequest < Struct.new( :log_group_name, :filter_name_prefix, :next_token, :limit, :metric_name, :metric_namespace) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
Filters results to include only those with the specified metric name. If you include this parameter in your request, you must also include the metricNamespace parameter.
2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2720 class DescribeMetricFiltersRequest < Struct.new( :log_group_name, :filter_name_prefix, :next_token, :limit, :metric_name, :metric_namespace) SENSITIVE = [] include Aws::Structure end |
#metric_namespace ⇒ String
Filters results to include only those in the specified namespace. If you include this parameter in your request, you must also include the metricName parameter.
2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2720 class DescribeMetricFiltersRequest < Struct.new( :log_group_name, :filter_name_prefix, :next_token, :limit, :metric_name, :metric_namespace) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2720 class DescribeMetricFiltersRequest < Struct.new( :log_group_name, :filter_name_prefix, :next_token, :limit, :metric_name, :metric_namespace) SENSITIVE = [] include Aws::Structure end |