Class: Aws::CloudWatchLogs::Types::DescribeQueriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeQueriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_name ⇒ String
Limits the returned queries to only those for the specified log group.
-
#max_results ⇒ Integer
Limits the number of returned queries to the specified number.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#query_language ⇒ String
Limits the returned queries to only the queries that use the specified query language.
-
#status ⇒ String
Limits the returned queries to only those that have the specified status.
Instance Attribute Details
#log_group_name ⇒ String
Limits the returned queries to only those for the specified log group.
3023 3024 3025 3026 3027 3028 3029 3030 3031 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3023 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token, :query_language) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Limits the number of returned queries to the specified number.
3023 3024 3025 3026 3027 3028 3029 3030 3031 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3023 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token, :query_language) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
3023 3024 3025 3026 3027 3028 3029 3030 3031 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3023 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token, :query_language) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
Limits the returned queries to only the queries that use the specified query language.
3023 3024 3025 3026 3027 3028 3029 3030 3031 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3023 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token, :query_language) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Limits the returned queries to only those that have the specified
status. Valid values are Cancelled, Complete, Failed,
Running, and Scheduled.
3023 3024 3025 3026 3027 3028 3029 3030 3031 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3023 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token, :query_language) SENSITIVE = [] include Aws::Structure end |