Class: Aws::CloudWatchLogs::Types::DescribeQueriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeQueriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass DescribeQueriesRequest data as a hash:
{
log_group_name: "LogGroupName",
status: "Scheduled", # accepts Scheduled, Running, Complete, Failed, Cancelled, Timeout, Unknown
max_results: 1,
next_token: "NextToken",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_name ⇒ String
Limits the returned queries to only those for the specified log group.
-
#max_results ⇒ Integer
Limits the number of returned queries to the specified number.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#status ⇒ String
Limits the returned queries to only those that have the specified status.
Instance Attribute Details
#log_group_name ⇒ String
Limits the returned queries to only those for the specified log group.
772 773 774 775 776 777 778 779 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 772 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Limits the number of returned queries to the specified number.
772 773 774 775 776 777 778 779 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 772 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
772 773 774 775 776 777 778 779 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 772 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Limits the returned queries to only those that have the specified status. Valid values are `Cancelled`, `Complete`, `Failed`, `Running`, and `Scheduled`.
772 773 774 775 776 777 778 779 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 772 class DescribeQueriesRequest < Struct.new( :log_group_name, :status, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |