Class: Aws::CloudWatchLogs::Types::DescribeQueryDefinitionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::DescribeQueryDefinitionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Limits the number of returned query definitions to the specified number.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#query_definition_name_prefix ⇒ String
Use this parameter to filter your results to only the query definitions that have names that start with the prefix you specify.
-
#query_language ⇒ String
The query language used for this query.
Instance Attribute Details
#max_results ⇒ Integer
Limits the number of returned query definitions to the specified number.
3066 3067 3068 3069 3070 3071 3072 3073 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3066 class DescribeQueryDefinitionsRequest < Struct.new( :query_language, :query_definition_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
3066 3067 3068 3069 3070 3071 3072 3073 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3066 class DescribeQueryDefinitionsRequest < Struct.new( :query_language, :query_definition_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#query_definition_name_prefix ⇒ String
Use this parameter to filter your results to only the query definitions that have names that start with the prefix you specify.
3066 3067 3068 3069 3070 3071 3072 3073 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3066 class DescribeQueryDefinitionsRequest < Struct.new( :query_language, :query_definition_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see [Supported query languages].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData_Languages.html
3066 3067 3068 3069 3070 3071 3072 3073 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3066 class DescribeQueryDefinitionsRequest < Struct.new( :query_language, :query_definition_name_prefix, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |