Class: Aws::CloudWatchLogs::Types::FieldIndex

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure describes one log event field that is used as an index in at least one index policy in this account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#field_index_nameString

The string that this field index matches.

Returns:

  • (String)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end

#first_event_timeInteger

The time and date of the earliest log event that matches this field index, after the index policy that contains it was created.

Returns:

  • (Integer)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end

#index_categoryString

The category of the field index:

  • DEFAULT: Fields that CloudWatch Logs indexes by default. Examples include @logStream and @data_format.

  • CUSTOM: Fields that you added manually to the field index policy. CloudWatch Logs always indexes these fields. These fields count toward the quota of 20 fields for each log group.

  • AUTO: Fields that CloudWatch Logs indexes automatically based on your query patterns and usage. These fields do not count toward the field index quota. CloudWatch Logs might update these fields based on changes in your query patterns. To keep a field indexed permanently, add it to an account-level or log-group level field index policy.

  • INACTIVE: Fields that CloudWatch Logs indexed before but does not index now. This happens if you remove a field from the field index policy or if CloudWatch Logs automatically selects a different field based on your queries.

For more information about automatically indexed fields, see Automatically indexed fields.

Returns:

  • (String)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end

#last_event_timeInteger

The time and date of the most recent log event that matches this field index.

Returns:

  • (Integer)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end

#last_scan_timeInteger

The most recent time that CloudWatch Logs scanned ingested log events to search for this field index to improve the speed of future CloudWatch Logs Insights queries that search for this field index.

Returns:

  • (Integer)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifierString

If this field index appears in an index policy that applies only to a single log group, the ARN of that log group is displayed here.

Returns:

  • (String)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of index. Specify FACET for facet-based indexing or FIELD_INDEX for field-based indexing. This determines how the field is indexed and can be queried.

Returns:

  • (String)


3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3579

class FieldIndex < Struct.new(
  :log_group_identifier,
  :field_index_name,
  :last_scan_time,
  :first_event_time,
  :last_event_time,
  :type,
  :index_category)
  SENSITIVE = []
  include Aws::Structure
end