Class: Aws::CloudWatchLogs::Types::FieldIndex
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::FieldIndex
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure describes one log event field that is used as an index in at least one index policy in this account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_index_name ⇒ String
The string that this field index matches.
-
#first_event_time ⇒ Integer
The time and date of the earliest log event that matches this field index, after the index policy that contains it was created.
-
#last_event_time ⇒ Integer
The time and date of the most recent log event that matches this field index.
-
#last_scan_time ⇒ Integer
The most recent time that CloudWatch Logs scanned ingested log events to search for this field index to improve the speed of future CloudWatch Logs Insights queries that search for this field index.
-
#log_group_identifier ⇒ String
If this field index appears in an index policy that applies only to a single log group, the ARN of that log group is displayed here.
-
#type ⇒ String
The type of index.
Instance Attribute Details
#field_index_name ⇒ String
The string that this field index matches.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3494 class FieldIndex < Struct.new( :log_group_identifier, :field_index_name, :last_scan_time, :first_event_time, :last_event_time, :type) SENSITIVE = [] include Aws::Structure end |
#first_event_time ⇒ Integer
The time and date of the earliest log event that matches this field index, after the index policy that contains it was created.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3494 class FieldIndex < Struct.new( :log_group_identifier, :field_index_name, :last_scan_time, :first_event_time, :last_event_time, :type) SENSITIVE = [] include Aws::Structure end |
#last_event_time ⇒ Integer
The time and date of the most recent log event that matches this field index.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3494 class FieldIndex < Struct.new( :log_group_identifier, :field_index_name, :last_scan_time, :first_event_time, :last_event_time, :type) SENSITIVE = [] include Aws::Structure end |
#last_scan_time ⇒ Integer
The most recent time that CloudWatch Logs scanned ingested log events to search for this field index to improve the speed of future CloudWatch Logs Insights queries that search for this field index.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3494 class FieldIndex < Struct.new( :log_group_identifier, :field_index_name, :last_scan_time, :first_event_time, :last_event_time, :type) SENSITIVE = [] include Aws::Structure end |
#log_group_identifier ⇒ String
If this field index appears in an index policy that applies only to a single log group, the ARN of that log group is displayed here.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3494 class FieldIndex < Struct.new( :log_group_identifier, :field_index_name, :last_scan_time, :first_event_time, :last_event_time, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of index. Specify ‘FACET` for facet-based indexing or `FIELD_INDEX` for field-based indexing. This determines how the field is indexed and can be queried.
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3494 class FieldIndex < Struct.new( :log_group_identifier, :field_index_name, :last_scan_time, :first_event_time, :last_event_time, :type) SENSITIVE = [] include Aws::Structure end |