Class: Aws::CloudWatchLogs::Types::GetIntegrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integration_detailsTypes::IntegrationDetails

A structure that contains information about the integration configuration. For an integration with OpenSearch Service, this includes information about OpenSearch Service resources such as the collection, the workspace, and policies.



3890
3891
3892
3893
3894
3895
3896
3897
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3890

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration.

Returns:

  • (String)


3890
3891
3892
3893
3894
3895
3896
3897
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3890

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end

#integration_statusString

The current status of this integration.

Returns:

  • (String)


3890
3891
3892
3893
3894
3895
3896
3897
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3890

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end

#integration_typeString

The type of integration. Integrations with OpenSearch Service have the type ‘OPENSEARCH`.

Returns:

  • (String)


3890
3891
3892
3893
3894
3895
3896
3897
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3890

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end