Class: Aws::CloudWatchLogs::Types::GetIntegrationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#integration_detailsTypes::IntegrationDetails

A structure that contains information about the integration configuration. For an integration with OpenSearch Service, this includes information about OpenSearch Service resources such as the collection, the workspace, and policies.



3850
3851
3852
3853
3854
3855
3856
3857
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3850

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration.

Returns:

  • (String)


3850
3851
3852
3853
3854
3855
3856
3857
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3850

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end

#integration_statusString

The current status of this integration.

Returns:

  • (String)


3850
3851
3852
3853
3854
3855
3856
3857
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3850

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end

#integration_typeString

The type of integration. Integrations with OpenSearch Service have the type ‘OPENSEARCH`.

Returns:

  • (String)


3850
3851
3852
3853
3854
3855
3856
3857
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3850

class GetIntegrationResponse < Struct.new(
  :integration_name,
  :integration_type,
  :integration_status,
  :integration_details)
  SENSITIVE = []
  include Aws::Structure
end