Class: Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector to retrieve information about.
Instance Attribute Details
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector to retrieve information about. You can find the ARNs of log anomaly detectors in your account by using the ListLogAnomalyDetectors operation.
3930 3931 3932 3933 3934 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3930 class GetLogAnomalyDetectorRequest < Struct.new( :anomaly_detector_arn) SENSITIVE = [] include Aws::Structure end |