Class: Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogAnomalyDetectorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_status ⇒ String
Specifies whether the anomaly detector is currently active.
-
#anomaly_visibility_time ⇒ Integer
The number of days used as the life cycle of anomalies.
-
#creation_time_stamp ⇒ Integer
The date and time when this anomaly detector was created.
-
#detector_name ⇒ String
The name of the log anomaly detector.
-
#evaluation_frequency ⇒ String
Specifies how often the anomaly detector runs and look for anomalies.
-
#filter_pattern ⇒ String
A symbolic description of how CloudWatch Logs should interpret the data in each log event.
-
#kms_key_id ⇒ String
The ARN of the KMS key assigned to this anomaly detector, if any.
-
#last_modified_time_stamp ⇒ Integer
The date and time when this anomaly detector was most recently modified.
-
#log_group_arn_list ⇒ Array<String>
An array of structures, where each structure contains the ARN of a log group associated with this anomaly detector.
Instance Attribute Details
#anomaly_detector_status ⇒ String
Specifies whether the anomaly detector is currently active. To change its status, use the ‘enabled` parameter in the
- UpdateLogAnomalyDetector][1
-
operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_UpdateLogAnomalyDetector.html
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#anomaly_visibility_time ⇒ Integer
The number of days used as the life cycle of anomalies. After this time, anomalies are automatically baselined and the anomaly detector model will treat new occurrences of similar event as normal.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#creation_time_stamp ⇒ Integer
The date and time when this anomaly detector was created.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#detector_name ⇒ String
The name of the log anomaly detector
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#evaluation_frequency ⇒ String
Specifies how often the anomaly detector runs and look for anomalies. Set this value according to the frequency that the log group receives new logs. For example, if the log group receives new log events every 10 minutes, then setting ‘evaluationFrequency` to `FIFTEEN_MIN` might be appropriate.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#filter_pattern ⇒ String
A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key assigned to this anomaly detector, if any.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time_stamp ⇒ Integer
The date and time when this anomaly detector was most recently modified.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |
#log_group_arn_list ⇒ Array<String>
An array of structures, where each structure contains the ARN of a log group associated with this anomaly detector.
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3953 class GetLogAnomalyDetectorResponse < Struct.new( :detector_name, :log_group_arn_list, :evaluation_frequency, :filter_pattern, :anomaly_detector_status, :kms_key_id, :creation_time_stamp, :last_modified_time_stamp, :anomaly_visibility_time) SENSITIVE = [] include Aws::Structure end |