Class: Aws::CloudWatchLogs::Types::GetLogEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
The end of the time range, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`.
-
#limit ⇒ Integer
The maximum number of log events returned.
-
#log_group_identifier ⇒ String
Specify either the name or ARN of the log group to view events from.
-
#log_group_name ⇒ String
The name of the log group.
-
#log_stream_name ⇒ String
The name of the log stream.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#start_from_head ⇒ Boolean
If the value is true, the earliest log events are returned first.
-
#start_time ⇒ Integer
The start of the time range, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`.
-
#unmask ⇒ Boolean
Specify `true` to display the log event fields with all sensitive data unmasked and visible.
Instance Attribute Details
#end_time ⇒ Integer
The end of the time range, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`. Events with a timestamp equal to or later than this time are not included.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of log events returned. If you don't specify a limit, the default is as many log events as can fit in a response size of 1 MB (up to 10,000 log events).
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_group_identifier ⇒ String
Specify either the name or ARN of the log group to view events from. If the log group is in a source account and you are using a monitoring account, you must use the log group ARN.
If you specify values for both `logGroupName` and `logGroupIdentifier`, the action returns an `InvalidParameterException` error.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
<note markdown=“1”> If you specify values for both `logGroupName` and `logGroupIdentifier`, the action returns an `InvalidParameterException` error.
</note>
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#log_stream_name ⇒ String
The name of the log stream.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#start_from_head ⇒ Boolean
If the value is true, the earliest log events are returned first. If the value is false, the latest log events are returned first. The default value is false.
If you are using a previous `nextForwardToken` value as the `nextToken` in this operation, you must specify `true` for `startFromHead`.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Integer
The start of the time range, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`. Events with a timestamp equal to this time or later than this time are included. Events with a timestamp earlier than this time are not included.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |
#unmask ⇒ Boolean
Specify `true` to display the log event fields with all sensitive data unmasked and visible. The default is `false`.
To use this operation with this parameter, you must be signed into an account with the `logs:Unmask` permission.
1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1269 class GetLogEventsRequest < Struct.new( :log_group_name, :log_group_identifier, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head, :unmask) SENSITIVE = [] include Aws::Structure end |