Class: Aws::CloudWatchLogs::Types::GetLogEventsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Note:

When making an API call, you may pass GetLogEventsRequest data as a hash:

{
  log_group_name: "LogGroupName", # required
  log_group_identifier: "LogGroupIdentifier",
  log_stream_name: "LogStreamName", # required
  start_time: 1,
  end_time: 1,
  next_token: "NextToken",
  limit: 1,
  start_from_head: false,
  unmask: false,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeInteger

The end of the time range, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`. Events with a timestamp equal to or later than this time are not included.

Returns:

  • (Integer)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of log events returned. If you don't specify a limit, the default is as many log events as can fit in a response size of 1 MB (up to 10,000 log events).

Returns:

  • (Integer)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifierString

Specify either the name or ARN of the log group to view events from. If the log group is in a source account and you are using a monitoring account, you must use the log group ARN.

If you specify values for both `logGroupName` and `logGroupIdentifier`, the action returns an `InvalidParameterException` error.

Returns:

  • (String)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group.

<note markdown=“1”> If you specify values for both `logGroupName` and `logGroupIdentifier`, the action returns an `InvalidParameterException` error.

</note>

Returns:

  • (String)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#log_stream_nameString

The name of the log stream.

Returns:

  • (String)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. (You received this token from a previous call.)

Returns:

  • (String)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#start_from_headBoolean

If the value is true, the earliest log events are returned first. If the value is false, the latest log events are returned first. The default value is false.

If you are using a previous `nextForwardToken` value as the `nextToken` in this operation, you must specify `true` for `startFromHead`.

Returns:

  • (Boolean)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeInteger

The start of the time range, expressed as the number of milliseconds after `Jan 1, 1970 00:00:00 UTC`. Events with a timestamp equal to this time or later than this time are included. Events with a timestamp earlier than this time are not included.

Returns:

  • (Integer)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end

#unmaskBoolean

Specify `true` to display the log event fields with all sensitive data unmasked and visible. The default is `false`.

To use this operation with this parameter, you must be signed into an account with the `logs:Unmask` permission.

Returns:

  • (Boolean)


1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1517

class GetLogEventsRequest < Struct.new(
  :log_group_name,
  :log_group_identifier,
  :log_stream_name,
  :start_time,
  :end_time,
  :next_token,
  :limit,
  :start_from_head,
  :unmask)
  SENSITIVE = []
  include Aws::Structure
end