Class: Aws::CloudWatchLogs::Types::GetLogEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
When making an API call, you may pass GetLogEventsRequest data as a hash:
{
log_group_name: "LogGroupName", # required
log_stream_name: "LogStreamName", # required
start_time: 1,
end_time: 1,
next_token: "NextToken",
limit: 1,
start_from_head: false,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
The end of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
-
#limit ⇒ Integer
The maximum number of log events returned.
-
#log_group_name ⇒ String
The name of the log group.
-
#log_stream_name ⇒ String
The name of the log stream.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#start_from_head ⇒ Boolean
If the value is true, the earliest log events are returned first.
-
#start_time ⇒ Integer
The start of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
Instance Attribute Details
#end_time ⇒ Integer
The end of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp equal to or later than this time are not included.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of log events returned. If you don't specify a value, the maximum is as many log events as can fit in a response size of 1 MB, up to 10,000 log events.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |
#log_stream_name ⇒ String
The name of the log stream.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. (You received this token from a previous call.)
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |
#start_from_head ⇒ Boolean
If the value is true, the earliest log events are returned first. If the value is false, the latest log events are returned first. The default value is false.
If you are using a previous `nextForwardToken` value as the `nextToken` in this operation, you must specify `true` for `startFromHead`.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Integer
The start of the time range, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC. Events with a timestamp equal to this time or later than this time are included. Events with a timestamp earlier than this time are not included.
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1340 class GetLogEventsRequest < Struct.new( :log_group_name, :log_stream_name, :start_time, :end_time, :next_token, :limit, :start_from_head) SENSITIVE = [] include Aws::Structure end |