Class: Aws::CloudWatchLogs::Types::GetLogEventsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogEventsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::OutputLogEvent>
The events.
-
#next_backward_token ⇒ String
The token for the next set of items in the backward direction.
-
#next_forward_token ⇒ String
The token for the next set of items in the forward direction.
Instance Attribute Details
#events ⇒ Array<Types::OutputLogEvent>
The events.
2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2033 class GetLogEventsResponse < Struct.new( :events, :next_forward_token, :next_backward_token) SENSITIVE = [] include Aws::Structure end |
#next_backward_token ⇒ String
The token for the next set of items in the backward direction. The token expires after 24 hours. This token is not null. If you have reached the end of the stream, it returns the same token you passed in.
2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2033 class GetLogEventsResponse < Struct.new( :events, :next_forward_token, :next_backward_token) SENSITIVE = [] include Aws::Structure end |
#next_forward_token ⇒ String
The token for the next set of items in the forward direction. The token expires after 24 hours. If you have reached the end of the stream, it returns the same token you passed in.
2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2033 class GetLogEventsResponse < Struct.new( :events, :next_forward_token, :next_backward_token) SENSITIVE = [] include Aws::Structure end |