Class: Aws::CloudWatchLogs::Types::GetLogEventsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::OutputLogEvent>

The events.

Returns:



1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1476

class GetLogEventsResponse < Struct.new(
  :events,
  :next_forward_token,
  :next_backward_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_backward_tokenString

The token for the next set of items in the backward direction. The token expires after 24 hours. This token is not null. If you have reached the end of the stream, it returns the same token you passed in.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1476

class GetLogEventsResponse < Struct.new(
  :events,
  :next_forward_token,
  :next_backward_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_forward_tokenString

The token for the next set of items in the forward direction. The token expires after 24 hours. If you have reached the end of the stream, it returns the same token you passed in.

Returns:

  • (String)


1476
1477
1478
1479
1480
1481
1482
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1476

class GetLogEventsResponse < Struct.new(
  :events,
  :next_forward_token,
  :next_backward_token)
  SENSITIVE = []
  include Aws::Structure
end