Class: Aws::CloudWatchLogs::Types::GetLogGroupFieldsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Note:

When making an API call, you may pass GetLogGroupFieldsRequest data as a hash:

{
  log_group_name: "LogGroupName", # required
  time: 1,
  log_group_identifier: "LogGroupIdentifier",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_identifierString

Specify either the name or ARN of the log group to view. If the log group is in a source account and you are using a monitoring account, you must specify the ARN.

If you specify values for both `logGroupName` and `logGroupIdentifier`, the action returns an `InvalidParameterException` error.

Returns:

  • (String)


1596
1597
1598
1599
1600
1601
1602
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1596

class GetLogGroupFieldsRequest < Struct.new(
  :log_group_name,
  :time,
  :log_group_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group to search.

If you specify values for both `logGroupName` and `logGroupIdentifier`, the action returns an `InvalidParameterException` error.

Returns:

  • (String)


1596
1597
1598
1599
1600
1601
1602
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1596

class GetLogGroupFieldsRequest < Struct.new(
  :log_group_name,
  :time,
  :log_group_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#timeInteger

The time to set as the center of the query. If you specify `time`, the 15 minutes before this time are queries. If you omit `time`, the 8 minutes before and 8 minutes after this time are searched.

The `time` value is specified as epoch time, which is the number of seconds since `January 1, 1970, 00:00:00 UTC`.

Returns:

  • (Integer)


1596
1597
1598
1599
1600
1601
1602
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1596

class GetLogGroupFieldsRequest < Struct.new(
  :log_group_name,
  :time,
  :log_group_identifier)
  SENSITIVE = []
  include Aws::Structure
end