Class: Aws::CloudWatchLogs::Types::GetLogGroupFieldsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogGroupFieldsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass GetLogGroupFieldsRequest data as a hash:
{
log_group_name: "LogGroupName", # required
time: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_name ⇒ String
The name of the log group to search.
-
#time ⇒ Integer
The time to set as the center of the query.
Instance Attribute Details
#log_group_name ⇒ String
The name of the log group to search.
1399 1400 1401 1402 1403 1404 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1399 class GetLogGroupFieldsRequest < Struct.new( :log_group_name, :time) SENSITIVE = [] include Aws::Structure end |
#time ⇒ Integer
The time to set as the center of the query. If you specify `time`, the 15 minutes before this time are queries. If you omit `time` the 8 minutes before and 8 minutes after this time are searched.
The `time` value is specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.
1399 1400 1401 1402 1403 1404 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1399 class GetLogGroupFieldsRequest < Struct.new( :log_group_name, :time) SENSITIVE = [] include Aws::Structure end |