Class: Aws::CloudWatchLogs::Types::GetLogGroupFieldsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogGroupFieldsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_fields ⇒ Array<Types::LogGroupField>
The array of fields found in the query.
Instance Attribute Details
#log_group_fields ⇒ Array<Types::LogGroupField>
The array of fields found in the query. Each object in the array contains the name of the field, along with the percentage of time it appeared in the log events that were queried.
3377 3378 3379 3380 3381 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3377 class GetLogGroupFieldsResponse < Struct.new( :log_group_fields) SENSITIVE = [] include Aws::Structure end |