Class: Aws::CloudWatchLogs::Types::GetLogGroupFieldsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_fieldsArray<Types::LogGroupField>

The array of fields found in the query. Each object in the array contains the name of the field, along with the percentage of time it appeared in the log events that were queried.

Returns:



1369
1370
1371
1372
1373
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1369

class GetLogGroupFieldsResponse < Struct.new(
  :log_group_fields)
  SENSITIVE = []
  include Aws::Structure
end