Class: Aws::CloudWatchLogs::Types::GetLogObjectRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

The parameters for the GetLogObject operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_object_pointerString

A pointer to the specific log object to retrieve. This is a required parameter that uniquely identifies the log object within CloudWatch Logs. The pointer is typically obtained from a previous query or filter operation.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4177

class GetLogObjectRequest < Struct.new(
  :unmask,
  :log_object_pointer)
  SENSITIVE = []
  include Aws::Structure
end

#unmaskBoolean

A boolean flag that indicates whether to unmask sensitive log data. When set to true, any masked or redacted data in the log object will be displayed in its original form. Default is false.

Returns:

  • (Boolean)


4177
4178
4179
4180
4181
4182
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4177

class GetLogObjectRequest < Struct.new(
  :unmask,
  :log_object_pointer)
  SENSITIVE = []
  include Aws::Structure
end