Class: Aws::CloudWatchLogs::Types::GetLogRecordRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetLogRecordRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_record_pointer ⇒ String
The pointer corresponding to the log event record you want to retrieve.
-
#unmask ⇒ Boolean
Specify
trueto display the log event fields with all sensitive data unmasked and visible.
Instance Attribute Details
#log_record_pointer ⇒ String
The pointer corresponding to the log event record you want to retrieve. You get this from the response of a GetQueryResults operation. In that response, the value of the ‘@ptr` field for a log event is the value to use as logRecordPointer to retrieve that complete log event record.
3981 3982 3983 3984 3985 3986 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3981 class GetLogRecordRequest < Struct.new( :log_record_pointer, :unmask) SENSITIVE = [] include Aws::Structure end |
#unmask ⇒ Boolean
Specify true to display the log event fields with all sensitive data unmasked and visible. The default is false.
To use this operation with this parameter, you must be signed into an account with the logs:Unmask permission.
3981 3982 3983 3984 3985 3986 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3981 class GetLogRecordRequest < Struct.new( :log_record_pointer, :unmask) SENSITIVE = [] include Aws::Structure end |