Class: Aws::CloudWatchLogs::Types::GetQueryResultsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetQueryResultsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_key ⇒ String
If you associated an KMS key with the CloudWatch Logs Insights query results in this account, this field displays the ARN of the key that’s used to encrypt the query results when [StartQuery] stores them.
-
#next_token ⇒ String
If there are more log events remaining in the results, the response includes a ‘nextToken`.
-
#query_language ⇒ String
The query language used for this query.
-
#results ⇒ Array<Array<Types::ResultField>>
The log events that matched the query criteria during the most recent time it ran.
-
#statistics ⇒ Types::QueryStatistics
Includes the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the scanned log events.
-
#status ⇒ String
The status of the most recent running of the query.
Instance Attribute Details
#encryption_key ⇒ String
If you associated an KMS key with the CloudWatch Logs Insights query results in this account, this field displays the ARN of the key that’s used to encrypt the query results when [StartQuery] stores them.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_StartQuery.html
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4257 class GetQueryResultsResponse < Struct.new( :query_language, :results, :statistics, :status, :encryption_key, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If there are more log events remaining in the results, the response includes a ‘nextToken`. You can use this token in a subsequent `GetQueryResults` request to get the next set of results.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4257 class GetQueryResultsResponse < Struct.new( :query_language, :results, :statistics, :status, :encryption_key, :next_token) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see [Supported query languages].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData_Languages.html
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4257 class GetQueryResultsResponse < Struct.new( :query_language, :results, :statistics, :status, :encryption_key, :next_token) SENSITIVE = [] include Aws::Structure end |
#results ⇒ Array<Array<Types::ResultField>>
The log events that matched the query criteria during the most recent time it ran.
The ‘results` value is an array of arrays. Each log event is one object in the top-level array. Each of these log event objects is an array of `field`/`value` pairs.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4257 class GetQueryResultsResponse < Struct.new( :query_language, :results, :statistics, :status, :encryption_key, :next_token) SENSITIVE = [] include Aws::Structure end |
#statistics ⇒ Types::QueryStatistics
Includes the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the scanned log events. These values reflect the full raw results of the query.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4257 class GetQueryResultsResponse < Struct.new( :query_language, :results, :statistics, :status, :encryption_key, :next_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the most recent running of the query. Possible values are ‘Cancelled`, `Complete`, `Failed`, `Running`, `Scheduled`, `Timeout`, and `Unknown`.
Queries time out after 60 minutes of runtime. To avoid having your queries time out, reduce the time range being searched or partition your query into a number of queries.
4257 4258 4259 4260 4261 4262 4263 4264 4265 4266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4257 class GetQueryResultsResponse < Struct.new( :query_language, :results, :statistics, :status, :encryption_key, :next_token) SENSITIVE = [] include Aws::Structure end |