Class: Aws::CloudWatchLogs::Types::GetQueryResultsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resultsArray<Array<Types::ResultField>>

The log events that matched the query criteria during the most recent time it ran.

The `results` value is an array of arrays. Each log event is one object in the top-level array. Each of these log event objects is an array of `field`/`value` pairs.

Returns:



1505
1506
1507
1508
1509
1510
1511
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1505

class GetQueryResultsResponse < Struct.new(
  :results,
  :statistics,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statisticsTypes::QueryStatistics

Includes the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the log events that were scanned. These values reflect the full raw results of the query.



1505
1506
1507
1508
1509
1510
1511
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1505

class GetQueryResultsResponse < Struct.new(
  :results,
  :statistics,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the most recent running of the query. Possible values are `Cancelled`, `Complete`, `Failed`, `Running`, `Scheduled`, `Timeout`, and `Unknown`.

Queries time out after 15 minutes of execution. To avoid having your queries time out, reduce the time range being searched or partition your query into a number of queries.

Returns:

  • (String)


1505
1506
1507
1508
1509
1510
1511
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1505

class GetQueryResultsResponse < Struct.new(
  :results,
  :statistics,
  :status)
  SENSITIVE = []
  include Aws::Structure
end