Class: Aws::CloudWatchLogs::Types::GetScheduledQueryHistoryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The name of the scheduled query.

Returns:

  • (String)


4308
4309
4310
4311
4312
4313
4314
4315
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4308

class GetScheduledQueryHistoryResponse < Struct.new(
  :name,
  :scheduled_query_arn,
  :trigger_history,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token for the next set of items to return. The token expires after 24 hours.

Returns:

  • (String)


4308
4309
4310
4311
4312
4313
4314
4315
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4308

class GetScheduledQueryHistoryResponse < Struct.new(
  :name,
  :scheduled_query_arn,
  :trigger_history,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_query_arnString

The ARN of the scheduled query.

Returns:

  • (String)


4308
4309
4310
4311
4312
4313
4314
4315
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4308

class GetScheduledQueryHistoryResponse < Struct.new(
  :name,
  :scheduled_query_arn,
  :trigger_history,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_historyArray<Types::TriggerHistoryRecord>

An array of execution history records for the scheduled query.

Returns:



4308
4309
4310
4311
4312
4313
4314
4315
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4308

class GetScheduledQueryHistoryResponse < Struct.new(
  :name,
  :scheduled_query_arn,
  :trigger_history,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end