Class: Aws::CloudWatchLogs::Types::GetScheduledQueryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetScheduledQueryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Integer
The timestamp when the scheduled query was created.
-
#description ⇒ String
The description of the scheduled query.
-
#destination_configuration ⇒ Types::DestinationConfiguration
Configuration for where query results are delivered.
-
#end_time_offset ⇒ Integer
The time offset in seconds that defines the end of the lookback period for the query.
-
#execution_role_arn ⇒ String
The ARN of the IAM role used to execute the query and deliver results.
-
#last_execution_status ⇒ String
The status of the most recent execution of the scheduled query.
-
#last_triggered_time ⇒ Integer
The timestamp when the scheduled query was last executed.
-
#last_updated_time ⇒ Integer
The timestamp when the scheduled query was last updated.
-
#log_group_identifiers ⇒ Array<String>
The log groups queried by the scheduled query.
-
#name ⇒ String
The name of the scheduled query.
-
#query_language ⇒ String
The query language used by the scheduled query.
-
#query_string ⇒ String
The query string executed by the scheduled query.
-
#schedule_end_time ⇒ Integer
The end time for the scheduled query in Unix epoch format.
-
#schedule_expression ⇒ String
The cron expression that defines when the scheduled query runs.
-
#schedule_start_time ⇒ Integer
The start time for the scheduled query in Unix epoch format.
-
#schedule_type ⇒ String
The schedule type of the scheduled query.
-
#scheduled_query_arn ⇒ String
The ARN of the scheduled query.
-
#start_time_offset ⇒ Integer
The time offset in seconds that defines the lookback period for the query.
-
#state ⇒ String
The current state of the scheduled query.
-
#timezone ⇒ String
The timezone used for evaluating the schedule expression.
Instance Attribute Details
#creation_time ⇒ Integer
The timestamp when the scheduled query was created.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#destination_configuration ⇒ Types::DestinationConfiguration
Configuration for where query results are delivered.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#end_time_offset ⇒ Integer
The time offset in seconds that defines the end of the lookback period for the query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The ARN of the IAM role used to execute the query and deliver results.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_execution_status ⇒ String
The status of the most recent execution of the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_triggered_time ⇒ Integer
The timestamp when the scheduled query was last executed.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Integer
The timestamp when the scheduled query was last updated.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
The log groups queried by the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The query language used by the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string executed by the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_end_time ⇒ Integer
The end time for the scheduled query in Unix epoch format.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_expression ⇒ String
The cron expression that defines when the scheduled query runs.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_start_time ⇒ Integer
The start time for the scheduled query in Unix epoch format.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_type ⇒ String
The schedule type of the scheduled query. Valid values are ‘CUSTOMER_MANAGED` and `AWS_MANAGED`.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#scheduled_query_arn ⇒ String
The ARN of the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#start_time_offset ⇒ Integer
The time offset in seconds that defines the lookback period for the query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the scheduled query.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#timezone ⇒ String
The timezone used for evaluating the schedule expression.
4554 4555 4556 4557 4558 4559 4560 4561 4562 4563 4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 4577 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4554 class GetScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |