Class: Aws::CloudWatchLogs::Types::GetStorageTierPolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_updated_timeInteger

The time when the storage tier policy was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.

Returns:

  • (Integer)


4615
4616
4617
4618
4619
4620
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4615

class GetStorageTierPolicyResponse < Struct.new(
  :storage_tier,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#storage_tierString

The current storage tier for the account.

Returns:

  • (String)


4615
4616
4617
4618
4619
4620
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4615

class GetStorageTierPolicyResponse < Struct.new(
  :storage_tier,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end