Class: Aws::CloudWatchLogs::Types::GetStorageTierPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::GetStorageTierPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_time ⇒ Integer
The time when the storage tier policy was last updated, expressed as the number of milliseconds after
Jan 1, 1970 00:00:00 UTC. -
#storage_tier ⇒ String
The current storage tier for the account.
Instance Attribute Details
#last_updated_time ⇒ Integer
The time when the storage tier policy was last updated, expressed as
the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4615 class GetStorageTierPolicyResponse < Struct.new( :storage_tier, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#storage_tier ⇒ String
The current storage tier for the account.
4615 4616 4617 4618 4619 4620 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4615 class GetStorageTierPolicyResponse < Struct.new( :storage_tier, :last_updated_time) SENSITIVE = [] include Aws::Structure end |