Class: Aws::CloudWatchLogs::Types::Grok
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::Grok
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This processor uses pattern matching to parse and structure unstructured data. This processor can also extract fields from log messages.
For more information about this processor including examples, see grok in the CloudWatch Logs User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#match ⇒ String
The grok pattern to match against the log event.
-
#source ⇒ String
The path to the field in the log event that you want to parse.
Instance Attribute Details
#match ⇒ String
The grok pattern to match against the log event. For a list of supported grok patterns, see Supported grok patterns.
4714 4715 4716 4717 4718 4719 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4714 class Grok < Struct.new( :source, :match) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The path to the field in the log event that you want to parse. If you omit this value, the whole log message is parsed.
4714 4715 4716 4717 4718 4719 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4714 class Grok < Struct.new( :source, :match) SENSITIVE = [] include Aws::Structure end |