Class: Aws::CloudWatchLogs::Types::IntegrationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::IntegrationDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
IntegrationDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IntegrationDetails corresponding to the set member.
This structure contains information about the integration configuration. For an integration with OpenSearch Service, this includes information about OpenSearch Service resources such as the collection, the workspace, and policies.
This structure is returned by a GetIntegration operation.
Defined Under Namespace
Classes: OpenSearchIntegrationDetails, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4925 class IntegrationDetails < Struct.new( :open_search_integration_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchIntegrationDetails < IntegrationDetails; end class Unknown < IntegrationDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4925 4926 4927 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4925 def unknown @unknown end |