Class: Aws::CloudWatchLogs::Types::IntegrationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::IntegrationDetails
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
IntegrationDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IntegrationDetails corresponding to the set member.
This structure contains information about the integration configuration. For an integration with OpenSearch Service, this includes information about OpenSearch Service resources such as the collection, the workspace, and policies.
This structure is returned by a [GetIntegration] operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetIntegration.html
Direct Known Subclasses
Defined Under Namespace
Classes: OpenSearchIntegrationDetails, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#open_search_integration_details ⇒ Types::OpenSearchIntegrationDetails
This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.
4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4901 class IntegrationDetails < Struct.new( :open_search_integration_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchIntegrationDetails < IntegrationDetails; end class Unknown < IntegrationDetails; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4901 4902 4903 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4901 def unknown @unknown end |