Class: Aws::CloudWatchLogs::Types::IntegrationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Note:

IntegrationDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of IntegrationDetails corresponding to the set member.

This structure contains information about the integration configuration. For an integration with OpenSearch Service, this includes information about OpenSearch Service resources such as the collection, the workspace, and policies.

This structure is returned by a [GetIntegration] operation.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_GetIntegration.html

Direct Known Subclasses

OpenSearchIntegrationDetails, Unknown

Defined Under Namespace

Classes: OpenSearchIntegrationDetails, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#open_search_integration_detailsTypes::OpenSearchIntegrationDetails

This structure contains complete information about one integration between CloudWatch Logs and OpenSearch Service.



4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4838

class IntegrationDetails < Struct.new(
  :open_search_integration_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpenSearchIntegrationDetails < IntegrationDetails; end
  class Unknown < IntegrationDetails; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4838
4839
4840
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4838

def unknown
  @unknown
end