Class: Aws::CloudWatchLogs::Types::InternalStreamingException
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::InternalStreamingException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
An internal error occurred during the streaming of log data. This exception is thrown when there’s an issue with the internal streaming mechanism used by the GetLogObject operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ Object
Returns the value of attribute event_type.
- #message ⇒ String
Instance Attribute Details
#event_type ⇒ Object
Returns the value of attribute event_type
4941 4942 4943 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4941 def event_type @event_type end |
#message ⇒ String
4941 4942 4943 4944 4945 4946 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4941 class InternalStreamingException < Struct.new( :message, :event_type) SENSITIVE = [] include Aws::Structure end |