Class: Aws::CloudWatchLogs::Types::InternalStreamingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

An internal error occurred during the streaming of log data. This exception is thrown when there’s an issue with the internal streaming mechanism used by the GetLogObject operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



4809
4810
4811
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4809

def event_type
  @event_type
end

#messageString

Returns:

  • (String)


4809
4810
4811
4812
4813
4814
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4809

class InternalStreamingException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end