Class: Aws::CloudWatchLogs::Types::ListAggregateLogGroupSummariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListAggregateLogGroupSummariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_identifiers ⇒ Array<String>
When ‘includeLinkedAccounts` is set to `true`, use this parameter to specify the list of accounts to search.
-
#data_sources ⇒ Array<Types::DataSourceFilter>
Filters the results by data source characteristics to include only log groups associated with the specified data sources.
-
#group_by ⇒ String
Specifies how to group the log groups in the summary.
-
#include_linked_accounts ⇒ Boolean
If you are using a monitoring account, set this to ‘true` to have the operation return log groups in the accounts listed in `accountIdentifiers`.
-
#limit ⇒ Integer
The maximum number of aggregated summaries to return.
-
#log_group_class ⇒ String
Filters the results by log group class to include only log groups of the specified class.
-
#log_group_name_pattern ⇒ String
Use this parameter to limit the returned log groups to only those with names that match the pattern that you specify.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#account_identifiers ⇒ Array<String>
When ‘includeLinkedAccounts` is set to `true`, use this parameter to specify the list of accounts to search. You can specify as many as 20 account IDs in the array.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Array<Types::DataSourceFilter>
Filters the results by data source characteristics to include only log groups associated with the specified data sources.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ String
Specifies how to group the log groups in the summary.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#include_linked_accounts ⇒ Boolean
If you are using a monitoring account, set this to ‘true` to have the operation return log groups in the accounts listed in `accountIdentifiers`.
If this parameter is set to ‘true` and `accountIdentifiers` contains a null value, the operation returns all log groups in the monitoring account and all log groups in all source accounts that are linked to the monitoring account.
The default for this parameter is ‘false`.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of aggregated summaries to return. If you omit this parameter, the default is up to 50 aggregated summaries.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_class ⇒ String
Filters the results by log group class to include only log groups of the specified class.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_name_pattern ⇒ String
Use this parameter to limit the returned log groups to only those with names that match the pattern that you specify. This parameter is a regular expression that can match prefixes and substrings, and supports wildcard matching and matching multiple patterns, as in the following examples.
-
Use ‘^` to match log group names by prefix.
-
For a substring match, specify the string to match. All matches are case sensitive
-
To match multiple patterns, separate them with a ‘|` as in the example `^/aws/lambda|discovery`
You can specify as many as five different regular expression patterns in this field, each of which must be between 3 and 24 characters. You can include the ‘^` symbol as many as five times, and include the `|` symbol as many as four times.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
4722 4723 4724 4725 4726 4727 4728 4729 4730 4731 4732 4733 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4722 class ListAggregateLogGroupSummariesRequest < Struct.new( :account_identifiers, :include_linked_accounts, :log_group_class, :log_group_name_pattern, :data_sources, :group_by, :next_token, :limit) SENSITIVE = [] include Aws::Structure end |