Class: Aws::CloudWatchLogs::Types::ListScheduledQueriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListScheduledQueriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of scheduled queries to return.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#schedule_type ⇒ String
Filter scheduled queries by schedule type.
-
#state ⇒ String
Filter scheduled queries by state.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of scheduled queries to return. Valid range is 1 to 1000.
5536 5537 5538 5539 5540 5541 5542 5543 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536 class ListScheduledQueriesRequest < Struct.new( :max_results, :next_token, :state, :schedule_type) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
5536 5537 5538 5539 5540 5541 5542 5543 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536 class ListScheduledQueriesRequest < Struct.new( :max_results, :next_token, :state, :schedule_type) SENSITIVE = [] include Aws::Structure end |
#schedule_type ⇒ String
Filter scheduled queries by schedule type. Valid values are
CUSTOMER_MANAGED and AWS_MANAGED. If not specified, scheduled
queries of all schedule types are returned.
5536 5537 5538 5539 5540 5541 5542 5543 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536 class ListScheduledQueriesRequest < Struct.new( :max_results, :next_token, :state, :schedule_type) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Filter scheduled queries by state. Valid values are ENABLED and
DISABLED. If not specified, all scheduled queries are returned.
5536 5537 5538 5539 5540 5541 5542 5543 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5536 class ListScheduledQueriesRequest < Struct.new( :max_results, :next_token, :state, :schedule_type) SENSITIVE = [] include Aws::Structure end |