Class: Aws::CloudWatchLogs::Types::ListSourcesForS3TableIntegrationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListSourcesForS3TableIntegrationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Table Integration to list associations for.
-
#max_results ⇒ Integer
The maximum number of associations to return in a single call.
-
#next_token ⇒ String
The token for the next set of items to return.
Instance Attribute Details
#integration_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 Table Integration to list associations for.
5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5099 class ListSourcesForS3TableIntegrationRequest < Struct.new( :integration_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of associations to return in a single call. Valid range is 1 to 100.
5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5099 class ListSourcesForS3TableIntegrationRequest < Struct.new( :integration_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. The token expires after 24 hours.
5099 5100 5101 5102 5103 5104 5105 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5099 class ListSourcesForS3TableIntegrationRequest < Struct.new( :integration_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |