Class: Aws::CloudWatchLogs::Types::ListSyslogConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ListSyslogConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_group_identifier ⇒ String
The name or ARN of the log group to filter syslog configurations for.
-
#max_results ⇒ Integer
The maximum number of syslog configurations to return in the response.
-
#next_token ⇒ String
The token for the next set of items to return.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint to filter syslog configurations for.
Instance Attribute Details
#log_group_identifier ⇒ String
The name or ARN of the log group to filter syslog configurations for.
5628 5629 5630 5631 5632 5633 5634 5635 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628 class ListSyslogConfigurationsRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of syslog configurations to return in the response.
5628 5629 5630 5631 5632 5633 5634 5635 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628 class ListSyslogConfigurationsRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of items to return. You received this token from a previous call.
5628 5629 5630 5631 5632 5633 5634 5635 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628 class ListSyslogConfigurationsRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint to filter syslog configurations for.
5628 5629 5630 5631 5632 5633 5634 5635 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5628 class ListSyslogConfigurationsRequest < Struct.new( :log_group_identifier, :vpc_endpoint_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |