Class: Aws::CloudWatchLogs::Types::LogGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Represents a log group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the log group.

Returns:

  • (String)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeInteger

The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.

Returns:

  • (Integer)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#data_protection_statusString

Displays whether this log group has a protection policy, or whether it had one in the past. For more information, see [PutDataProtectionPolicy].

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutDataProtectionPolicy.html

Returns:

  • (String)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Resource Name (ARN) of the KMS key to use when encrypting log data.

Returns:

  • (String)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the log group.

Returns:

  • (String)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#metric_filter_countInteger

The number of metric filters.

Returns:

  • (Integer)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#retention_in_daysInteger

The number of days to retain the log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 2192, 2557, 2922, 3288, and 3653.

To set a log group so that its log events do not expire, use [DeleteRetentionPolicy].

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteRetentionPolicy.html

Returns:

  • (Integer)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end

#stored_bytesInteger

The number of bytes stored.

Returns:

  • (Integer)


1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
1918
1919
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1908

class LogGroup < Struct.new(
  :log_group_name,
  :creation_time,
  :retention_in_days,
  :metric_filter_count,
  :arn,
  :stored_bytes,
  :kms_key_id,
  :data_protection_status)
  SENSITIVE = []
  include Aws::Structure
end