Class: Aws::CloudWatchLogs::Types::LogGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LogGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Represents a log group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the log group.
-
#creation_time ⇒ Integer
The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the CMK to use when encrypting log data.
-
#log_group_name ⇒ String
The name of the log group.
-
#metric_filter_count ⇒ Integer
The number of metric filters.
-
#retention_in_days ⇒ Integer
The number of days to retain the log events in the specified log group.
-
#stored_bytes ⇒ Integer
The number of bytes stored.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the log group.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Integer
The creation time of the log group, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) of the CMK to use when encrypting log data.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#metric_filter_count ⇒ Integer
The number of metric filters.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days to retain the log events in the specified log group. Possible values are: 1, 3, 5, 7, 14, 30, 60, 90, 120, 150, 180, 365, 400, 545, 731, 1827, 2192, 2557, 2922, 3288, and 3653.
To set a log group to never have log events expire, use [DeleteRetentionPolicy].
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DeleteRetentionPolicy.html
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#stored_bytes ⇒ Integer
The number of bytes stored.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 1693 class LogGroup < Struct.new( :log_group_name, :creation_time, :retention_in_days, :metric_filter_count, :arn, :stored_bytes, :kms_key_id) SENSITIVE = [] include Aws::Structure end |