Class: Aws::CloudWatchLogs::Types::LogStream
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LogStream
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Represents a log stream, which is a sequence of log events from a single emitter of logs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the log stream.
-
#creation_time ⇒ Integer
The creation time of the stream, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#first_event_timestamp ⇒ Integer
The time of the first event, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#last_event_timestamp ⇒ Integer
The time of the most recent log event in the log stream in CloudWatch Logs.
-
#last_ingestion_time ⇒ Integer
The ingestion time, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC` The `lastIngestionTime` value updates on an eventual consistency basis.
-
#log_stream_name ⇒ String
The name of the log stream.
-
#stored_bytes ⇒ Integer
The number of bytes stored.
-
#upload_sequence_token ⇒ String
The sequence token.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the log stream.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Integer
The creation time of the stream, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#first_event_timestamp ⇒ Integer
The time of the first event, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#last_event_timestamp ⇒ Integer
The time of the most recent log event in the log stream in CloudWatch Logs. This number is expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`. The `lastEventTime` value updates on an eventual consistency basis. It typically updates in less than an hour from ingestion, but in rare situations might take longer.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#last_ingestion_time ⇒ Integer
The ingestion time, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC` The `lastIngestionTime` value updates on an eventual consistency basis. It typically updates in less than an hour after ingestion, but in rare situations might take longer.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#log_stream_name ⇒ String
The name of the log stream.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#stored_bytes ⇒ Integer
The number of bytes stored.
Important: As of June 17, 2019, this parameter is no longer supported for log streams, and is always reported as zero. This change applies only to log streams. The ‘storedBytes` parameter for log groups is not affected.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |
#upload_sequence_token ⇒ String
The sequence token.
The sequence token is now ignored in ‘PutLogEvents` actions. `PutLogEvents` actions are always accepted regardless of receiving an invalid sequence token. You don’t need to obtain ‘uploadSequenceToken` to use a `PutLogEvents` action.
6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6030 class LogStream < Struct.new( :log_stream_name, :creation_time, :first_event_timestamp, :last_event_timestamp, :last_ingestion_time, :upload_sequence_token, :arn, :stored_bytes) SENSITIVE = [] include Aws::Structure end |