Class: Aws::CloudWatchLogs::Types::LookupTableConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Configuration for a lookup table destination. Use it to automatically refresh a lookup table with query results on a schedule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the lookup table.

Returns:

  • (String)


6258
6259
6260
6261
6262
6263
6264
6265
6266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258

class LookupTableConfiguration < Struct.new(
  :table_name,
  :role_arn,
  :description,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ARN of the KMS key to use to encrypt the lookup table data. If you don't specify a key, the data is encrypted with an Amazon Web Services-owned key.

Returns:

  • (String)


6258
6259
6260
6261
6262
6263
6264
6265
6266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258

class LookupTableConfiguration < Struct.new(
  :table_name,
  :role_arn,
  :description,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that grants permissions to create or update the lookup table with query results.

Returns:

  • (String)


6258
6259
6260
6261
6262
6263
6264
6265
6266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258

class LookupTableConfiguration < Struct.new(
  :table_name,
  :role_arn,
  :description,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#table_nameString

The name of the lookup table to create or update with query results. The name can contain only alphanumeric characters and underscores.

Returns:

  • (String)


6258
6259
6260
6261
6262
6263
6264
6265
6266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258

class LookupTableConfiguration < Struct.new(
  :table_name,
  :role_arn,
  :description,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Key-value pairs to associate with the lookup table for resource management and cost allocation. The service applies tags only during initial table creation.

Returns:

  • (Hash<String,String>)


6258
6259
6260
6261
6262
6263
6264
6265
6266
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258

class LookupTableConfiguration < Struct.new(
  :table_name,
  :role_arn,
  :description,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end