Class: Aws::CloudWatchLogs::Types::LookupTableConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::LookupTableConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Configuration for a lookup table destination. Use it to automatically refresh a lookup table with query results on a schedule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the lookup table.
-
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data.
-
#role_arn ⇒ String
The ARN of the IAM role that grants permissions to create or update the lookup table with query results.
-
#table_name ⇒ String
The name of the lookup table to create or update with query results.
-
#tags ⇒ Hash<String,String>
Key-value pairs to associate with the lookup table for resource management and cost allocation.
Instance Attribute Details
#description ⇒ String
A description of the lookup table.
6258 6259 6260 6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258 class LookupTableConfiguration < Struct.new( :table_name, :role_arn, :description, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data. If you don't specify a key, the data is encrypted with an Amazon Web Services-owned key.
6258 6259 6260 6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258 class LookupTableConfiguration < Struct.new( :table_name, :role_arn, :description, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of the IAM role that grants permissions to create or update the lookup table with query results.
6258 6259 6260 6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258 class LookupTableConfiguration < Struct.new( :table_name, :role_arn, :description, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the lookup table to create or update with query results. The name can contain only alphanumeric characters and underscores.
6258 6259 6260 6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258 class LookupTableConfiguration < Struct.new( :table_name, :role_arn, :description, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Key-value pairs to associate with the lookup table for resource management and cost allocation. The service applies tags only during initial table creation.
6258 6259 6260 6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6258 class LookupTableConfiguration < Struct.new( :table_name, :role_arn, :description, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |