Class: Aws::CloudWatchLogs::Types::MoveKeyEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::MoveKeyEntry
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This object defines one key that will be moved with the moveKey processor.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#overwrite_if_exists ⇒ Boolean
Specifies whether to overwrite the value if the destination key already exists.
-
#source ⇒ String
The key to move.
-
#target ⇒ String
The key to move to.
Instance Attribute Details
#overwrite_if_exists ⇒ Boolean
Specifies whether to overwrite the value if the destination key
already exists. If you omit this, the default is false.
6440 6441 6442 6443 6444 6445 6446 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6440 class MoveKeyEntry < Struct.new( :source, :target, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The key to move.
6440 6441 6442 6443 6444 6445 6446 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6440 class MoveKeyEntry < Struct.new( :source, :target, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#target ⇒ String
The key to move to.
6440 6441 6442 6443 6444 6445 6446 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6440 class MoveKeyEntry < Struct.new( :source, :target, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |