Class: Aws::CloudWatchLogs::Types::OpenSearchApplication

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains information about the OpenSearch Service application used for this integration. An OpenSearch Service application is the web application created by the integration with CloudWatch Logs. It hosts the vended logs dashboards.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arnString

The Amazon Resource Name (ARN) of the application.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353

class OpenSearchApplication < Struct.new(
  :application_endpoint,
  :application_arn,
  :application_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#application_endpointString

The endpoint of the application.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353

class OpenSearchApplication < Struct.new(
  :application_endpoint,
  :application_arn,
  :application_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#application_idString

The ID of the application.

Returns:

  • (String)


6353
6354
6355
6356
6357
6358
6359
6360
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353

class OpenSearchApplication < Struct.new(
  :application_endpoint,
  :application_arn,
  :application_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OpenSearchResourceStatus

This structure contains information about the status of this OpenSearch Service resource.



6353
6354
6355
6356
6357
6358
6359
6360
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353

class OpenSearchApplication < Struct.new(
  :application_endpoint,
  :application_arn,
  :application_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end