Class: Aws::CloudWatchLogs::Types::OpenSearchApplication
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::OpenSearchApplication
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about the OpenSearch Service application used for this integration. An OpenSearch Service application is the web application created by the integration with CloudWatch Logs. It hosts the vended logs dashboards.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
The Amazon Resource Name (ARN) of the application.
-
#application_endpoint ⇒ String
The endpoint of the application.
-
#application_id ⇒ String
The ID of the application.
-
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
Instance Attribute Details
#application_arn ⇒ String
The Amazon Resource Name (ARN) of the application.
6353 6354 6355 6356 6357 6358 6359 6360 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353 class OpenSearchApplication < Struct.new( :application_endpoint, :application_arn, :application_id, :status) SENSITIVE = [] include Aws::Structure end |
#application_endpoint ⇒ String
The endpoint of the application.
6353 6354 6355 6356 6357 6358 6359 6360 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353 class OpenSearchApplication < Struct.new( :application_endpoint, :application_arn, :application_id, :status) SENSITIVE = [] include Aws::Structure end |
#application_id ⇒ String
The ID of the application.
6353 6354 6355 6356 6357 6358 6359 6360 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353 class OpenSearchApplication < Struct.new( :application_endpoint, :application_arn, :application_id, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
6353 6354 6355 6356 6357 6358 6359 6360 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6353 class OpenSearchApplication < Struct.new( :application_endpoint, :application_arn, :application_id, :status) SENSITIVE = [] include Aws::Structure end |