Class: Aws::CloudWatchLogs::Types::OpenSearchDataAccessPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains information about the OpenSearch Service data access policy used for this integration. The access policy defines the access controls for the collection. This data access policy was automatically created as part of the integration setup. For more information about OpenSearch Service data access policies, see [Data access control for Amazon OpenSearch Serverless] in the OpenSearch Service Developer Guide.

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_nameString

The name of the data access policy.

Returns:

  • (String)


6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6324

class OpenSearchDataAccessPolicy < Struct.new(
  :policy_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OpenSearchResourceStatus

This structure contains information about the status of this OpenSearch Service resource.



6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6324

class OpenSearchDataAccessPolicy < Struct.new(
  :policy_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end