Class: Aws::CloudWatchLogs::Types::OpenSearchEncryptionPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::OpenSearchEncryptionPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about the OpenSearch Service encryption policy used for this integration. The encryption policy was created automatically when you created the integration. For more information, see Encryption policies in the OpenSearch Service Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_name ⇒ String
The name of the encryption policy.
-
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
Instance Attribute Details
#policy_name ⇒ String
The name of the encryption policy.
6620 6621 6622 6623 6624 6625 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6620 class OpenSearchEncryptionPolicy < Struct.new( :policy_name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
6620 6621 6622 6623 6624 6625 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6620 class OpenSearchEncryptionPolicy < Struct.new( :policy_name, :status) SENSITIVE = [] include Aws::Structure end |