Class: Aws::CloudWatchLogs::Types::OpenSearchLifecyclePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains information about the OpenSearch Service data lifecycle policy used for this integration. The lifecycle policy determines the lifespan of the data in the collection. It was automatically created as part of the integration setup.

For more information, see [Using data lifecycle policies with OpenSearch Service Serverless] in the OpenSearch Service Developer Guide.

[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_nameString

The name of the lifecycle policy.

Returns:

  • (String)


6753
6754
6755
6756
6757
6758
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6753

class OpenSearchLifecyclePolicy < Struct.new(
  :policy_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OpenSearchResourceStatus

This structure contains information about the status of this OpenSearch Service resource.



6753
6754
6755
6756
6757
6758
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6753

class OpenSearchLifecyclePolicy < Struct.new(
  :policy_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end