Class: Aws::CloudWatchLogs::Types::OpenSearchLifecyclePolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::OpenSearchLifecyclePolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about the OpenSearch Service data lifecycle policy used for this integration. The lifecycle policy determines the lifespan of the data in the collection. It was automatically created as part of the integration setup.
For more information, see [Using data lifecycle policies with OpenSearch Service Serverless] in the OpenSearch Service Developer Guide.
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-lifecycle.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_name ⇒ String
The name of the lifecycle policy.
-
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
Instance Attribute Details
#policy_name ⇒ String
The name of the lifecycle policy.
6547 6548 6549 6550 6551 6552 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6547 class OpenSearchLifecyclePolicy < Struct.new( :policy_name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
6547 6548 6549 6550 6551 6552 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6547 class OpenSearchLifecyclePolicy < Struct.new( :policy_name, :status) SENSITIVE = [] include Aws::Structure end |