Class: Aws::CloudWatchLogs::Types::OpenSearchNetworkPolicy
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::OpenSearchNetworkPolicy
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about the OpenSearch Service network policy used for this integration. The network policy assigns network access settings to collections. For more information, see Network policies in the OpenSearch Service Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy_name ⇒ String
The name of the network policy.
-
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
Instance Attribute Details
#policy_name ⇒ String
The name of the network policy.
6941 6942 6943 6944 6945 6946 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6941 class OpenSearchNetworkPolicy < Struct.new( :policy_name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of this OpenSearch Service resource.
6941 6942 6943 6944 6945 6946 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6941 class OpenSearchNetworkPolicy < Struct.new( :policy_name, :status) SENSITIVE = [] include Aws::Structure end |