Class: Aws::CloudWatchLogs::Types::OpenSearchNetworkPolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This structure contains information about the OpenSearch Service network policy used for this integration. The network policy assigns network access settings to collections. For more information, see Network policies in the OpenSearch Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy_nameString

The name of the network policy.

Returns:

  • (String)


6804
6805
6806
6807
6808
6809
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6804

class OpenSearchNetworkPolicy < Struct.new(
  :policy_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusTypes::OpenSearchResourceStatus

This structure contains information about the status of this OpenSearch Service resource.



6804
6805
6806
6807
6808
6809
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6804

class OpenSearchNetworkPolicy < Struct.new(
  :policy_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end