Class: Aws::CloudWatchLogs::Types::OpenSearchWorkspace
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::OpenSearchWorkspace
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains information about the OpenSearch Service workspace used for this integration. An OpenSearch Service workspace is the collection of dashboards along with other OpenSearch Service tools. This workspace was created automatically as part of the integration setup. For more information, see [Centralized OpenSearch user interface (Dashboards) with OpenSearch Service].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/application.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of an OpenSearch Service resource.
-
#workspace_id ⇒ String
The ID of this workspace.
Instance Attribute Details
#status ⇒ Types::OpenSearchResourceStatus
This structure contains information about the status of an OpenSearch Service resource.
5042 5043 5044 5045 5046 5047 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5042 class OpenSearchWorkspace < Struct.new( :workspace_id, :status) SENSITIVE = [] include Aws::Structure end |
#workspace_id ⇒ String
The ID of this workspace.
5042 5043 5044 5045 5046 5047 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5042 class OpenSearchWorkspace < Struct.new( :workspace_id, :status) SENSITIVE = [] include Aws::Structure end |