Class: Aws::CloudWatchLogs::Types::ParseKeyValue
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ParseKeyValue
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This processor parses a specified field in the original log event into key-value pairs.
For more information about this processor including examples, see [ parseKeyValue] in the *CloudWatch Logs User Guide*.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ String
The destination field to put the extracted key-value pairs into.
-
#field_delimiter ⇒ String
The field delimiter string that is used between key-value pairs in the original log events.
-
#key_prefix ⇒ String
If you want to add a prefix to all transformed keys, specify it here.
-
#key_value_delimiter ⇒ String
The delimiter string to use between the key and value in each pair in the transformed log event.
-
#non_match_value ⇒ String
A value to insert into the value field in the result, when a key-value pair is not successfully split.
-
#overwrite_if_exists ⇒ Boolean
Specifies whether to overwrite the value if the destination key already exists.
-
#source ⇒ String
Path to the field in the log event that will be parsed.
Instance Attribute Details
#destination ⇒ String
The destination field to put the extracted key-value pairs into
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#field_delimiter ⇒ String
The field delimiter string that is used between key-value pairs in the original log events. If you omit this, the ampersand ‘&` character is used.
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#key_prefix ⇒ String
If you want to add a prefix to all transformed keys, specify it here.
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#key_value_delimiter ⇒ String
The delimiter string to use between the key and value in each pair in the transformed log event.
If you omit this, the equal ‘=` character is used.
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#non_match_value ⇒ String
A value to insert into the value field in the result, when a key-value pair is not successfully split.
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#overwrite_if_exists ⇒ Boolean
Specifies whether to overwrite the value if the destination key already exists. If you omit this, the default is false.
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
Path to the field in the log event that will be parsed. Use dot notation to access child fields. For example, store.book
6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 6584 class ParseKeyValue < Struct.new( :source, :destination, :field_delimiter, :key_value_delimiter, :key_prefix, :non_match_value, :overwrite_if_exists) SENSITIVE = [] include Aws::Structure end |