Class: Aws::CloudWatchLogs::Types::Processor
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::Processor
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains the information about one processor in a log transformer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#add_keys ⇒ Types::AddKeys
Use this parameter to include the [ addKeys][1] processor in your transformer.
-
#copy_value ⇒ Types::CopyValue
Use this parameter to include the [ copyValue][1] processor in your transformer.
-
#csv ⇒ Types::CSV
Use this parameter to include the [ CSV][1] processor in your transformer.
-
#date_time_converter ⇒ Types::DateTimeConverter
Use this parameter to include the [ datetimeConverter][1] processor in your transformer.
-
#delete_keys ⇒ Types::DeleteKeys
Use this parameter to include the [ deleteKeys][1] processor in your transformer.
-
#grok ⇒ Types::Grok
Use this parameter to include the [ grok][1] processor in your transformer.
-
#list_to_map ⇒ Types::ListToMap
Use this parameter to include the [ listToMap][1] processor in your transformer.
-
#lower_case_string ⇒ Types::LowerCaseString
Use this parameter to include the [ lowerCaseString][1] processor in your transformer.
-
#move_keys ⇒ Types::MoveKeys
Use this parameter to include the [ moveKeys][1] processor in your transformer.
-
#parse_cloudfront ⇒ Types::ParseCloudfront
Use this parameter to include the [ parseCloudfront][1] processor in your transformer.
-
#parse_json ⇒ Types::ParseJSON
Use this parameter to include the [ parseJSON][1] processor in your transformer.
-
#parse_key_value ⇒ Types::ParseKeyValue
Use this parameter to include the [ parseKeyValue][1] processor in your transformer.
-
#parse_postgres ⇒ Types::ParsePostgres
Use this parameter to include the [ parsePostGres][1] processor in your transformer.
-
#parse_route_53 ⇒ Types::ParseRoute53
Use this parameter to include the [ parseRoute53][1] processor in your transformer.
-
#parse_to_ocsf ⇒ Types::ParseToOCSF
Use this parameter to convert logs into Open Cybersecurity Schema (OCSF) format.
-
#parse_vpc ⇒ Types::ParseVPC
Use this parameter to include the [ parseVPC][1] processor in your transformer.
-
#parse_waf ⇒ Types::ParseWAF
Use this parameter to include the [ parseWAF][1] processor in your transformer.
-
#rename_keys ⇒ Types::RenameKeys
Use this parameter to include the [ renameKeys][1] processor in your transformer.
-
#split_string ⇒ Types::SplitString
Use this parameter to include the [ splitString][1] processor in your transformer.
-
#substitute_string ⇒ Types::SubstituteString
Use this parameter to include the [ substituteString][1] processor in your transformer.
-
#trim_string ⇒ Types::TrimString
Use this parameter to include the [ trimString][1] processor in your transformer.
-
#type_converter ⇒ Types::TypeConverter
Use this parameter to include the [ typeConverter][1] processor in your transformer.
-
#upper_case_string ⇒ Types::UpperCaseString
Use this parameter to include the [ upperCaseString][1] processor in your transformer.
Instance Attribute Details
#add_keys ⇒ Types::AddKeys
Use this parameter to include the addKeys processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#copy_value ⇒ Types::CopyValue
Use this parameter to include the copyValue processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#csv ⇒ Types::CSV
Use this parameter to include the CSV processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#date_time_converter ⇒ Types::DateTimeConverter
Use this parameter to include the datetimeConverter processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#delete_keys ⇒ Types::DeleteKeys
Use this parameter to include the deleteKeys processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#grok ⇒ Types::Grok
Use this parameter to include the grok processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#list_to_map ⇒ Types::ListToMap
Use this parameter to include the listToMap processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#lower_case_string ⇒ Types::LowerCaseString
Use this parameter to include the lowerCaseString processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#move_keys ⇒ Types::MoveKeys
Use this parameter to include the moveKeys processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_cloudfront ⇒ Types::ParseCloudfront
Use this parameter to include the parseCloudfront processor in your transformer.
If you use this processor, it must be the first processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_json ⇒ Types::ParseJSON
Use this parameter to include the parseJSON processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_key_value ⇒ Types::ParseKeyValue
Use this parameter to include the parseKeyValue processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_postgres ⇒ Types::ParsePostgres
Use this parameter to include the parsePostGres processor in your transformer.
If you use this processor, it must be the first processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_route_53 ⇒ Types::ParseRoute53
Use this parameter to include the parseRoute53 processor in your transformer.
If you use this processor, it must be the first processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_to_ocsf ⇒ Types::ParseToOCSF
Use this parameter to convert logs into Open Cybersecurity Schema (OCSF) format.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_vpc ⇒ Types::ParseVPC
Use this parameter to include the parseVPC processor in your transformer.
If you use this processor, it must be the first processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#parse_waf ⇒ Types::ParseWAF
Use this parameter to include the parseWAF processor in your transformer.
If you use this processor, it must be the first processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#rename_keys ⇒ Types::RenameKeys
Use this parameter to include the renameKeys processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#split_string ⇒ Types::SplitString
Use this parameter to include the splitString processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#substitute_string ⇒ Types::SubstituteString
Use this parameter to include the substituteString processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#trim_string ⇒ Types::TrimString
Use this parameter to include the trimString processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#type_converter ⇒ Types::TypeConverter
Use this parameter to include the typeConverter processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |
#upper_case_string ⇒ Types::UpperCaseString
Use this parameter to include the upperCaseString processor in your transformer.
7595 7596 7597 7598 7599 7600 7601 7602 7603 7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 7616 7617 7618 7619 7620 7621 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7595 class Processor < Struct.new( :add_keys, :copy_value, :csv, :date_time_converter, :delete_keys, :grok, :list_to_map, :lower_case_string, :move_keys, :parse_cloudfront, :parse_json, :parse_key_value, :parse_route_53, :parse_to_ocsf, :parse_postgres, :parse_vpc, :parse_waf, :rename_keys, :split_string, :substitute_string, :trim_string, :type_converter, :upper_case_string) SENSITIVE = [] include Aws::Structure end |