Class: Aws::CloudWatchLogs::Types::PutDeliverySourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDeliverySourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#log_type ⇒ String
Defines the type of log that the source is sending.
-
#name ⇒ String
A name for this delivery source.
-
#resource_arn ⇒ String
The ARN of the Amazon Web Services resource that is generating and sending logs.
-
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
Instance Attribute Details
#log_type ⇒ String
Defines the type of log that the source is sending. For valid values for this parameter, see the documentation for the source service.
3771 3772 3773 3774 3775 3776 3777 3778 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3771 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for this delivery source. This name must be unique for all delivery sources in your account.
3771 3772 3773 3774 3775 3776 3777 3778 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3771 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the Amazon Web Services resource that is generating and sending logs. For example, ‘arn:aws:workmail:us-east-1:123456789012:organization/m-1234EXAMPLEabcd1234abcd1234abcd1234`
3771 3772 3773 3774 3775 3776 3777 3778 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3771 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
For more information about tagging, see [Tagging Amazon Web Services resources]
3771 3772 3773 3774 3775 3776 3777 3778 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3771 class PutDeliverySourceRequest < Struct.new( :name, :resource_arn, :log_type, :tags) SENSITIVE = [] include Aws::Structure end |