Class: Aws::CloudWatchLogs::Types::PutDestinationPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDestinationPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_policy ⇒ String
An IAM policy document that authorizes cross-account users to deliver their log events to the associated destination.
-
#destination_name ⇒ String
A name for an existing destination.
-
#force_update ⇒ Boolean
Specify true if you are updating an existing destination policy to grant permission to an organization ID instead of granting permission to individual Amazon Web Services accounts.
Instance Attribute Details
#access_policy ⇒ String
An IAM policy document that authorizes cross-account users to deliver their log events to the associated destination. This can be up to 5120 bytes.
7997 7998 7999 8000 8001 8002 8003 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7997 class PutDestinationPolicyRequest < Struct.new( :destination_name, :access_policy, :force_update) SENSITIVE = [] include Aws::Structure end |
#destination_name ⇒ String
A name for an existing destination.
7997 7998 7999 8000 8001 8002 8003 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7997 class PutDestinationPolicyRequest < Struct.new( :destination_name, :access_policy, :force_update) SENSITIVE = [] include Aws::Structure end |
#force_update ⇒ Boolean
Specify true if you are updating an existing destination policy to grant permission to an organization ID instead of granting permission to individual Amazon Web Services accounts. Before you update a destination policy this way, you must first update the subscription filters in the accounts that send logs to this destination. If you do not, the subscription filters might stop working. By specifying ‘true` for `forceUpdate`, you are affirming that you have already updated the subscription filters. For more information, see [ Updating an existing cross-account subscription]
If you omit this parameter, the default of ‘false` is used.
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/Cross-Account-Log_Subscription-Update.html
7997 7998 7999 8000 8001 8002 8003 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7997 class PutDestinationPolicyRequest < Struct.new( :destination_name, :access_policy, :force_update) SENSITIVE = [] include Aws::Structure end |