Class: Aws::CloudWatchLogs::Types::PutDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
When making an API call, you may pass PutDestinationRequest data as a hash:
{
destination_name: "DestinationName", # required
target_arn: "TargetArn", # required
role_arn: "RoleArn", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_name ⇒ String
A name for the destination.
-
#role_arn ⇒ String
The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis `PutRecord` operation on the destination stream.
-
#target_arn ⇒ String
The ARN of an Amazon Kinesis stream to which to deliver matching log events.
Instance Attribute Details
#destination_name ⇒ String
A name for the destination.
2019 2020 2021 2022 2023 2024 2025 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2019 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis `PutRecord` operation on the destination stream.
2019 2020 2021 2022 2023 2024 2025 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2019 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The ARN of an Amazon Kinesis stream to which to deliver matching log events.
2019 2020 2021 2022 2023 2024 2025 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2019 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn) SENSITIVE = [] include Aws::Structure end |