Class: Aws::CloudWatchLogs::Types::PutDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_name ⇒ String
A name for the destination.
-
#role_arn ⇒ String
The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis
PutRecordoperation on the destination stream. -
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
-
#target_arn ⇒ String
The ARN of an Amazon Kinesis stream to which to deliver matching log events.
Instance Attribute Details
#destination_name ⇒ String
A name for the destination.
7658 7659 7660 7661 7662 7663 7664 7665 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7658 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The ARN of an IAM role that grants CloudWatch Logs permissions to call the Amazon Kinesis PutRecord operation on the destination stream.
7658 7659 7660 7661 7662 7663 7664 7665 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7658 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An optional list of key-value pairs to associate with the resource.
For more information about tagging, see [Tagging Amazon Web Services resources]
7658 7659 7660 7661 7662 7663 7664 7665 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7658 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The ARN of an Amazon Kinesis stream to which to deliver matching log events.
7658 7659 7660 7661 7662 7663 7664 7665 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7658 class PutDestinationRequest < Struct.new( :destination_name, :target_arn, :role_arn, :tags) SENSITIVE = [] include Aws::Structure end |