Class: Aws::CloudWatchLogs::Types::PutIndexPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_identifierString

Specify either the log group name or log group ARN to apply this field index policy to. If you specify an ARN, use the format arn:aws:logs:region:account-id:log-group:log_group_name Don't include an * at the end.

Returns:

  • (String)


8238
8239
8240
8241
8242
8243
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8238

class PutIndexPolicyRequest < Struct.new(
  :log_group_identifier,
  :policy_document)
  SENSITIVE = []
  include Aws::Structure
end

#policy_documentString

The index policy document, in JSON format. The following is an example of an index policy document that creates indexes with different types.

"policyDocument": "{"Fields": [ "TransactionId" ], "FieldsV2": {"RequestId": {"type": "FIELD_INDEX"}, "APIName": {"type": "FACET"}, "StatusCode": {"type": "FACET"}}}"

You can use FieldsV2 to specify the type for each field. Supported types are FIELD_INDEX and FACET. Field names within Fields and FieldsV2 must be mutually exclusive.

The policy document must include at least one field index. For more information about the fields that can be included and other restrictions, see Field index syntax and quotas.

Returns:

  • (String)


8238
8239
8240
8241
8242
8243
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8238

class PutIndexPolicyRequest < Struct.new(
  :log_group_identifier,
  :policy_document)
  SENSITIVE = []
  include Aws::Structure
end