Class: Aws::CloudWatchLogs::Types::PutLogEventsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutLogEventsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_sequence_token ⇒ String
The next sequence token.
-
#rejected_entity_info ⇒ Types::RejectedEntityInfo
Information about why the entity is rejected when calling
PutLogEvents. -
#rejected_log_events_info ⇒ Types::RejectedLogEventsInfo
The rejected events.
Instance Attribute Details
#next_sequence_token ⇒ String
The next sequence token.
This field has been deprecated.
The sequence token is now ignored in PutLogEvents actions.
PutLogEvents actions are always accepted even if the sequence
token is not valid. You can use parallel PutLogEvents actions on
the same log stream and you do not need to wait for the response of
a previous PutLogEvents action to obtain the nextSequenceToken
value.
8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8427 class PutLogEventsResponse < Struct.new( :next_sequence_token, :rejected_log_events_info, :rejected_entity_info) SENSITIVE = [] include Aws::Structure end |
#rejected_entity_info ⇒ Types::RejectedEntityInfo
Information about why the entity is rejected when calling
PutLogEvents. Only returned when the entity is rejected.
8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8427 class PutLogEventsResponse < Struct.new( :next_sequence_token, :rejected_log_events_info, :rejected_entity_info) SENSITIVE = [] include Aws::Structure end |
#rejected_log_events_info ⇒ Types::RejectedLogEventsInfo
The rejected events.
8427 8428 8429 8430 8431 8432 8433 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8427 class PutLogEventsResponse < Struct.new( :next_sequence_token, :rejected_log_events_info, :rejected_entity_info) SENSITIVE = [] include Aws::Structure end |