Class: Aws::CloudWatchLogs::Types::PutMetricFilterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutMetricFilterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_on_transformed_logs ⇒ Boolean
This parameter is valid only for log groups that have an active log transformer.
-
#emit_system_field_dimensions ⇒ Array<String>
A list of system fields to emit as additional dimensions in the generated metrics.
-
#field_selection_criteria ⇒ String
A filter expression that specifies which log events should be processed by this metric filter based on system fields such as source account and source region.
-
#filter_name ⇒ String
A name for the metric filter.
-
#filter_pattern ⇒ String
A filter pattern for extracting metric data out of ingested log events.
-
#log_group_name ⇒ String
The name of the log group.
-
#metric_transformations ⇒ Array<Types::MetricTransformation>
A collection of information that defines how metric data gets emitted.
Instance Attribute Details
#apply_on_transformed_logs ⇒ Boolean
This parameter is valid only for log groups that have an active log transformer. For more information about log transformers, see PutTransformer.
If the log group uses either a log-group level or account-level
transformer, and you specify true, the metric filter will be
applied on the transformed version of the log events instead of the
original ingested log events.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#emit_system_field_dimensions ⇒ Array<String>
A list of system fields to emit as additional dimensions in the
generated metrics. Valid values are @aws.account and
@aws.region. These dimensions help identify the source of
centralized log data and count toward the total dimension limit for
metric filters.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#field_selection_criteria ⇒ String
A filter expression that specifies which log events should be
processed by this metric filter based on system fields such as
source account and source region. Uses selection criteria syntax
with operators like =, !=, AND, OR, IN, NOT IN. Example:
@aws.region = "us-east-1" or @aws.account IN ["123456789012", "987654321098"]. Maximum length: 2000 characters.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#filter_name ⇒ String
A name for the metric filter.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#filter_pattern ⇒ String
A filter pattern for extracting metric data out of ingested log events.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |
#metric_transformations ⇒ Array<Types::MetricTransformation>
A collection of information that defines how metric data gets emitted.
8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8174 class PutMetricFilterRequest < Struct.new( :log_group_name, :filter_name, :filter_pattern, :metric_transformations, :apply_on_transformed_logs, :field_selection_criteria, :emit_system_field_dimensions) SENSITIVE = [] include Aws::Structure end |