Class: Aws::CloudWatchLogs::Types::PutStorageTierPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#storage_tierString

The storage tier to set for the account. Use INTELLIGENT_TIERING to automatically optimize storage costs by moving log data to the appropriate tier based on access frequency.

Returns:

  • (String)


8741
8742
8743
8744
8745
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8741

class PutStorageTierPolicyRequest < Struct.new(
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end