Class: Aws::CloudWatchLogs::Types::PutStorageTierPolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_updated_timeInteger

The time when the storage tier policy was last updated, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.

Returns:

  • (Integer)


8697
8698
8699
8700
8701
8702
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8697

class PutStorageTierPolicyResponse < Struct.new(
  :storage_tier,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#storage_tierString

The storage tier that was set.

Returns:

  • (String)


8697
8698
8699
8700
8701
8702
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8697

class PutStorageTierPolicyResponse < Struct.new(
  :storage_tier,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end