Class: Aws::CloudWatchLogs::Types::PutStorageTierPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::PutStorageTierPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_updated_time ⇒ Integer
The time when the storage tier policy was last updated, expressed as the number of milliseconds after
Jan 1, 1970 00:00:00 UTC. -
#storage_tier ⇒ String
The storage tier that was set.
Instance Attribute Details
#last_updated_time ⇒ Integer
The time when the storage tier policy was last updated, expressed as
the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
8697 8698 8699 8700 8701 8702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8697 class PutStorageTierPolicyResponse < Struct.new( :storage_tier, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#storage_tier ⇒ String
The storage tier that was set.
8697 8698 8699 8700 8701 8702 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8697 class PutStorageTierPolicyResponse < Struct.new( :storage_tier, :last_updated_time) SENSITIVE = [] include Aws::Structure end |