Class: Aws::CloudWatchLogs::Types::QueryInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::QueryInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Information about one CloudWatch Logs Insights query that matches the request in a ‘DescribeQueries` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes_scanned ⇒ Float
The total number of bytes scanned by the query.
-
#create_time ⇒ Integer
The date and time that this query was created.
-
#log_group_name ⇒ String
The name of the log group scanned by this query.
-
#query_duration ⇒ Integer
The duration in milliseconds that the query took to execute.
-
#query_id ⇒ String
The unique ID number of this query.
-
#query_language ⇒ String
The query language used for this query.
-
#query_string ⇒ String
The query string used in this query.
-
#status ⇒ String
The status of this query.
-
#user_identity ⇒ String
The ARN of the user who ran the query.
Instance Attribute Details
#bytes_scanned ⇒ Float
The total number of bytes scanned by the query. This indicates the cost associated with the query.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Integer
The date and time that this query was created.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group scanned by this query.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#query_duration ⇒ Integer
The duration in milliseconds that the query took to execute.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The unique ID number of this query.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The query language used for this query. For more information about the query languages that CloudWatch Logs supports, see [Supported query languages].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData_Languages.html
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string used in this query.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of this query. Possible values are ‘Cancelled`, `Complete`, `Failed`, `Running`, `Scheduled`, and `Unknown`.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |
#user_identity ⇒ String
The ARN of the user who ran the query.
8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 8684 class QueryInfo < Struct.new( :query_language, :query_id, :query_string, :status, :create_time, :log_group_name, :query_duration, :bytes_scanned, :user_identity) SENSITIVE = [] include Aws::Structure end |