Class: Aws::CloudWatchLogs::Types::QueryInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::QueryInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Information about one CloudWatch Logs Insights query that matches the request in a ‘DescribeQueries` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_time ⇒ Integer
The date and time that this query was created.
-
#log_group_name ⇒ String
The name of the log group scanned by this query.
-
#query_id ⇒ String
The unique ID number of this query.
-
#query_string ⇒ String
The query string used in this query.
-
#status ⇒ String
The status of this query.
Instance Attribute Details
#create_time ⇒ Integer
The date and time that this query was created.
3492 3493 3494 3495 3496 3497 3498 3499 3500 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3492 class QueryInfo < Struct.new( :query_id, :query_string, :status, :create_time, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The name of the log group scanned by this query.
3492 3493 3494 3495 3496 3497 3498 3499 3500 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3492 class QueryInfo < Struct.new( :query_id, :query_string, :status, :create_time, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The unique ID number of this query.
3492 3493 3494 3495 3496 3497 3498 3499 3500 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3492 class QueryInfo < Struct.new( :query_id, :query_string, :status, :create_time, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string used in this query.
3492 3493 3494 3495 3496 3497 3498 3499 3500 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3492 class QueryInfo < Struct.new( :query_id, :query_string, :status, :create_time, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of this query. Possible values are ‘Cancelled`, `Complete`, `Failed`, `Running`, `Scheduled`, and `Unknown`.
3492 3493 3494 3495 3496 3497 3498 3499 3500 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3492 class QueryInfo < Struct.new( :query_id, :query_string, :status, :create_time, :log_group_name) SENSITIVE = [] include Aws::Structure end |