Class: Aws::CloudWatchLogs::Types::QueryStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Contains the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the log events that were scanned.

If the query involved log groups that have field index policies, the estimated number of skipped log events and the total bytes of those skipped log events are included. Using field indexes to skip log events in queries reduces scan volume and improves performance. For more information, see Create field indexes to improve query performance and reduce scan volume.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bytes_scannedFloat

The total number of bytes in the log events scanned during the query.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_bytes_skippedFloat

An estimate of the number of bytes in the log events that were skipped when processing this query, because the query contained an indexed field. Skipping these entries lowers query costs and improves the query performance time. For more information about field indexes, see PutIndexPolicy.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_records_skippedFloat

An estimate of the number of log events that were skipped when processing this query, because the query contained an indexed field. Skipping these entries lowers query costs and improves the query performance time. For more information about field indexes, see PutIndexPolicy.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end

#log_groups_scannedFloat

The number of log groups that were scanned by this query.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end

#records_matchedFloat

The number of log events that matched the query string.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end

#records_scannedFloat

The total number of log events scanned during the query.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end

#result_countFloat

The number of rows in the final query result set. This value represents the total number of output rows across all pages. For queries that include post-aggregation filters (such as stats count(*) by field | filter count > threshold), this value might be less than recordsMatched. It reflects only the rows that survived all operations in the query.

Returns:

  • (Float)


9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9251

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :estimated_records_skipped,
  :bytes_scanned,
  :estimated_bytes_skipped,
  :log_groups_scanned,
  :result_count)
  SENSITIVE = []
  include Aws::Structure
end