Class: Aws::CloudWatchLogs::Types::QueryStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::QueryStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Contains the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the log events that were scanned.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bytes_scanned ⇒ Float
The total number of bytes in the log events scanned during the query.
-
#records_matched ⇒ Float
The number of log events that matched the query string.
-
#records_scanned ⇒ Float
The total number of log events scanned during the query.
Instance Attribute Details
#bytes_scanned ⇒ Float
The total number of bytes in the log events scanned during the query.
4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4426 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :bytes_scanned) SENSITIVE = [] include Aws::Structure end |
#records_matched ⇒ Float
The number of log events that matched the query string.
4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4426 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :bytes_scanned) SENSITIVE = [] include Aws::Structure end |
#records_scanned ⇒ Float
The total number of log events scanned during the query.
4426 4427 4428 4429 4430 4431 4432 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4426 class QueryStatistics < Struct.new( :records_matched, :records_scanned, :bytes_scanned) SENSITIVE = [] include Aws::Structure end |