Class: Aws::CloudWatchLogs::Types::QueryStatistics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Contains the number of log events scanned by the query, the number of log events that matched the query criteria, and the total number of bytes in the log events that were scanned.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bytes_scannedFloat

The total number of bytes in the log events scanned during the query.

Returns:

  • (Float)


2613
2614
2615
2616
2617
2618
2619
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2613

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :bytes_scanned)
  SENSITIVE = []
  include Aws::Structure
end

#records_matchedFloat

The number of log events that matched the query string.

Returns:

  • (Float)


2613
2614
2615
2616
2617
2618
2619
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2613

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :bytes_scanned)
  SENSITIVE = []
  include Aws::Structure
end

#records_scannedFloat

The total number of log events scanned during the query.

Returns:

  • (Float)


2613
2614
2615
2616
2617
2618
2619
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2613

class QueryStatistics < Struct.new(
  :records_matched,
  :records_scanned,
  :bytes_scanned)
  SENSITIVE = []
  include Aws::Structure
end