Class: Aws::CloudWatchLogs::Types::ResourceConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::ResourceConfig
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Note:
ResourceConfig is a union - when making an API calls you must set exactly one of the members.
This structure contains configuration details about an integration between CloudWatch Logs and another entity.
Defined Under Namespace
Classes: OpenSearchResourceConfig, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#open_search_resource_config ⇒ Types::OpenSearchResourceConfig
This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#open_search_resource_config ⇒ Types::OpenSearchResourceConfig
This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
9408 9409 9410 9411 9412 9413 9414 9415 9416 9417 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9408 class ResourceConfig < Struct.new( :open_search_resource_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class OpenSearchResourceConfig < ResourceConfig; end class Unknown < ResourceConfig; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9408 9409 9410 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9408 def unknown @unknown end |