Class: Aws::CloudWatchLogs::Types::ResourceConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Note:

ResourceConfig is a union - when making an API calls you must set exactly one of the members.

This structure contains configuration details about an integration between CloudWatch Logs and another entity.

Defined Under Namespace

Classes: OpenSearchResourceConfig, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#open_search_resource_configTypes::OpenSearchResourceConfig

This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.



9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9256

class ResourceConfig < Struct.new(
  :open_search_resource_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpenSearchResourceConfig < ResourceConfig; end
  class Unknown < ResourceConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9256
9257
9258
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9256

def unknown
  @unknown
end