Class: Aws::CloudWatchLogs::Types::ResourceConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Note:

ResourceConfig is a union - when making an API calls you must set exactly one of the members.

This structure contains configuration details about an integration between CloudWatch Logs and another entity.

Direct Known Subclasses

OpenSearchResourceConfig, Unknown

Defined Under Namespace

Classes: OpenSearchResourceConfig, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#open_search_resource_configTypes::OpenSearchResourceConfig

This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.



7258
7259
7260
7261
7262
7263
7264
7265
7266
7267
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7258

class ResourceConfig < Struct.new(
  :open_search_resource_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class OpenSearchResourceConfig < ResourceConfig; end
  class Unknown < ResourceConfig; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



7258
7259
7260
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7258

def unknown
  @unknown
end