Class: Aws::CloudWatchLogs::Types::ResultField

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Contains one field from one log event returned by a CloudWatch Logs Insights query, along with the value of that field.

For more information about the fields that are generated by CloudWatch logs, see Supported Logs and Discovered Fields.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldString

The log event field.

Returns:

  • (String)


9337
9338
9339
9340
9341
9342
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9337

class ResultField < Struct.new(
  :field,
  :value)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of this field.

Returns:

  • (String)


9337
9338
9339
9340
9341
9342
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9337

class ResultField < Struct.new(
  :field,
  :value)
  SENSITIVE = []
  include Aws::Structure
end