Class: Aws::CloudWatchLogs::Types::S3DeliveryConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::S3DeliveryConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
This structure contains delivery configurations that apply only when the delivery destination resource is an S3 bucket.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enable_hive_compatible_path ⇒ Boolean
This parameter causes the S3 objects that contain delivered logs to use a prefix structure that allows for integration with Apache Hive.
-
#suffix_path ⇒ String
This string allows re-configuring the S3 object prefix to contain either static or variable sections.
Instance Attribute Details
#enable_hive_compatible_path ⇒ Boolean
This parameter causes the S3 objects that contain delivered logs to use a prefix structure that allows for integration with Apache Hive.
7369 7370 7371 7372 7373 7374 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7369 class S3DeliveryConfiguration < Struct.new( :suffix_path, :enable_hive_compatible_path) SENSITIVE = [] include Aws::Structure end |
#suffix_path ⇒ String
This string allows re-configuring the S3 object prefix to contain either static or variable sections. The valid variables to use in the suffix path will vary by each log source. To find the values supported for the suffix path for each log source, use the
- DescribeConfigurationTemplates][1
-
operation and check the
‘allowedSuffixPathFields` field in the response.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_DescribeConfigurationTemplates.html
7369 7370 7371 7372 7373 7374 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 7369 class S3DeliveryConfiguration < Struct.new( :suffix_path, :enable_hive_compatible_path) SENSITIVE = [] include Aws::Structure end |