Class: Aws::CloudWatchLogs::Types::StartLiveTailResponseStream

Inherits:
Enumerator
  • Object
show all
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

This object includes the stream returned by your StartLiveTail request.

EventStream is an Enumerator of Events. #event_types #=> Array, returns all modeled event types in the stream

Instance Method Summary collapse

Instance Method Details

#event_typesObject



10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10888

def event_types
  [
    :session_start,
    :session_update,
    :session_timeout_exception,
    :session_streaming_exception
  ]
end