Class: Aws::CloudWatchLogs::Types::StartQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::StartQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
The end of the time range to query.
-
#limit ⇒ Integer
The maximum number of log events to return from the query.
-
#log_group_identifiers ⇒ Array<String>
The list of log groups to query.
-
#log_group_name ⇒ String
The log group on which to perform the query.
-
#log_group_names ⇒ Array<String>
The list of log groups to be queried.
-
#query_language ⇒ String
Specify the query language to use for this query.
-
#query_string ⇒ String
The query string to use.
-
#start_time ⇒ Integer
The beginning of the time range to query.
Instance Attribute Details
#end_time ⇒ Integer
The end of the time range to query. The range is inclusive, so the specified end time is included in the query. Specified as epoch time, the number of seconds since ‘January 1, 1970, 00:00:00 UTC`.
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of log events to return from the query. The maximum limit is 100,000. The maximum events returned in a single GetQueryResults API call is 10,000 log events per request. You can retrieve up to 100,000 log event results from a query by paginating with the ‘nextToken`. 100,000 limit is only supported for Logs Insights QL and is currently not supported for PPL and SQL query languages.
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
The list of log groups to query. You can include up to 50 log groups.
You can specify them by the log group name or ARN. If a log group that you’re querying is in a source account and you’re using a monitoring account, you must specify the ARN of the log group here. The query definition must also be defined in the monitoring account.
If you specify an ARN, use the format arn:aws:logs:region:account-id:log-group:log_group_name Don’t include an * at the end.
A ‘StartQuery` operation must include exactly one of the following parameters: `logGroupName`, `logGroupNames`, or `logGroupIdentifiers`. The exception is queries using the OpenSearch Service SQL query language, where you specify the log group names inside the `querystring` instead of here.
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The log group on which to perform the query.
<note markdown=“1”> A ‘StartQuery` operation must include exactly one of the following parameters: `logGroupName`, `logGroupNames`, or `logGroupIdentifiers`. The exception is queries using the OpenSearch Service SQL query language, where you specify the log group names inside the `querystring` instead of here.
</note>
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_names ⇒ Array<String>
The list of log groups to be queried. You can include up to 50 log groups.
<note markdown=“1”> A ‘StartQuery` operation must include exactly one of the following parameters: `logGroupName`, `logGroupNames`, or `logGroupIdentifiers`. The exception is queries using the OpenSearch Service SQL query language, where you specify the log group names inside the `querystring` instead of here.
</note>
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
Specify the query language to use for this query. The options are Logs Insights QL, OpenSearch PPL, and OpenSearch SQL. For more information about the query languages that CloudWatch Logs supports, see [Supported query languages].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_AnalyzeLogData_Languages.html
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string to use. For more information, see [CloudWatch Logs Insights Query Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Integer
The beginning of the time range to query. The range is inclusive, so the specified start time is included in the query. Specified as epoch time, the number of seconds since ‘January 1, 1970, 00:00:00 UTC`.
9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 9683 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9672 class StartQueryRequest < Struct.new( :query_language, :log_group_name, :log_group_names, :log_group_identifiers, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |