Class: Aws::CloudWatchLogs::Types::StartQueryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeInteger

The end of the time range to query. The range is inclusive, so the specified end time is included in the query. Specified as epoch time, the number of seconds since ‘January 1, 1970, 00:00:00 UTC`.

Returns:

  • (Integer)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of log events to return in the query. If the query string uses the ‘fields` command, only the specified fields and their values are returned. The default is 1000.

Returns:

  • (Integer)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

The list of log groups to query. You can include up to 50 log groups.

You can specify them by the log group name or ARN. If a log group that you’re querying is in a source account and you’re using a monitoring account, you must specify the ARN of the log group here. The query definition must also be defined in the monitoring account.

If you specify an ARN, the ARN can’t end with an asterisk (*).

A ‘StartQuery` operation must include exactly one of the following parameters: `logGroupName`, `logGroupNames`, or `logGroupIdentifiers`.

Returns:

  • (Array<String>)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The log group on which to perform the query.

<note markdown=“1”> A ‘StartQuery` operation must include exactly one of the following parameters: `logGroupName`, `logGroupNames`, or `logGroupIdentifiers`.

</note>

Returns:

  • (String)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_namesArray<String>

The list of log groups to be queried. You can include up to 50 log groups.

<note markdown=“1”> A ‘StartQuery` operation must include exactly one of the following parameters: `logGroupName`, `logGroupNames`, or `logGroupIdentifiers`.

</note>

Returns:

  • (Array<String>)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The query string to use. For more information, see [CloudWatch Logs Insights Query Syntax].

[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html

Returns:

  • (String)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeInteger

The beginning of the time range to query. The range is inclusive, so the specified start time is included in the query. Specified as epoch time, the number of seconds since ‘January 1, 1970, 00:00:00 UTC`.

Returns:

  • (Integer)


3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 3009

class StartQueryRequest < Struct.new(
  :log_group_name,
  :log_group_names,
  :log_group_identifiers,
  :start_time,
  :end_time,
  :query_string,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end