Class: Aws::CloudWatchLogs::Types::StartQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::StartQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
When making an API call, you may pass StartQueryRequest data as a hash:
{
log_group_name: "LogGroupName",
log_group_names: ["LogGroupName"],
start_time: 1, # required
end_time: 1, # required
query_string: "QueryString", # required
limit: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
The end of the time range to query.
-
#limit ⇒ Integer
The maximum number of log events to return in the query.
-
#log_group_name ⇒ String
The log group on which to perform the query.
-
#log_group_names ⇒ Array<String>
The list of log groups to be queried.
-
#query_string ⇒ String
The query string to use.
-
#start_time ⇒ Integer
The beginning of the time range to query.
Instance Attribute Details
#end_time ⇒ Integer
The end of the time range to query. The range is inclusive, so the specified end time is included in the query. Specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.
2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2792 class StartQueryRequest < Struct.new( :log_group_name, :log_group_names, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of log events to return in the query. If the query string uses the `fields` command, only the specified fields and their values are returned. The default is 1000.
2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2792 class StartQueryRequest < Struct.new( :log_group_name, :log_group_names, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The log group on which to perform the query.
A `StartQuery` operation must include a `logGroupNames` or a `logGroupName` parameter, but not both.
2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2792 class StartQueryRequest < Struct.new( :log_group_name, :log_group_names, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#log_group_names ⇒ Array<String>
The list of log groups to be queried. You can include up to 20 log groups.
A `StartQuery` operation must include a `logGroupNames` or a `logGroupName` parameter, but not both.
2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2792 class StartQueryRequest < Struct.new( :log_group_name, :log_group_names, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string to use. For more information, see [CloudWatch Logs Insights Query Syntax].
[1]: docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CWL_QuerySyntax.html
2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2792 class StartQueryRequest < Struct.new( :log_group_name, :log_group_names, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Integer
The beginning of the time range to query. The range is inclusive, so the specified start time is included in the query. Specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC.
2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 2792 class StartQueryRequest < Struct.new( :log_group_name, :log_group_names, :start_time, :end_time, :query_string, :limit) SENSITIVE = [] include Aws::Structure end |