Class: Aws::CloudWatchLogs::Types::SyslogConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::SyslogConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Contains information about a syslog configuration associated with a log group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Integer
The time when the syslog configuration was created, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
-
#log_group_arn ⇒ String
The ARN of the log group associated with this syslog configuration.
-
#source_type ⇒ String
The source type for the syslog configuration.
-
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint used for syslog ingestion.
Instance Attribute Details
#created_at ⇒ Integer
The time when the syslog configuration was created, expressed as the number of milliseconds after ‘Jan 1, 1970 00:00:00 UTC`.
10022 10023 10024 10025 10026 10027 10028 10029 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022 class SyslogConfiguration < Struct.new( :log_group_arn, :source_type, :vpc_endpoint_id, :created_at) SENSITIVE = [] include Aws::Structure end |
#log_group_arn ⇒ String
The ARN of the log group associated with this syslog configuration.
10022 10023 10024 10025 10026 10027 10028 10029 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022 class SyslogConfiguration < Struct.new( :log_group_arn, :source_type, :vpc_endpoint_id, :created_at) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The source type for the syslog configuration.
10022 10023 10024 10025 10026 10027 10028 10029 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022 class SyslogConfiguration < Struct.new( :log_group_arn, :source_type, :vpc_endpoint_id, :created_at) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_id ⇒ String
The ID of the VPC endpoint used for syslog ingestion.
10022 10023 10024 10025 10026 10027 10028 10029 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10022 class SyslogConfiguration < Struct.new( :log_group_arn, :source_type, :vpc_endpoint_id, :created_at) SENSITIVE = [] include Aws::Structure end |