Class: Aws::CloudWatchLogs::Types::TriggerHistoryRecord
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::TriggerHistoryRecord
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
A record of a scheduled query execution, including execution status, timestamp, and destination processing results.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destinations ⇒ Array<Types::ScheduledQueryDestination>
Information about destination processing for this query execution.
-
#error_message ⇒ String
Error message if the query execution failed.
-
#execution_status ⇒ String
The execution status of the scheduled query run.
-
#query_id ⇒ String
The unique identifier for this query execution.
-
#triggered_timestamp ⇒ Integer
The timestamp when the scheduled query execution was triggered.
Instance Attribute Details
#destinations ⇒ Array<Types::ScheduledQueryDestination>
Information about destination processing for this query execution.
9520 9521 9522 9523 9524 9525 9526 9527 9528 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520 class TriggerHistoryRecord < Struct.new( :query_id, :execution_status, :triggered_timestamp, :error_message, :destinations) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
Error message if the query execution failed.
9520 9521 9522 9523 9524 9525 9526 9527 9528 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520 class TriggerHistoryRecord < Struct.new( :query_id, :execution_status, :triggered_timestamp, :error_message, :destinations) SENSITIVE = [] include Aws::Structure end |
#execution_status ⇒ String
The execution status of the scheduled query run.
9520 9521 9522 9523 9524 9525 9526 9527 9528 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520 class TriggerHistoryRecord < Struct.new( :query_id, :execution_status, :triggered_timestamp, :error_message, :destinations) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The unique identifier for this query execution.
9520 9521 9522 9523 9524 9525 9526 9527 9528 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520 class TriggerHistoryRecord < Struct.new( :query_id, :execution_status, :triggered_timestamp, :error_message, :destinations) SENSITIVE = [] include Aws::Structure end |
#triggered_timestamp ⇒ Integer
The timestamp when the scheduled query execution was triggered.
9520 9521 9522 9523 9524 9525 9526 9527 9528 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9520 class TriggerHistoryRecord < Struct.new( :query_id, :execution_status, :triggered_timestamp, :error_message, :destinations) SENSITIVE = [] include Aws::Structure end |