Class: Aws::CloudWatchLogs::Types::TrimString
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::TrimString
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Use this processor to remove leading and trailing whitespace.
For more information about this processor including examples, see trimString in the CloudWatch Logs User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#with_keys ⇒ Array<String>
The array containing the keys of the fields to trim.
Instance Attribute Details
#with_keys ⇒ Array<String>
The array containing the keys of the fields to trim.
10337 10338 10339 10340 10341 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10337 class TrimString < Struct.new( :with_keys) SENSITIVE = [] include Aws::Structure end |