Class: Aws::CloudWatchLogs::Types::UpdateAnomalyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anomaly_detector_arnString

The ARN of the anomaly detector that this operation is to act on.

Returns:

  • (String)


5384
5385
5386
5387
5388
5389
5390
5391
5392
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5384

class UpdateAnomalyRequest < Struct.new(
  :anomaly_id,
  :pattern_id,
  :anomaly_detector_arn,
  :suppression_type,
  :suppression_period)
  SENSITIVE = []
  include Aws::Structure
end

#anomaly_idString

If you are suppressing or unsuppressing an anomaly, specify its unique ID here. You can find anomaly IDs by using the

ListAnomalies][1

operation.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListAnomalies.html

Returns:

  • (String)


5384
5385
5386
5387
5388
5389
5390
5391
5392
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5384

class UpdateAnomalyRequest < Struct.new(
  :anomaly_id,
  :pattern_id,
  :anomaly_detector_arn,
  :suppression_type,
  :suppression_period)
  SENSITIVE = []
  include Aws::Structure
end

#pattern_idString

If you are suppressing or unsuppressing an pattern, specify its unique ID here. You can find pattern IDs by using the

ListAnomalies][1

operation.

[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListAnomalies.html

Returns:

  • (String)


5384
5385
5386
5387
5388
5389
5390
5391
5392
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5384

class UpdateAnomalyRequest < Struct.new(
  :anomaly_id,
  :pattern_id,
  :anomaly_detector_arn,
  :suppression_type,
  :suppression_period)
  SENSITIVE = []
  include Aws::Structure
end

#suppression_periodTypes::SuppressionPeriod

If you are temporarily suppressing an anomaly or pattern, use this structure to specify how long the suppression is to last.



5384
5385
5386
5387
5388
5389
5390
5391
5392
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5384

class UpdateAnomalyRequest < Struct.new(
  :anomaly_id,
  :pattern_id,
  :anomaly_detector_arn,
  :suppression_type,
  :suppression_period)
  SENSITIVE = []
  include Aws::Structure
end

#suppression_typeString

Use this to specify whether the suppression to be temporary or infinite. If you specify ‘LIMITED`, you must also specify a `suppressionPeriod`. If you specify `INFINITE`, any value for `suppressionPeriod` is ignored.

Returns:

  • (String)


5384
5385
5386
5387
5388
5389
5390
5391
5392
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 5384

class UpdateAnomalyRequest < Struct.new(
  :anomaly_id,
  :pattern_id,
  :anomaly_detector_arn,
  :suppression_type,
  :suppression_period)
  SENSITIVE = []
  include Aws::Structure
end