Class: Aws::CloudWatchLogs::Types::UpdateAnomalyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateAnomalyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector that this operation is to act on.
-
#anomaly_id ⇒ String
If you are suppressing or unsuppressing an anomaly, specify its unique ID here.
-
#pattern_id ⇒ String
If you are suppressing or unsuppressing an pattern, specify its unique ID here.
-
#suppression_period ⇒ Types::SuppressionPeriod
If you are temporarily suppressing an anomaly or pattern, use this structure to specify how long the suppression is to last.
-
#suppression_type ⇒ String
Use this to specify whether the suppression to be temporary or infinite.
Instance Attribute Details
#anomaly_detector_arn ⇒ String
The ARN of the anomaly detector that this operation is to act on.
4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4957 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period) SENSITIVE = [] include Aws::Structure end |
#anomaly_id ⇒ String
If you are suppressing or unsuppressing an anomaly, specify its unique ID here. You can find anomaly IDs by using the
- ListAnomalies][1
-
operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListAnomalies.html
4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4957 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period) SENSITIVE = [] include Aws::Structure end |
#pattern_id ⇒ String
If you are suppressing or unsuppressing an pattern, specify its unique ID here. You can find pattern IDs by using the
- ListAnomalies][1
-
operation.
[1]: docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_ListAnomalies.html
4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4957 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period) SENSITIVE = [] include Aws::Structure end |
#suppression_period ⇒ Types::SuppressionPeriod
If you are temporarily suppressing an anomaly or pattern, use this structure to specify how long the suppression is to last.
4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4957 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period) SENSITIVE = [] include Aws::Structure end |
#suppression_type ⇒ String
Use this to specify whether the suppression to be temporary or infinite. If you specify ‘LIMITED`, you must also specify a `suppressionPeriod`. If you specify `INFINITE`, any value for `suppressionPeriod` is ignored.
4957 4958 4959 4960 4961 4962 4963 4964 4965 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 4957 class UpdateAnomalyRequest < Struct.new( :anomaly_id, :pattern_id, :anomaly_detector_arn, :suppression_type, :suppression_period) SENSITIVE = [] include Aws::Structure end |