Class: Aws::CloudWatchLogs::Types::UpdateDeliveryConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateDeliveryConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#field_delimiter ⇒ String
The field delimiter to use between record fields when the final output format of a delivery is in ‘Plain`, `W3C`, or `Raw` format.
-
#id ⇒ String
The ID of the delivery to be updated by this request.
-
#record_fields ⇒ Array<String>
The list of record fields to be delivered to the destination, in order.
-
#s3_delivery_configuration ⇒ Types::S3DeliveryConfiguration
This structure contains parameters that are valid only when the delivery’s delivery destination is an S3 bucket.
Instance Attribute Details
#field_delimiter ⇒ String
The field delimiter to use between record fields when the final output format of a delivery is in ‘Plain`, `W3C`, or `Raw` format.
10323 10324 10325 10326 10327 10328 10329 10330 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10323 class UpdateDeliveryConfigurationRequest < Struct.new( :id, :record_fields, :field_delimiter, :s3_delivery_configuration) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the delivery to be updated by this request.
10323 10324 10325 10326 10327 10328 10329 10330 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10323 class UpdateDeliveryConfigurationRequest < Struct.new( :id, :record_fields, :field_delimiter, :s3_delivery_configuration) SENSITIVE = [] include Aws::Structure end |
#record_fields ⇒ Array<String>
The list of record fields to be delivered to the destination, in order. If the delivery’s log source has mandatory fields, they must be included in this list.
10323 10324 10325 10326 10327 10328 10329 10330 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10323 class UpdateDeliveryConfigurationRequest < Struct.new( :id, :record_fields, :field_delimiter, :s3_delivery_configuration) SENSITIVE = [] include Aws::Structure end |
#s3_delivery_configuration ⇒ Types::S3DeliveryConfiguration
This structure contains parameters that are valid only when the delivery’s delivery destination is an S3 bucket.
10323 10324 10325 10326 10327 10328 10329 10330 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10323 class UpdateDeliveryConfigurationRequest < Struct.new( :id, :record_fields, :field_delimiter, :s3_delivery_configuration) SENSITIVE = [] include Aws::Structure end |