Class: Aws::CloudWatchLogs::Types::UpdateLogAnomalyDetectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anomaly_detector_arnString

The ARN of the anomaly detector that you want to update.

Returns:

  • (String)


10520
10521
10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10520

class UpdateLogAnomalyDetectorRequest < Struct.new(
  :anomaly_detector_arn,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_visibility_time,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#anomaly_visibility_timeInteger

The number of days to use as the life cycle of anomalies. After this time, anomalies are automatically baselined and the anomaly detector model will treat new occurrences of similar event as normal. Therefore, if you do not correct the cause of an anomaly during this time, it will be considered normal going forward and will not be detected.

Returns:

  • (Integer)


10520
10521
10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10520

class UpdateLogAnomalyDetectorRequest < Struct.new(
  :anomaly_detector_arn,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_visibility_time,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

Use this parameter to pause or restart the anomaly detector.

Returns:

  • (Boolean)


10520
10521
10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10520

class UpdateLogAnomalyDetectorRequest < Struct.new(
  :anomaly_detector_arn,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_visibility_time,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#evaluation_frequencyString

Specifies how often the anomaly detector runs and look for anomalies. Set this value according to the frequency that the log group receives new logs. For example, if the log group receives new log events every 10 minutes, then setting ‘evaluationFrequency` to `FIFTEEN_MIN` might be appropriate.

Returns:

  • (String)


10520
10521
10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10520

class UpdateLogAnomalyDetectorRequest < Struct.new(
  :anomaly_detector_arn,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_visibility_time,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end

#filter_patternString

A symbolic description of how CloudWatch Logs should interpret the data in each log event. For example, a log event can contain timestamps, IP addresses, strings, and so on. You use the filter pattern to specify what to look for in the log event message.

Returns:

  • (String)


10520
10521
10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10520

class UpdateLogAnomalyDetectorRequest < Struct.new(
  :anomaly_detector_arn,
  :evaluation_frequency,
  :filter_pattern,
  :anomaly_visibility_time,
  :enabled)
  SENSITIVE = []
  include Aws::Structure
end