Class: Aws::CloudWatchLogs::Types::UpdateLookupTableRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateLookupTableRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
An updated description of the lookup table.
-
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data.
-
#lookup_table_arn ⇒ String
The ARN of the lookup table to update.
-
#query_id ⇒ String
The ID of a completed or cancelled CloudWatch Logs query whose results replace the lookup table content.
-
#table_body ⇒ String
The new CSV content to replace the existing data.
Instance Attribute Details
#description ⇒ String
An updated description of the lookup table.
10773 10774 10775 10776 10777 10778 10779 10780 10781 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10773 class UpdateLookupTableRequest < Struct.new( :lookup_table_arn, :description, :table_body, :query_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ARN of the KMS key to use to encrypt the lookup table data. You can use this parameter to add, update, or remove the KMS key. To remove the KMS key and use an Amazon Web Services-owned key instead, specify an empty string.
10773 10774 10775 10776 10777 10778 10779 10780 10781 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10773 class UpdateLookupTableRequest < Struct.new( :lookup_table_arn, :description, :table_body, :query_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#lookup_table_arn ⇒ String
The ARN of the lookup table to update.
10773 10774 10775 10776 10777 10778 10779 10780 10781 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10773 class UpdateLookupTableRequest < Struct.new( :lookup_table_arn, :description, :table_body, :query_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#query_id ⇒ String
The ID of a completed or cancelled CloudWatch Logs query whose results replace the lookup table content. A cancelled query replaces the content with the partial results that were available when the query was stopped.
You must specify either tableBody or queryId, but not both.
10773 10774 10775 10776 10777 10778 10779 10780 10781 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10773 class UpdateLookupTableRequest < Struct.new( :lookup_table_arn, :description, :table_body, :query_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |
#table_body ⇒ String
The new CSV content to replace the existing data. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.
You must specify either tableBody or queryId, but not both.
10773 10774 10775 10776 10777 10778 10779 10780 10781 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10773 class UpdateLookupTableRequest < Struct.new( :lookup_table_arn, :description, :table_body, :query_id, :kms_key_id) SENSITIVE = [] include Aws::Structure end |