Class: Aws::CloudWatchLogs::Types::UpdateLookupTableRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

An updated description of the lookup table.

Returns:

  • (String)


10206
10207
10208
10209
10210
10211
10212
10213
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10206

class UpdateLookupTableRequest < Struct.new(
  :lookup_table_arn,
  :description,
  :table_body,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ARN of the KMS key to use to encrypt the lookup table data. You can use this parameter to add, update, or remove the KMS key. To remove the KMS key and use an Amazon Web Services-owned key instead, specify an empty string.

Returns:

  • (String)


10206
10207
10208
10209
10210
10211
10212
10213
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10206

class UpdateLookupTableRequest < Struct.new(
  :lookup_table_arn,
  :description,
  :table_body,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#lookup_table_arnString

The ARN of the lookup table to update.

Returns:

  • (String)


10206
10207
10208
10209
10210
10211
10212
10213
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10206

class UpdateLookupTableRequest < Struct.new(
  :lookup_table_arn,
  :description,
  :table_body,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end

#table_bodyString

The new CSV content to replace the existing data. The first row must be a header row with column names. The content must use UTF-8 encoding and not exceed 10 MB.

Returns:

  • (String)


10206
10207
10208
10209
10210
10211
10212
10213
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10206

class UpdateLookupTableRequest < Struct.new(
  :lookup_table_arn,
  :description,
  :table_body,
  :kms_key_id)
  SENSITIVE = []
  include Aws::Structure
end