Class: Aws::CloudWatchLogs::Types::UpdateScheduledQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateScheduledQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
An updated description for the scheduled query.
-
#destination_configuration ⇒ Types::DestinationConfiguration
The updated configuration for where to deliver query results.
-
#end_time_offset ⇒ Integer
The updated time offset in seconds that defines the end of the lookback period for the query.
-
#execution_role_arn ⇒ String
The updated ARN of the IAM role that grants permissions to execute the query and deliver results.
-
#identifier ⇒ String
The ARN or name of the scheduled query to update.
-
#log_group_identifiers ⇒ Array<String>
The updated array of log group names or ARNs to query.
-
#query_language ⇒ String
The updated query language for the scheduled query.
-
#query_string ⇒ String
The updated query string to execute.
-
#schedule_end_time ⇒ Integer
The updated end time for the scheduled query in Unix epoch format.
-
#schedule_expression ⇒ String
The updated cron expression that defines when the scheduled query runs.
-
#schedule_start_time ⇒ Integer
The updated start time for the scheduled query in Unix epoch format.
-
#start_time_offset ⇒ Integer
The updated time offset in seconds that defines the lookback period for the query.
-
#state ⇒ String
The updated state of the scheduled query.
-
#timezone ⇒ String
The updated timezone for evaluating the schedule expression.
Instance Attribute Details
#description ⇒ String
An updated description for the scheduled query.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#destination_configuration ⇒ Types::DestinationConfiguration
The updated configuration for where to deliver query results.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#end_time_offset ⇒ Integer
The updated time offset in seconds that defines the end of the lookback period for the query.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The updated ARN of the IAM role that grants permissions to execute the query and deliver results.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The ARN or name of the scheduled query to update.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
The updated array of log group names or ARNs to query.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The updated query language for the scheduled query.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The updated query string to execute.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_end_time ⇒ Integer
The updated end time for the scheduled query in Unix epoch format.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_expression ⇒ String
The updated cron expression that defines when the scheduled query runs.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_start_time ⇒ Integer
The updated start time for the scheduled query in Unix epoch format.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#start_time_offset ⇒ Integer
The updated time offset in seconds that defines the lookback period for the query.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The updated state of the scheduled query.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#timezone ⇒ String
The updated timezone for evaluating the schedule expression.
10699 10700 10701 10702 10703 10704 10705 10706 10707 10708 10709 10710 10711 10712 10713 10714 10715 10716 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10699 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |