Class: Aws::CloudWatchLogs::Types::UpdateScheduledQueryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateScheduledQueryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
An updated description for the scheduled query.
-
#destination_configuration ⇒ Types::DestinationConfiguration
The updated configuration for where to deliver query results.
-
#execution_role_arn ⇒ String
The updated ARN of the IAM role that grants permissions to execute the query and deliver results.
-
#identifier ⇒ String
The ARN or name of the scheduled query to update.
-
#log_group_identifiers ⇒ Array<String>
The updated array of log group names or ARNs to query.
-
#query_language ⇒ String
The updated query language for the scheduled query.
-
#query_string ⇒ String
The updated query string to execute.
-
#schedule_end_time ⇒ Integer
The updated end time for the scheduled query in Unix epoch format.
-
#schedule_expression ⇒ String
The updated cron expression that defines when the scheduled query runs.
-
#schedule_start_time ⇒ Integer
The updated start time for the scheduled query in Unix epoch format.
-
#start_time_offset ⇒ Integer
The updated time offset in seconds that defines the lookback period for the query.
-
#state ⇒ String
The updated state of the scheduled query.
-
#timezone ⇒ String
The updated timezone for evaluating the schedule expression.
Instance Attribute Details
#description ⇒ String
An updated description for the scheduled query.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#destination_configuration ⇒ Types::DestinationConfiguration
The updated configuration for where to deliver query results.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The updated ARN of the IAM role that grants permissions to execute the query and deliver results.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The ARN or name of the scheduled query to update.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
The updated array of log group names or ARNs to query.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The updated query language for the scheduled query.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The updated query string to execute.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_end_time ⇒ Integer
The updated end time for the scheduled query in Unix epoch format.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_expression ⇒ String
The updated cron expression that defines when the scheduled query runs.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#schedule_start_time ⇒ Integer
The updated start time for the scheduled query in Unix epoch format.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#start_time_offset ⇒ Integer
The updated time offset in seconds that defines the lookback period for the query.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The updated state of the scheduled query.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |
#timezone ⇒ String
The updated timezone for evaluating the schedule expression.
9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 9904 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 9888 class UpdateScheduledQueryRequest < Struct.new( :identifier, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :destination_configuration, :schedule_start_time, :schedule_end_time, :execution_role_arn, :state) SENSITIVE = [] include Aws::Structure end |