Class: Aws::CloudWatchLogs::Types::UpdateScheduledQueryResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cloudwatchlogs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeInteger

The timestamp when the scheduled query was originally created.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configurationTypes::DestinationConfiguration

The destination configuration of the updated scheduled query.



10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#end_time_offsetInteger

The end time offset in seconds of the updated scheduled query.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

The execution role ARN of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_execution_statusString

The status of the most recent execution of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_triggered_timeInteger

The timestamp when the updated scheduled query was last executed.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_timeInteger

The timestamp when the scheduled query was last updated.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_identifiersArray<String>

The log groups queried by the updated scheduled query.

Returns:

  • (Array<String>)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#query_languageString

The query language of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The query string of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_end_timeInteger

The end time of the updated scheduled query.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expressionString

The cron expression of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_start_timeInteger

The start time of the updated scheduled query.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_typeString

The schedule type of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#scheduled_query_arnString

The ARN of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_time_offsetInteger

The time offset of the updated scheduled query.

Returns:

  • (Integer)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end

#timezoneString

The timezone of the updated scheduled query.

Returns:

  • (String)


10872
10873
10874
10875
10876
10877
10878
10879
10880
10881
10882
10883
10884
10885
10886
10887
10888
10889
10890
10891
10892
10893
10894
10895
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872

class UpdateScheduledQueryResponse < Struct.new(
  :scheduled_query_arn,
  :name,
  :description,
  :query_language,
  :query_string,
  :log_group_identifiers,
  :schedule_expression,
  :timezone,
  :start_time_offset,
  :end_time_offset,
  :destination_configuration,
  :state,
  :schedule_type,
  :last_triggered_time,
  :last_execution_status,
  :schedule_start_time,
  :schedule_end_time,
  :execution_role_arn,
  :creation_time,
  :last_updated_time)
  SENSITIVE = []
  include Aws::Structure
end