Class: Aws::CloudWatchLogs::Types::UpdateScheduledQueryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchLogs::Types::UpdateScheduledQueryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchlogs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Integer
The timestamp when the scheduled query was originally created.
-
#description ⇒ String
The description of the updated scheduled query.
-
#destination_configuration ⇒ Types::DestinationConfiguration
The destination configuration of the updated scheduled query.
-
#end_time_offset ⇒ Integer
The end time offset in seconds of the updated scheduled query.
-
#execution_role_arn ⇒ String
The execution role ARN of the updated scheduled query.
-
#last_execution_status ⇒ String
The status of the most recent execution of the updated scheduled query.
-
#last_triggered_time ⇒ Integer
The timestamp when the updated scheduled query was last executed.
-
#last_updated_time ⇒ Integer
The timestamp when the scheduled query was last updated.
-
#log_group_identifiers ⇒ Array<String>
The log groups queried by the updated scheduled query.
-
#name ⇒ String
The name of the updated scheduled query.
-
#query_language ⇒ String
The query language of the updated scheduled query.
-
#query_string ⇒ String
The query string of the updated scheduled query.
-
#schedule_end_time ⇒ Integer
The end time of the updated scheduled query.
-
#schedule_expression ⇒ String
The cron expression of the updated scheduled query.
-
#schedule_start_time ⇒ Integer
The start time of the updated scheduled query.
-
#schedule_type ⇒ String
The schedule type of the updated scheduled query.
-
#scheduled_query_arn ⇒ String
The ARN of the updated scheduled query.
-
#start_time_offset ⇒ Integer
The time offset of the updated scheduled query.
-
#state ⇒ String
The state of the updated scheduled query.
-
#timezone ⇒ String
The timezone of the updated scheduled query.
Instance Attribute Details
#creation_time ⇒ Integer
The timestamp when the scheduled query was originally created.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#destination_configuration ⇒ Types::DestinationConfiguration
The destination configuration of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#end_time_offset ⇒ Integer
The end time offset in seconds of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The execution role ARN of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_execution_status ⇒ String
The status of the most recent execution of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_triggered_time ⇒ Integer
The timestamp when the updated scheduled query was last executed.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Integer
The timestamp when the scheduled query was last updated.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#log_group_identifiers ⇒ Array<String>
The log groups queried by the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#query_language ⇒ String
The query language of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The query string of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_end_time ⇒ Integer
The end time of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_expression ⇒ String
The cron expression of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_start_time ⇒ Integer
The start time of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#schedule_type ⇒ String
The schedule type of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#scheduled_query_arn ⇒ String
The ARN of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#start_time_offset ⇒ Integer
The time offset of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#timezone ⇒ String
The timezone of the updated scheduled query.
10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 |
# File 'lib/aws-sdk-cloudwatchlogs/types.rb', line 10872 class UpdateScheduledQueryResponse < Struct.new( :scheduled_query_arn, :name, :description, :query_language, :query_string, :log_group_identifiers, :schedule_expression, :timezone, :start_time_offset, :end_time_offset, :destination_configuration, :state, :schedule_type, :last_triggered_time, :last_execution_status, :schedule_start_time, :schedule_end_time, :execution_role_arn, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |